c;;;;;;;;;;;;;;;;;;;;;;;;;;;;; -*- Mode: Fortran -*- ;;;;;;;;;;;;;;;;;;;;;;;;;;;
c;; hadr5n.f -- 
c;; Author          : Friedrich Jegerlehner
c;; Created On      : Wed Sep  9 17:52:59 2009
c;; Last Modified By: Friedrich Jegerlehner
c;; Last Modified On: Fri Jan 22 02:28:43 2010
c;; RCS: $Id$
c;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
c;; Copyright (C) 2009 Friedrich Jegerlehner
c;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
c;; 
       subroutine hadr5n(e,st2,der,errder,deg,errdeg)
c Provides real part of 5 flavor hadronic contribution to photon vacuum polarization
c single precision HADR5 ; double precision DHADR5
c ******************************************************************
c *                                                                *
c *      subroutine for the evaluation of the light hadron         *
c *           contributions to Delta_r  and  Delta_g               *
c *                    using fits to the                           *
c *          QED vacuum polarization from e^+ e^- data             *
c *                                                                *
c *    F. Jegerlehner, Institut fr Physik                         *
c *                    Humboldt-Universitt zu Berlin              *
c *                    Newtonstrae 15, D-12489 Berlin, Germany    *
c *    E-mail: fjeger@physik.hu-berlin.de                          *
c *    Phone :   +49-3375 500 277                                  *
c *                                                                *
c *    Reference: F. Jegerlehner, Z. Phys. C32 (1986) 195          *
c *               H. Burkhardt et al., Z. Phys. C42 (1989) 497     *
c *               S. Eidelman, F. Jegerlehner, Z. Phys. C (1995)   *
c *               F. Jegerlehner,                                  *
c *                    Nucl.Phys.Proc.Suppl.131:213-222,2004       *
c *                    Nucl.Phys.Proc.Suppl.162:22-32,2006         *
c *                    Nucl.Phys.Proc.Suppl.181-182:135-140,2008   *
c *                                                                *
c ******************************************************************
c       VERSION: 09/09/2009
c
C  Notation: E energy ( momentum transfer ): E>0 timelike , E<0 spacelike
C            st2 is sin^2(Theta); st2=0.2322 is the reference value
C  the routine returns the hadronic contribution of 5 flavors (u,d,s,c,b)
C                 to   DER=Delta_r with hadronic error ERRDER
C                and   DEG=Delta_g with hadronic error ERRDEG
C  The effective value of the fine structure constant alphaQED at energy
C  E is alphaQED(E)=alphaQED(0)/(1-Delta_r) ,similarly for the SU(2)
C  coupling alphaSU2(E)=alphaSU2(0)/(1-Delta_g), where Delta_r(g) is the
C  sum of leptonic, hadronic contributions (top to be added).
C
      IMPLICIT NONE
      INTEGER NA,NB,NC,IJ,I,ini
      PARAMETER(NA=977,NB=1840,NC=200)
      real e,st2,der,errder,deg,errdeg
      real dal(2),dg2(2)
      REAL ETA(NA),DAT(NA,2),ESA(NB),DAS(NB,2),EMA(NC),DAM(NC,2)
      COMMON /DATT/ETA,DAT
      COMMON /DATS/ESA,DAS
      COMMON /DATM/EMA,DAM
      data ini/0/
C initialize data

      call dalhad_spacelike

      call dalhad_timelike

      call dalhad_timelike1

c boundaries of data sets
c space-like and unphysical region  -1.0000E+03 - 0.27599999D0 (ETA,DAT)
c time-like R data range 0.28207018D0 - 38.29000000D0          (ESA,DAS)
c time-like1 pQCD range 1.3005E+01 - 2.0000E+04                (EMA,DAM)
c 2 pion threshold at 0.27914....

      if (e.eq.0.0) then
        der=0.0
        errder=0.0
        deg=0.0
        errdeg=0.0
        return
c first bridge cracks between regions
      else if ((e.ge.ETA(NA)).and.(e.lt.ESA(1))) then
        DO I=1,2
        dal(i)=DAT(NA,I)
     &    +(DAS(1,I)-DAT(NA,I))/(ESA(1)-ETA(NA))*(E-ETA(NA))
        ENDDO
        der=dal(1)
        errder=dal(2)
        deg=0.0
        errdeg=0.0
        return
      else if ((e.lt.ETA(NA)).and.(e.ge.ETA(1))) then
        ij=NA
        do while (ETA(ij).ge.e)
          ij=ij-1
        enddo
        DO I=1,2
        dal(i)=DAT(IJ,I)
     &    +(DAT(IJ+1,I)-DAT(IJ,I))/(ETA(IJ+1)-ETA(IJ))*(E-ETA(IJ))
        ENDDO
        der=dal(1)
        errder=dal(2)
        deg=0.0
        errdeg=0.0
        return
      else if ((e.le.EMA(NC)).and.(e.gt.EMA(1))) then
        ij=NC
        do while (EMA(ij).ge.e)
          ij=ij-1
        enddo
        DO I=1,2
        dal(i)=DAM(IJ,I)
     &    +(DAM(IJ+1,I)-DAM(IJ,I))/(EMA(IJ+1)-EMA(IJ))*(E-EMA(IJ))
        ENDDO
        der=dal(1)
        errder=dal(2)
        deg=0.0
        errdeg=0.0
        return
      else if ((e.le.ESA(NB)).and.(e.gt.ESA(1))) then
        if ((e.gt.3.96).and.(e.lt.4.52).and.(ini.eq.0)) then
c           write (*,*) ' ******************************************'
c           write (*,*) ' * Note: fluctuations in the Psi(4,5,6)   *'
c           write (*,*) ' * region are because we are using the    *'
c           write (*,*) ' * CB and BES data without any smoothing  *'
c           write (*,*) ' *********** FJ@HU Berlin *****************'
           ini=1
        endif
        ij=NB
        do while (ESA(ij).ge.e)
          ij=ij-1
        enddo
        DO I=1,2
        dal(i)=DAS(IJ,I)
     &    +(DAS(IJ+1,I)-DAS(IJ,I))/(ESA(IJ+1)-ESA(IJ))*(E-ESA(IJ))
        ENDDO
        der=dal(1)
        errder=dal(2)
        deg=0.0
        errdeg=0.0
        return
      else
         write(*,*) ' out of range! '
      endif
      return
      end

       subroutine dhadr5n(de,dst2,dder,derrder,ddeg,derrdeg)
c **********************************************************************
c *    F. Jegerlehner, University of Silesia, PL-40007 Katowice, Poland *
c **********************************************************************
c Converts hadr5n to double precision variables in dhadr5n
c
       implicit none
       real *8 de,dst2,dder,ddeg,derrder,derrdeg
       real    se,sst2,sder,sdeg,serrder,serrdeg
       se  =sngl(de)
       sst2=sngl(dst2)
       call hadr5n(se,sst2,sder,serrder,sdeg,serrdeg)
       dder   =dble(sder)
       ddeg   =dble(sdeg)
       derrder=dble(serrder)
       derrdeg=dble(serrdeg)
       return
       end
c
c Following datasets obtained with run parameters specified in the header
c 
c ******************************************************************************
c *                                                                            *
c *    --- intRdat1 ---                              Tue Jan 19 14:57:19 2010  *
c *                                                                            *
c ***************************# FJ@HU Berlin #***********************************
c 
c    Delta alpha [5 quarks]     Update version (22/09/2009) 
c
c  ISCAN: 1, Ismooth: 0, IGS: 0, DSET:     , iplot: 0
c  IKE,Emin,Emax,NP,N,EPSREL: 1, 3.6000E+00, 4.2000E+00,   2, 10, 1.00E-03,
c  ALS(sta)(sys):  0.1184( 0.0007)( 0.0000), MZINP:   91.1876, MTOP:    171.30
c  NF,IOR,ICHK: 5,4,2
c  CHPTCUT,EC,ECUT: 0.3180,     5.20,    11.50
 
       subroutine dalhad_timelike
       IMPLICIT NONE
       INTEGER NB,I,J
       PARAMETER(NB=1840)
       REAL ESA(NB),DAS(NB,2)
       COMMON /DATS/ESA,DAS
  
       DATA  (ESA(I), I=   1, 100) /
     &   0.28207018D0, 0.28800000D0, 0.29400000D0, 0.30000000D0,
     &   0.30600000D0, 0.31200000D0, 0.32050000D0, 0.32600000D0,
     &   0.33100000D0, 0.33600000D0, 0.34100000D0, 0.34600000D0,
     &   0.35200000D0, 0.35600000D0, 0.36100000D0, 0.36600000D0,
     &   0.37100000D0, 0.37600000D0, 0.38000000D0, 0.38500000D0,
     &   0.38900000D0, 0.39400000D0, 0.39800000D0, 0.40300000D0,
     &   0.40700000D0, 0.41100000D0, 0.41600000D0, 0.41871100D0,
     &   0.42000000D0, 0.42400000D0, 0.42800000D0, 0.43200000D0,
     &   0.43600000D0, 0.44000000D0, 0.44400000D0, 0.44800000D0,
     &   0.45200000D0, 0.45600000D0, 0.46000000D0, 0.46400000D0,
     &   0.46700000D0, 0.47100000D0, 0.47500000D0, 0.47800000D0,
     &   0.48200000D0, 0.48600000D0, 0.48900000D0, 0.49300000D0,
     &   0.49600000D0, 0.50000000D0, 0.52000000D0, 0.54000000D0,
     &   0.56600000D0, 0.59200000D0, 0.60000000D0, 0.60200000D0,
     &   0.60800000D0, 0.61600000D0, 0.62400000D0, 0.63200000D0,
     &   0.64000000D0, 0.64300000D0, 0.64800000D0, 0.65600000D0,
     &   0.66300000D0, 0.67100000D0, 0.67800000D0, 0.68600000D0,
     &   0.68800000D0, 0.69300000D0, 0.69800000D0, 0.70000000D0,
     &   0.70700000D0, 0.71400000D0, 0.72100000D0, 0.72800000D0,
     &   0.73500000D0, 0.74200000D0, 0.74800000D0, 0.75000000D0,
     &   0.75500000D0, 0.75743600D0, 0.76007300D0, 0.76207300D0,
     &   0.76507300D0, 0.76851700D0, 0.77060500D0, 0.77205400D0,
     &   0.77314300D0, 0.77400300D0, 0.77470900D0, 0.77530500D0,
     &   0.77582000D0, 0.77627100D0, 0.77667300D0, 0.77726600D0,
     &   0.77746600D0, 0.77766900D0, 0.77795100D0, 0.77821500D0/
  
       DATA  (ESA(I), I= 101, 200) /
     &   0.77846300D0, 0.77869800D0, 0.77892200D0, 0.77913700D0,
     &   0.77934400D0, 0.77954500D0, 0.77974200D0, 0.77993500D0,
     &   0.78012700D0, 0.78031800D0, 0.78051000D0, 0.78070600D0,
     &   0.78090800D0, 0.78112100D0, 0.78135100D0, 0.78161200D0,
     &   0.78193600D0, 0.78268000D0, 0.78341500D0, 0.78373400D0,
     &   0.78399100D0, 0.78421700D0, 0.78442600D0, 0.78462500D0,
     &   0.78481700D0, 0.78500500D0, 0.78519100D0, 0.78537800D0,
     &   0.78556600D0, 0.78575600D0, 0.78595100D0, 0.78615100D0,
     &   0.78635800D0, 0.78657300D0, 0.78679800D0, 0.78703400D0,
     &   0.78728400D0, 0.78755000D0, 0.78773500D0, 0.78793500D0,
     &   0.78814300D0, 0.78847900D0, 0.78884800D0, 0.78925800D0,
     &   0.78971900D0, 0.79024600D0, 0.79085900D0, 0.79158800D0,
     &   0.79248000D0, 0.79361500D0, 0.79513900D0, 0.79736300D0,
     &   0.79800000D0, 0.80000000D0, 0.80200000D0, 0.80400000D0,
     &   0.80600000D0, 0.80800000D0, 0.81200000D0, 0.81400000D0,
     &   0.81600000D0, 0.82000000D0, 0.82200000D0, 0.82400000D0,
     &   0.82600000D0, 0.82800000D0, 0.83000000D0, 0.83100000D0,
     &   0.83700000D0, 0.84300000D0, 0.84900000D0, 0.85400000D0,
     &   0.86000000D0, 0.86600000D0, 0.87200000D0, 0.87700000D0,
     &   0.88300000D0, 0.88900000D0, 0.89400000D0, 0.89700000D0,
     &   0.90250000D0, 0.90500000D0, 0.91100000D0, 0.91600000D0,
     &   0.92200000D0, 0.92700000D0, 0.93300000D0, 0.93800000D0,
     &   0.94300000D0, 0.94900000D0, 0.95200000D0, 0.95400000D0,
     &   0.95800000D0, 0.96000000D0, 0.96200000D0, 0.96400000D0,
     &   0.96600000D0, 0.96800000D0, 0.97000000D0, 0.97400000D0/
  
       DATA  (ESA(I), I= 201, 300) /
     &   0.97800000D0, 0.98000000D0, 0.98070000D0, 0.98140000D0,
     &   0.98210000D0, 0.98280000D0, 0.98350000D0, 0.98420000D0,
     &   0.98490000D0, 0.98560000D0, 0.98630000D0, 0.98700000D0,
     &   0.98770000D0, 0.98840000D0, 0.98910000D0, 0.98980000D0,
     &   0.99050000D0, 0.99120000D0, 0.99190000D0, 0.99260000D0,
     &   0.99330000D0, 0.99400000D0, 0.99470000D0, 0.99540000D0,
     &   0.99610000D0, 0.99680000D0, 0.99750000D0, 0.99820000D0,
     &   0.99890000D0, 0.99960000D0, 0.99990000D0, 1.00001000D0,
     &   1.00030000D0, 1.00100000D0, 1.00170000D0, 1.00240000D0,
     &   1.00310000D0, 1.00380000D0, 1.00450000D0, 1.00520000D0,
     &   1.00590000D0, 1.00660000D0, 1.00730000D0, 1.00800000D0,
     &   1.00870000D0, 1.00940000D0, 1.01010000D0, 1.01080000D0,
     &   1.01150000D0, 1.01220000D0, 1.01290000D0, 1.01360000D0,
     &   1.01430000D0, 1.01500000D0, 1.01520000D0, 1.01540000D0,
     &   1.01560000D0, 1.01580000D0, 1.01600000D0, 1.01620000D0,
     &   1.01640000D0, 1.01660000D0, 1.01680000D0, 1.01700000D0,
     &   1.01720000D0, 1.01740000D0, 1.01760000D0, 1.01780000D0,
     &   1.01800000D0, 1.01820000D0, 1.01840000D0, 1.01860000D0,
     &   1.01880000D0, 1.01900000D0, 1.01920000D0, 1.01940000D0,
     &   1.01960000D0, 1.01980000D0, 1.02000000D0, 1.02020000D0,
     &   1.02040000D0, 1.02060000D0, 1.02080000D0, 1.02100000D0,
     &   1.02120000D0, 1.02140000D0, 1.02160000D0, 1.02180000D0,
     &   1.02200000D0, 1.02220000D0, 1.02240000D0, 1.02260000D0,
     &   1.02280000D0, 1.02300000D0, 1.02320000D0, 1.02340000D0,
     &   1.02360000D0, 1.02380000D0, 1.02400000D0, 1.02420000D0/
  
       DATA  (ESA(I), I= 301, 400) /
     &   1.02440000D0, 1.02460000D0, 1.02480000D0, 1.02500000D0,
     &   1.02570000D0, 1.02640000D0, 1.02710000D0, 1.02780000D0,
     &   1.02850000D0, 1.02920000D0, 1.02990000D0, 1.03060000D0,
     &   1.03130000D0, 1.03200000D0, 1.03270000D0, 1.03340000D0,
     &   1.03410000D0, 1.03480000D0, 1.03550000D0, 1.03620000D0,
     &   1.03690000D0, 1.03760000D0, 1.03830000D0, 1.03900000D0,
     &   1.03970000D0, 1.03999000D0, 1.04001000D0, 1.04040000D0,
     &   1.04110000D0, 1.04180000D0, 1.04250000D0, 1.04320000D0,
     &   1.04390000D0, 1.04460000D0, 1.04530000D0, 1.04600000D0,
     &   1.04670000D0, 1.04740000D0, 1.04810000D0, 1.04880000D0,
     &   1.04950000D0, 1.05020000D0, 1.05090000D0, 1.05160000D0,
     &   1.05230000D0, 1.05300000D0, 1.05370000D0, 1.05440000D0,
     &   1.05510000D0, 1.05580000D0, 1.05650000D0, 1.05720000D0,
     &   1.05790000D0, 1.05860000D0, 1.05930000D0, 1.06000000D0,
     &   1.06200000D0, 1.06700000D0, 1.07700000D0, 1.08700000D0,
     &   1.09700000D0, 1.10700000D0, 1.11700000D0, 1.12700000D0,
     &   1.13700000D0, 1.13800000D0, 1.15200000D0, 1.16300000D0,
     &   1.16700000D0, 1.17700000D0, 1.18700000D0, 1.18800000D0,
     &   1.19700000D0, 1.20700000D0, 1.21200000D0, 1.21700000D0,
     &   1.22700000D0, 1.23700000D0, 1.24700000D0, 1.25700000D0,
     &   1.26300000D0, 1.26700000D0, 1.27700000D0, 1.28700000D0,
     &   1.28800000D0, 1.29700000D0, 1.30700000D0, 1.31200000D0,
     &   1.31700000D0, 1.32700000D0, 1.33700000D0, 1.34700000D0,
     &   1.35000000D0, 1.35700000D0, 1.36200000D0, 1.36700000D0,
     &   1.37700000D0, 1.38700000D0, 1.38800000D0, 1.39500000D0/
  
       DATA  (ESA(I), I= 401, 500) /
     &   1.41000000D0, 1.41900000D0, 1.42700000D0, 1.43500000D0,
     &   1.43800000D0, 1.45200000D0, 1.45700000D0, 1.46000000D0,
     &   1.46400000D0, 1.47200000D0, 1.48100000D0, 1.49000000D0,
     &   1.49100000D0, 1.50000000D0, 1.50100000D0, 1.50600000D0,
     &   1.51000000D0, 1.52300000D0, 1.52500000D0, 1.53800000D0,
     &   1.53900000D0, 1.54000000D0, 1.55000000D0, 1.56000000D0,
     &   1.56200000D0, 1.57400000D0, 1.57500000D0, 1.58000000D0,
     &   1.58100000D0, 1.58700000D0, 1.59000000D0, 1.59900000D0,
     &   1.60000000D0, 1.61000000D0, 1.61900000D0, 1.62400000D0,
     &   1.62500000D0, 1.63800000D0, 1.64000000D0, 1.65000000D0,
     &   1.65700000D0, 1.66000000D0, 1.66200000D0, 1.66300000D0,
     &   1.67300000D0, 1.67500000D0, 1.68100000D0, 1.68700000D0,
     &   1.69000000D0, 1.70000000D0, 1.71000000D0, 1.71200000D0,
     &   1.71300000D0, 1.71900000D0, 1.72200000D0, 1.72500000D0,
     &   1.73800000D0, 1.74000000D0, 1.74600000D0, 1.75000000D0,
     &   1.75600000D0, 1.75700000D0, 1.76000000D0, 1.76200000D0,
     &   1.76400000D0, 1.76900000D0, 1.77500000D0, 1.78100000D0,
     &   1.79000000D0, 1.79900000D0, 1.80000000D0, 1.81200000D0,
     &   1.81900000D0, 1.82500000D0, 1.82600000D0, 1.83400000D0,
     &   1.83500000D0, 1.83800000D0, 1.84500000D0, 1.85700000D0,
     &   1.85900000D0, 1.87400000D0, 1.88100000D0, 1.88600000D0,
     &   1.90000000D0, 1.91900000D0, 1.92500000D0, 1.93000000D0,
     &   1.93800000D0, 1.94000000D0, 1.94500000D0, 1.94600000D0,
     &   1.95000000D0, 1.95500000D0, 1.96000000D0, 1.96200000D0,
     &   1.98100000D0, 1.99050000D0, 2.00000000D0, 2.05000000D0/
  
       DATA  (ESA(I), I= 501, 600) /
     &   2.10000000D0, 2.15000000D0, 2.22000000D0, 2.25000000D0,
     &   2.30000000D0, 2.40000000D0, 2.45000000D0, 2.50000000D0,
     &   2.55000000D0, 2.60000000D0, 2.65000000D0, 2.70000000D0,
     &   2.75000000D0, 2.80000000D0, 2.85000000D0, 2.90000000D0,
     &   2.95000000D0, 3.00000000D0, 3.04293500D0, 3.08587000D0,
     &   3.08688300D0, 3.08789600D0, 3.08890900D0, 3.08992200D0,
     &   3.09093500D0, 3.09194800D0, 3.09296100D0, 3.09397400D0,
     &   3.09498700D0, 3.09600000D0, 3.09605000D0, 3.09610000D0,
     &   3.09615000D0, 3.09620000D0, 3.09625000D0, 3.09630000D0,
     &   3.09635000D0, 3.09640000D0, 3.09645000D0, 3.09650000D0,
     &   3.09655000D0, 3.09660000D0, 3.09665000D0, 3.09665500D0,
     &   3.09673500D0, 3.09677100D0, 3.09679300D0, 3.09680900D0,
     &   3.09682000D0, 3.09682900D0, 3.09683600D0, 3.09684300D0,
     &   3.09684800D0, 3.09685300D0, 3.09685700D0, 3.09686100D0,
     &   3.09686400D0, 3.09686800D0, 3.09687000D0, 3.09687300D0,
     &   3.09687600D0, 3.09687800D0, 3.09688100D0, 3.09688300D0,
     &   3.09688500D0, 3.09688700D0, 3.09688900D0, 3.09689100D0,
     &   3.09689300D0, 3.09689500D0, 3.09689700D0, 3.09689900D0,
     &   3.09690100D0, 3.09690400D0, 3.09690600D0, 3.09690900D0,
     &   3.09691200D0, 3.09692000D0, 3.09692800D0, 3.09693100D0,
     &   3.09693400D0, 3.09693600D0, 3.09693900D0, 3.09694100D0,
     &   3.09694300D0, 3.09694500D0, 3.09694700D0, 3.09694900D0,
     &   3.09695100D0, 3.09695300D0, 3.09695500D0, 3.09695700D0,
     &   3.09695900D0, 3.09696200D0, 3.09696400D0, 3.09696700D0,
     &   3.09697000D0, 3.09697200D0, 3.09697600D0, 3.09697900D0/
  
       DATA  (ESA(I), I= 601, 700) /
     &   3.09698300D0, 3.09698700D0, 3.09699200D0, 3.09699700D0,
     &   3.09700400D0, 3.09701100D0, 3.09702000D0, 3.09703100D0,
     &   3.09704700D0, 3.09706900D0, 3.09710500D0, 3.09715000D0,
     &   3.09720000D0, 3.09725000D0, 3.09730000D0, 3.09735000D0,
     &   3.09740000D0, 3.09745000D0, 3.09750000D0, 3.09755000D0,
     &   3.09760000D0, 3.09765000D0, 3.09770000D0, 3.09775000D0,
     &   3.09780000D0, 3.09785000D0, 3.09790000D0, 3.09795000D0,
     &   3.09800000D0, 3.09898700D0, 3.09997400D0, 3.10096100D0,
     &   3.10194800D0, 3.10293500D0, 3.10392200D0, 3.10490900D0,
     &   3.10589600D0, 3.10688300D0, 3.10787000D0, 3.15000000D0,
     &   3.25000000D0, 3.30000000D0, 3.40000000D0, 3.45000000D0,
     &   3.50000000D0, 3.55000000D0, 3.59000000D0, 3.60200000D0,
     &   3.63000000D0, 3.65000000D0, 3.66000000D0, 3.67000000D0,
     &   3.67496000D0, 3.67551000D0, 3.67606000D0, 3.67661000D0,
     &   3.67716000D0, 3.67771000D0, 3.67826000D0, 3.67881000D0,
     &   3.67936000D0, 3.67991000D0, 3.68046000D0, 3.68101000D0,
     &   3.68156000D0, 3.68211000D0, 3.68266000D0, 3.68321000D0,
     &   3.68376000D0, 3.68431000D0, 3.68486000D0, 3.68527300D0,
     &   3.68541000D0, 3.68552000D0, 3.68569900D0, 3.68574600D0,
     &   3.68578100D0, 3.68580900D0, 3.68583200D0, 3.68585100D0,
     &   3.68586800D0, 3.68588300D0, 3.68589500D0, 3.68590700D0,
     &   3.68591800D0, 3.68592800D0, 3.68593700D0, 3.68594600D0,
     &   3.68595300D0, 3.68596100D0, 3.68596800D0, 3.68597500D0,
     &   3.68598200D0, 3.68598800D0, 3.68599500D0, 3.68600100D0,
     &   3.68600700D0, 3.68601300D0, 3.68602000D0, 3.68602600D0/
  
       DATA  (ESA(I), I= 701, 800) /
     &   3.68603300D0, 3.68603900D0, 3.68604700D0, 3.68605500D0,
     &   3.68606600D0, 3.68607500D0, 3.68608500D0, 3.68609000D0,
     &   3.68609500D0, 3.68610000D0, 3.68611400D0, 3.68612500D0,
     &   3.68613300D0, 3.68614100D0, 3.68614700D0, 3.68615400D0,
     &   3.68616000D0, 3.68616700D0, 3.68617300D0, 3.68617900D0,
     &   3.68618500D0, 3.68619200D0, 3.68619800D0, 3.68620500D0,
     &   3.68621200D0, 3.68621900D0, 3.68622700D0, 3.68623400D0,
     &   3.68624300D0, 3.68625200D0, 3.68626200D0, 3.68627300D0,
     &   3.68628500D0, 3.68629700D0, 3.68631200D0, 3.68632900D0,
     &   3.68634800D0, 3.68637100D0, 3.68639900D0, 3.68643400D0,
     &   3.68648100D0, 3.68654800D0, 3.68651000D0, 3.68666000D0,
     &   3.68690700D0, 3.68706000D0, 3.68761000D0, 3.68816000D0,
     &   3.68871000D0, 3.68926000D0, 3.68981000D0, 3.69036000D0,
     &   3.69091000D0, 3.69146000D0, 3.69201000D0, 3.69256000D0,
     &   3.69311000D0, 3.69366000D0, 3.69421000D0, 3.69476000D0,
     &   3.69531000D0, 3.69586000D0, 3.69641000D0, 3.69696000D0,
     &   3.72128100D0, 3.73082800D0, 3.73660200D0, 3.74060200D0,
     &   3.74360300D0, 3.74597300D0, 3.74791700D0, 3.74955600D0,
     &   3.75096800D0, 3.75220600D0, 3.75330900D0, 3.75430100D0,
     &   3.75520500D0, 3.75603600D0, 3.75680500D0, 3.75752300D0,
     &   3.75819800D0, 3.75883700D0, 3.75944400D0, 3.76002600D0,
     &   3.76058600D0, 3.76112800D0, 3.76165500D0, 3.76217200D0,
     &   3.76268100D0, 3.76318700D0, 3.76369200D0, 3.76420200D0,
     &   3.76472200D0, 3.76526100D0, 3.76582800D0, 3.76644200D0,
     &   3.76713800D0, 3.76800500D0, 3.77000000D0, 3.77199500D0/
  
       DATA  (ESA(I), I= 801, 900) /
     &   3.77286200D0, 3.77355800D0, 3.77417200D0, 3.77474000D0,
     &   3.77527800D0, 3.77579800D0, 3.77630800D0, 3.77681400D0,
     &   3.77731900D0, 3.77782800D0, 3.77834500D0, 3.77887200D0,
     &   3.77941400D0, 3.77997400D0, 3.78055600D0, 3.78116300D0,
     &   3.78180200D0, 3.78247700D0, 3.78319500D0, 3.78396400D0,
     &   3.78479500D0, 3.78569900D0, 3.78669100D0, 3.78779400D0,
     &   3.78903200D0, 3.79044400D0, 3.79208300D0, 3.79402700D0,
     &   3.79639700D0, 3.79939800D0, 3.80339800D0, 3.80917200D0,
     &   3.81871900D0, 3.82200000D0, 3.83200000D0, 3.85000000D0,
     &   3.85200000D0, 3.86700000D0, 3.87300000D0, 3.87800000D0,
     &   3.88400000D0, 3.89000000D0, 3.89600000D0, 3.90000000D0,
     &   3.90200000D0, 3.90800000D0, 3.91400000D0, 3.92000000D0,
     &   3.92600000D0, 3.93200000D0, 3.93800000D0, 3.94400000D0,
     &   3.95000000D0, 3.95600000D0, 3.96200000D0, 3.96800000D0,
     &   3.97400000D0, 3.98000000D0, 3.98600000D0, 3.99200000D0,
     &   3.99800000D0, 4.00000000D0, 4.00400000D0, 4.01000000D0,
     &   4.01600000D0, 4.02000000D0, 4.02200000D0, 4.02800000D0,
     &   4.03000000D0, 4.03400000D0, 4.04000000D0, 4.04600000D0,
     &   4.05000000D0, 4.05200000D0, 4.05800000D0, 4.06400000D0,
     &   4.07000000D0, 4.07600000D0, 4.08200000D0, 4.08800000D0,
     &   4.09000000D0, 4.09400000D0, 4.10000000D0, 4.10500000D0,
     &   4.10900000D0, 4.11000000D0, 4.11300000D0, 4.11800000D0,
     &   4.12100000D0, 4.12500000D0, 4.12900000D0, 4.13000000D0,
     &   4.13300000D0, 4.13600000D0, 4.14100000D0, 4.14700000D0,
     &   4.15000000D0, 4.15300000D0, 4.15900000D0, 4.16500000D0/
  
       DATA  (ESA(I), I= 901,1000) /
     &   4.17100000D0, 4.17700000D0, 4.18000000D0, 4.18200000D0,
     &   4.18500000D0, 4.19000000D0, 4.19500000D0, 4.20000000D0,
     &   4.20100000D0, 4.20800000D0, 4.21200000D0, 4.21400000D0,
     &   4.22000000D0, 4.22600000D0, 4.23200000D0, 4.23800000D0,
     &   4.24000000D0, 4.24400000D0, 4.25000000D0, 4.25600000D0,
     &   4.26200000D0, 4.26800000D0, 4.27400000D0, 4.28000000D0,
     &   4.29200000D0, 4.30000000D0, 4.30400000D0, 4.31000000D0,
     &   4.31600000D0, 4.32800000D0, 4.33000000D0, 4.34000000D0,
     &   4.35000000D0, 4.35200000D0, 4.36400000D0, 4.37600000D0,
     &   4.38000000D0, 4.38200000D0, 4.38800000D0, 4.39000000D0,
     &   4.39400000D0, 4.40000000D0, 4.40600000D0, 4.41000000D0,
     &   4.41200000D0, 4.41800000D0, 4.42400000D0, 4.43000000D0,
     &   4.43600000D0, 4.44000000D0, 4.44200000D0, 4.44800000D0,
     &   4.45000000D0, 4.46000000D0, 4.47200000D0, 4.48400000D0,
     &   4.49600000D0, 4.50450000D0, 4.54000000D0, 4.55000000D0,
     &   4.57000000D0, 4.60000000D0, 4.62000000D0, 4.65000000D0,
     &   4.66000000D0, 4.70000000D0, 4.71000000D0, 4.80000000D0,
     &   4.90000000D0, 4.98000000D0, 5.06500000D0, 5.15000000D0,
     &   5.22500000D0, 5.25000000D0, 5.30000000D0, 5.40000000D0,
     &   5.45000000D0, 5.50000000D0, 5.60000000D0, 5.70000000D0,
     &   5.75000000D0, 5.80000000D0, 5.85000000D0, 5.90000000D0,
     &   5.95000000D0, 6.00000000D0, 6.05000000D0, 6.10000000D0,
     &   6.15000000D0, 6.20000000D0, 6.25000000D0, 6.30000000D0,
     &   6.35000000D0, 6.40000000D0, 6.45000000D0, 6.50000000D0,
     &   6.55000000D0, 6.60000000D0, 6.65000000D0, 6.70000000D0/
  
       DATA  (ESA(I), I=1001,1100) /
     &   6.75000000D0, 6.80000000D0, 6.85000000D0, 6.90000000D0,
     &   6.95000000D0, 7.00000000D0, 7.05000000D0, 7.10000000D0,
     &   7.15000000D0, 7.20000000D0, 7.25000000D0, 7.30000000D0,
     &   7.35000000D0, 7.40000000D0, 7.44000000D0, 7.50000000D0,
     &   7.60000000D0, 7.70000000D0, 7.80000000D0, 7.90000000D0,
     &   8.00000000D0, 8.10000000D0, 8.20000000D0, 8.30000000D0,
     &   8.40000000D0, 8.50000000D0, 8.60000000D0, 8.70000000D0,
     &   8.80000000D0, 8.90000000D0, 8.91000000D0, 9.00000000D0,
     &   9.10000000D0, 9.20000000D0, 9.28000000D0, 9.30000000D0,
     &   9.35000000D0, 9.39000000D0, 9.40000000D0, 9.41000000D0,
     &   9.41500000D0, 9.42000000D0, 9.43000000D0, 9.44000000D0,
     &   9.44937000D0, 9.44959000D0, 9.44981000D0, 9.45003000D0,
     &   9.45025000D0, 9.45047000D0, 9.45069000D0, 9.45091000D0,
     &   9.45113000D0, 9.45135000D0, 9.45157000D0, 9.45179000D0,
     &   9.45201000D0, 9.45223000D0, 9.45245000D0, 9.45267000D0,
     &   9.45289000D0, 9.45311000D0, 9.45333000D0, 9.45355000D0,
     &   9.45377000D0, 9.45399000D0, 9.45421000D0, 9.45443000D0,
     &   9.45465000D0, 9.45487000D0, 9.45509000D0, 9.45531000D0,
     &   9.45553000D0, 9.45575000D0, 9.45597000D0, 9.45619000D0,
     &   9.45641000D0, 9.45663000D0, 9.45685000D0, 9.45707000D0,
     &   9.45729000D0, 9.45751000D0, 9.45773000D0, 9.45795000D0,
     &   9.45817000D0, 9.45839000D0, 9.45861000D0, 9.45883000D0,
     &   9.45905000D0, 9.45927000D0, 9.45949000D0, 9.45971000D0,
     &   9.45993000D0, 9.46000000D0, 9.46014595D0, 9.46019268D0,
     &   9.46021366D0, 9.46022606D0, 9.46023464D0, 9.46024132D0/
  
       DATA  (ESA(I), I=1101,1200) /
     &   9.46024704D0, 9.46025085D0, 9.46025467D0, 9.46025848D0,
     &   9.46026039D0, 9.46026325D0, 9.46026516D0, 9.46026802D0,
     &   9.46026897D0, 9.46027088D0, 9.46027279D0, 9.46027470D0,
     &   9.46027565D0, 9.46027660D0, 9.46027851D0, 9.46027946D0,
     &   9.46028042D0, 9.46028233D0, 9.46028328D0, 9.46028423D0,
     &   9.46028519D0, 9.46028709D0, 9.46028805D0, 9.46028900D0,
     &   9.46029091D0, 9.46029186D0, 9.46029377D0, 9.46029568D0,
     &   9.46030045D0, 9.46030426D0, 9.46030617D0, 9.46030807D0,
     &   9.46030998D0, 9.46031094D0, 9.46031189D0, 9.46031284D0,
     &   9.46031475D0, 9.46031570D0, 9.46031666D0, 9.46031761D0,
     &   9.46031952D0, 9.46032047D0, 9.46032143D0, 9.46032333D0,
     &   9.46032429D0, 9.46032619D0, 9.46032715D0, 9.46032906D0,
     &   9.46033096D0, 9.46033287D0, 9.46033478D0, 9.46033669D0,
     &   9.46033955D0, 9.46034145D0, 9.46034527D0, 9.46034908D0,
     &   9.46035290D0, 9.46035862D0, 9.46036530D0, 9.46037388D0,
     &   9.46038628D0, 9.46040726D0, 9.46045494D0, 9.46059000D0,
     &   9.46081000D0, 9.46103000D0, 9.46125000D0, 9.46147000D0,
     &   9.46169000D0, 9.46191000D0, 9.46213000D0, 9.46235000D0,
     &   9.46257000D0, 9.46279000D0, 9.46301000D0, 9.46323000D0,
     &   9.46345000D0, 9.46367000D0, 9.46389000D0, 9.46411000D0,
     &   9.46433000D0, 9.46455000D0, 9.46477000D0, 9.46499000D0,
     &   9.46521000D0, 9.46543000D0, 9.46565000D0, 9.46587000D0,
     &   9.46609000D0, 9.46631000D0, 9.46653000D0, 9.46675000D0,
     &   9.46697000D0, 9.46719000D0, 9.46741000D0, 9.46763000D0,
     &   9.46785000D0, 9.46807000D0, 9.46829000D0, 9.46851000D0/
  
       DATA  (ESA(I), I=1201,1300) /
     &   9.46873000D0, 9.46895000D0, 9.46917000D0, 9.46939000D0,
     &   9.46961000D0, 9.46983000D0, 9.47005000D0, 9.47027000D0,
     &   9.47049000D0, 9.47071000D0, 9.47093000D0, 9.47115000D0,
     &   9.47137000D0, 9.48000000D0, 9.48400000D0, 9.49000000D0,
     &   9.51000000D0, 9.60000000D0, 9.70000000D0, 9.80000000D0,
     &   9.90000000D0,10.00000000D0,10.01226000D0,10.01281000D0,
     &  10.01336000D0,10.01391000D0,10.01446000D0,10.01501000D0,
     &  10.01556000D0,10.01611000D0,10.01666000D0,10.01721000D0,
     &  10.01776000D0,10.01831000D0,10.01886000D0,10.01941000D0,
     &  10.01996000D0,10.02051000D0,10.02106000D0,10.02161000D0,
     &  10.02216000D0,10.02250000D0,10.02253750D0,10.02257500D0,
     &  10.02261250D0,10.02265000D0,10.02268750D0,10.02272500D0,
     &  10.02276250D0,10.02280000D0,10.02283750D0,10.02287500D0,
     &  10.02291250D0,10.02295000D0,10.02298750D0,10.02302500D0,
     &  10.02306250D0,10.02310000D0,10.02313750D0,10.02317500D0,
     &  10.02321250D0,10.02322000D0,10.02322500D0,10.02323000D0,
     &  10.02323400D0,10.02323700D0,10.02324000D0,10.02324200D0,
     &  10.02324400D0,10.02324600D0,10.02324800D0,10.02324930D0,
     &  10.02324950D0,10.02324960D0,10.02324980D0,10.02324988D0,
     &  10.02324994D0,10.02325000D0,10.02325060D0,10.02325150D0,
     &  10.02325250D0,10.02325340D0,10.02325440D0,10.02325540D0,
     &  10.02325630D0,10.02325680D0,10.02325730D0,10.02325780D0,
     &  10.02325850D0,10.02325900D0,10.02325950D0,10.02325980D0,
     &  10.02325990D0,10.02326000D0,10.02326010D0,10.02326050D0,
     &  10.02326100D0,10.02326150D0,10.02326390D0,10.02326490D0/
  
       DATA  (ESA(I), I=1301,1400) /
     &  10.02326680D0,10.02326770D0,10.02326870D0,10.02326970D0,
     &  10.02327060D0,10.02327160D0,10.02327250D0,10.02327350D0,
     &  10.02327440D0,10.02327540D0,10.02327630D0,10.02327730D0,
     &  10.02327820D0,10.02328010D0,10.02328110D0,10.02328210D0,
     &  10.02328300D0,10.02328490D0,10.02328590D0,10.02328750D0,
     &  10.02332500D0,10.02336250D0,10.02340000D0,10.02343750D0,
     &  10.02347500D0,10.02351250D0,10.02355000D0,10.02358750D0,
     &  10.02362500D0,10.02366250D0,10.02370000D0,10.02373750D0,
     &  10.02377500D0,10.02381250D0,10.02385000D0,10.02388750D0,
     &  10.02392500D0,10.02396250D0,10.02400000D0,10.02436000D0,
     &  10.02491000D0,10.02546000D0,10.02601000D0,10.02656000D0,
     &  10.02711000D0,10.02766000D0,10.02821000D0,10.02876000D0,
     &  10.02931000D0,10.02986000D0,10.03041000D0,10.03096000D0,
     &  10.03151000D0,10.03206000D0,10.03261000D0,10.03316000D0,
     &  10.03371000D0,10.03426000D0,10.04000000D0,10.10000000D0,
     &  10.20000000D0,10.30000000D0,10.34420000D0,10.34493333D0,
     &  10.34566667D0,10.34640000D0,10.34713333D0,10.34786667D0,
     &  10.34860000D0,10.34933333D0,10.35006667D0,10.35080000D0,
     &  10.35153333D0,10.35226667D0,10.35300000D0,10.35309167D0,
     &  10.35318333D0,10.35327500D0,10.35336667D0,10.35345833D0,
     &  10.35355000D0,10.35364167D0,10.35373333D0,10.35382500D0,
     &  10.35391667D0,10.35400833D0,10.35410000D0,10.35419167D0,
     &  10.35428333D0,10.35437500D0,10.34420000D0,10.35446667D0,
     &  10.35455833D0,10.35465000D0,10.35474167D0,10.35483334D0,
     &  10.35492500D0,10.35501667D0,10.35510834D0,10.35512330D0/
  
       DATA  (ESA(I), I=1401,1500) /
     &  10.35514660D0,10.35515710D0,10.35516340D0,10.35516780D0,
     &  10.35517110D0,10.35517370D0,10.35517580D0,10.35517760D0,
     &  10.35517920D0,10.35518060D0,10.35518180D0,10.35518290D0,
     &  10.35518390D0,10.35518480D0,10.35518570D0,10.35518650D0,
     &  10.35518720D0,10.35518790D0,10.35518860D0,10.35518930D0,
     &  10.35518990D0,10.35519050D0,10.35519110D0,10.35519170D0,
     &  10.35519230D0,10.35519280D0,10.35519340D0,10.35519400D0,
     &  10.35519460D0,10.35519530D0,10.35519600D0,10.35519680D0,
     &  10.35519770D0,10.35520000D0,10.35520230D0,10.35520320D0,
     &  10.35520400D0,10.35520470D0,10.35520540D0,10.35520600D0,
     &  10.35520660D0,10.35520720D0,10.35520770D0,10.35520830D0,
     &  10.35520890D0,10.35520950D0,10.35521010D0,10.35521070D0,
     &  10.35521140D0,10.35521210D0,10.35521280D0,10.35521350D0,
     &  10.35521430D0,10.35521520D0,10.35521610D0,10.35521710D0,
     &  10.35521820D0,10.35521940D0,10.35522080D0,10.35522240D0,
     &  10.35522420D0,10.35522630D0,10.35522890D0,10.35523220D0,
     &  10.35523660D0,10.35524290D0,10.35525340D0,10.35527670D0,
     &  10.35529167D0,10.35538334D0,10.35547500D0,10.35556667D0,
     &  10.35565834D0,10.35575000D0,10.35584167D0,10.35593334D0,
     &  10.35602500D0,10.35611667D0,10.35620834D0,10.35630000D0,
     &  10.35639167D0,10.35648334D0,10.35657500D0,10.35666667D0,
     &  10.35740000D0,10.35813333D0,10.35886667D0,10.35960000D0,
     &  10.36033333D0,10.36106667D0,10.36180000D0,10.36253333D0,
     &  10.36326667D0,10.36400000D0,10.36473333D0,10.36546667D0,
     &  10.36620000D0,10.40000000D0,10.47300000D0,10.52897000D0/
  
       DATA  (ESA(I), I=1501,1600) /
     &  10.54217000D0,10.54889000D0,10.55317000D0,10.55622000D0,
     &  10.55855000D0,10.56042000D0,10.56197000D0,10.56328000D0,
     &  10.56442000D0,10.56543000D0,10.56633000D0,10.56714000D0,
     &  10.56788000D0,10.56857000D0,10.56921000D0,10.56980000D0,
     &  10.57036000D0,10.57090000D0,10.57141000D0,10.57189000D0,
     &  10.57237000D0,10.57282000D0,10.57327000D0,10.57371000D0,
     &  10.57415000D0,10.57459000D0,10.57503000D0,10.57547000D0,
     &  10.57594000D0,10.57643000D0,10.57695000D0,10.57755000D0,
     &  10.57829000D0,10.58000000D0,10.58171000D0,10.58245000D0,
     &  10.58305000D0,10.58357000D0,10.58406000D0,10.58453000D0,
     &  10.58497000D0,10.58541000D0,10.58585000D0,10.58629000D0,
     &  10.58673000D0,10.58718000D0,10.58763000D0,10.58811000D0,
     &  10.58859000D0,10.58910000D0,10.58964000D0,10.59020000D0,
     &  10.59079000D0,10.59143000D0,10.59212000D0,10.59286000D0,
     &  10.59367000D0,10.59457000D0,10.59558000D0,10.59671000D0,
     &  10.59803000D0,10.59958000D0,10.60145000D0,10.60378000D0,
     &  10.60683000D0,10.61111000D0,10.61783000D0,10.63103000D0,
     &  10.68700000D0,10.69000000D0,10.71309000D0,10.72975000D0,
     &  10.74256000D0,10.75286000D0,10.76141000D0,10.76869000D0,
     &  10.77500000D0,10.78057000D0,10.78554000D0,10.79004000D0,
     &  10.79414000D0,10.79791000D0,10.80141000D0,10.80468000D0,
     &  10.80775000D0,10.81065000D0,10.81341000D0,10.81604000D0,
     &  10.81858000D0,10.82102000D0,10.82339000D0,10.82570000D0,
     &  10.82796000D0,10.83019000D0,10.83240000D0,10.83460000D0,
     &  10.83681000D0,10.83906000D0,10.84135000D0,10.84374000D0/
  
       DATA  (ESA(I), I=1601,1700) /
     &  10.84626000D0,10.84900000D0,10.85212000D0,10.85601000D0,
     &  10.86500000D0,10.87288000D0,10.87627000D0,10.87895000D0,
     &  10.88128000D0,10.88340000D0,10.88539000D0,10.88728000D0,
     &  10.88910000D0,10.89088000D0,10.89262000D0,10.89434000D0,
     &  10.89605000D0,10.89775000D0,10.89946000D0,10.90119000D0,
     &  10.90292000D0,10.90468000D0,10.90648000D0,10.90830000D0,
     &  10.91017000D0,10.91208000D0,10.91406000D0,10.91609000D0,
     &  10.91820000D0,10.92038000D0,10.92266000D0,10.92504000D0,
     &  10.92754000D0,10.93017000D0,10.93295000D0,10.93590000D0,
     &  10.93905000D0,10.94242000D0,10.94606000D0,10.95000000D0,
     &  10.97500000D0,10.97638000D0,10.97771000D0,10.97900000D0,
     &  10.98025000D0,10.98146000D0,10.98263000D0,10.98377000D0,
     &  10.98489000D0,10.98598000D0,10.98705000D0,10.98810000D0,
     &  10.98913000D0,10.99014000D0,10.99114000D0,10.99213000D0,
     &  10.99310000D0,10.99407000D0,10.99504000D0,10.99600000D0,
     &  10.99697000D0,10.99793000D0,10.99890000D0,10.99988000D0,
     &  11.00087000D0,11.00188000D0,11.00290000D0,11.00396000D0,
     &  11.00506000D0,11.00621000D0,11.00742000D0,11.00873000D0,
     &  11.01018000D0,11.01186000D0,11.01399000D0,11.01900000D0,
     &  11.02401000D0,11.02614000D0,11.02782000D0,11.02927000D0,
     &  11.03058000D0,11.03179000D0,11.03294000D0,11.03404000D0,
     &  11.03510000D0,11.03612000D0,11.03713000D0,11.03812000D0,
     &  11.03910000D0,11.04007000D0,11.04103000D0,11.04200000D0,
     &  11.04296000D0,11.04392000D0,11.04490000D0,11.04587000D0,
     &  11.04686000D0,11.04786000D0,11.04887000D0,11.04990000D0/
  
       DATA  (ESA(I), I=1701,1800) /
     &  11.05095000D0,11.05202000D0,11.05311000D0,11.05423000D0,
     &  11.05537000D0,11.05654000D0,11.05775000D0,11.05900000D0,
     &  11.06029000D0,11.06162000D0,11.06300000D0,11.07000000D0,
     &  11.09200000D0,11.11500000D0,11.13700000D0,11.16000000D0,
     &  11.18200000D0,11.20500000D0,11.22700000D0,11.25000000D0,
     &  11.27300000D0,11.29500000D0,11.31800000D0,11.34000000D0,
     &  11.50000000D0,11.65500000D0,11.67700000D0,11.70000000D0,
     &  11.72200000D0,11.74500000D0,11.76700000D0,11.79000000D0,
     &  11.81200000D0,11.83500000D0,11.85800000D0,11.88000000D0,
     &  11.90300000D0,11.92500000D0,11.94800000D0,11.97000000D0,
     &  11.99300000D0,12.01500000D0,12.03800000D0,12.06000000D0,
     &  12.08300000D0,12.10500000D0,12.12700000D0,12.15000000D0,
     &  12.17200000D0,12.19500000D0,12.21700000D0,12.24000000D0,
     &  12.26200000D0,12.28500000D0,12.30700000D0,12.33000000D0,
     &  12.35200000D0,12.37500000D0,12.39800000D0,12.42000000D0,
     &  12.44300000D0,12.46500000D0,12.48800000D0,12.51000000D0,
     &  12.53300000D0,12.55500000D0,12.57800000D0,12.60000000D0,
     &  12.62300000D0,12.64500000D0,12.66700000D0,12.69000000D0,
     &  12.71200000D0,12.73500000D0,12.75700000D0,12.78000000D0,
     &  12.80200000D0,12.82500000D0,12.84700000D0,12.87000000D0,
     &  12.89200000D0,12.91500000D0,12.93800000D0,12.96000000D0,
     &  12.98300000D0,13.00500000D0,13.02800000D0,13.05000000D0,
     &  13.07300000D0,13.09500000D0,13.11800000D0,13.14000000D0,
     &  13.16300000D0,13.18500000D0,13.20800000D0,13.23000000D0,
     &  13.25200000D0,13.27500000D0,13.29700000D0,13.32000000D0/
  
       DATA  (ESA(I), I=1801,1840) /
     &  13.34200000D0,13.36500000D0,13.38700000D0,13.41000000D0,
     &  13.43200000D0,13.45500000D0,13.47700000D0,13.50000000D0,
     &  13.75000000D0,14.00000000D0,14.04000000D0,16.00000000D0,
     &  17.00000000D0,20.00000000D0,21.95000000D0,22.05000000D0,
     &  25.00000000D0,25.01000000D0,27.50000000D0,27.60000000D0,
     &  27.66000000D0,29.00000000D0,29.93000000D0,30.10000000D0,
     &  30.38000000D0,30.80000000D0,31.10000000D0,31.29000000D0,
     &  33.20000000D0,33.30000000D0,33.89000000D0,34.00000000D0,
     &  34.50000000D0,34.70000000D0,34.86000000D0,35.01000000D0,
     &  35.45000000D0,36.10000000D0,36.38000000D0,38.29000000D0/
  
         DATA ((DAS(I,J), I=   1, 100), J=1,1) /
     &  -9.21616955E-04,-9.79165887E-04,-1.03594887E-03,-1.09191008E-03,
     &  -1.14689747E-03,-1.19236282E-03,-1.32451634E-03,-1.33867013E-03,
     &  -1.38013488E-03,-1.43198561E-03,-1.48524382E-03,-1.54021591E-03,
     &  -1.60660313E-03,-1.64977163E-03,-1.70214258E-03,-1.75481253E-03,
     &  -1.80744311E-03,-1.85952883E-03,-1.90092665E-03,-1.95574375E-03,
     &  -2.00133022E-03,-2.06010720E-03,-2.10868315E-03,-2.17079389E-03,
     &  -2.22019568E-03,-2.26969452E-03,-2.33449645E-03,-2.36980810E-03,
     &  -2.38637911E-03,-2.43783600E-03,-2.48951057E-03,-2.54234284E-03,
     &  -2.59661262E-03,-2.65015090E-03,-2.70434338E-03,-2.76045385E-03,
     &  -2.81925911E-03,-2.88121921E-03,-2.94688280E-03,-3.01653822E-03,
     &  -3.06914704E-03,-3.14056638E-03,-3.21436922E-03,-3.27093252E-03,
     &  -3.34732810E-03,-3.42250817E-03,-3.47832540E-03,-3.55304214E-03,
     &  -3.60974279E-03,-3.68569851E-03,-4.08629241E-03,-4.56133976E-03,
     &  -5.26254413E-03,-6.09314911E-03,-6.40264970E-03,-6.48258739E-03,
     &  -6.72843763E-03,-7.06432171E-03,-7.40200228E-03,-7.74564493E-03,
     &  -8.09733922E-03,-8.23274765E-03,-8.46393445E-03,-8.83831250E-03,
     &  -9.15025831E-03,-9.47811911E-03,-9.72864503E-03,-9.95217165E-03,
     &  -9.99266787E-03,-1.00652326E-02,-1.00938053E-02,-1.00909109E-02,
     &  -9.99160017E-03,-9.73048025E-03,-9.31578277E-03,-8.74275431E-03,
     &  -7.99949769E-03,-7.08603148E-03,-6.24272308E-03,-5.98360165E-03,
     &  -5.20874456E-03,-4.92783127E-03,-4.69604526E-03,-4.58050211E-03,
     &  -4.54238834E-03,-4.77705167E-03,-5.08761947E-03,-5.38136712E-03,
     &  -5.64404926E-03,-5.87235928E-03,-6.06338924E-03,-6.20606537E-03,
     &  -6.30126013E-03,-6.34293548E-03,-6.32609855E-03,-6.20696675E-03,
     &  -6.14952419E-03,-6.01051460E-03,-5.73950422E-03,-5.45580523E-03/
         DATA ((DAS(I,J), I= 101, 200), J=1,1) /
     &  -5.18480322E-03,-4.92342172E-03,-4.65240459E-03,-4.37072045E-03,
     &  -4.05255371E-03,-3.69335278E-03,-3.28594772E-03,-2.82644872E-03,
     &  -2.30307351E-03,-1.71047261E-03,-1.04308088E-03,-2.84254323E-04,
     &   5.81639046E-04, 1.58753525E-03, 2.77795713E-03, 4.25241966E-03,
     &   6.24282171E-03, 1.12256334E-02, 1.60542357E-02, 1.79118913E-02,
     &   1.92530639E-02, 2.03048764E-02, 2.11677515E-02, 2.18893834E-02,
     &   2.24942938E-02, 2.30055362E-02, 2.34362968E-02, 2.37960900E-02,
     &   2.40864303E-02, 2.43113783E-02, 2.44716622E-02, 2.45624938E-02,
     &   2.45782352E-02, 2.45114938E-02, 2.43556726E-02, 2.41161719E-02,
     &   2.38104041E-02, 2.34919885E-02, 2.33093330E-02, 2.31084032E-02,
     &   2.28882655E-02, 2.25255176E-02, 2.21223510E-02, 2.16720552E-02,
     &   2.11766563E-02, 2.06268618E-02, 2.00201787E-02, 1.93504731E-02,
     &   1.86096133E-02, 1.77817217E-02, 1.68491530E-02, 1.57825400E-02,
     &   1.55263959E-02, 1.48369528E-02, 1.42941286E-02, 1.38743253E-02,
     &   1.35529642E-02, 1.32798004E-02, 1.33362003E-02, 1.34457493E-02,
     &   1.34601268E-02, 1.33743986E-02, 1.33021714E-02, 1.32119289E-02,
     &   1.31084183E-02, 1.29943481E-02, 1.28754481E-02, 1.28153971E-02,
     &   1.24585860E-02, 1.21315719E-02, 1.18267942E-02, 1.15840566E-02,
     &   1.12963051E-02, 1.09893159E-02, 1.06451907E-02, 1.03288600E-02,
     &   9.92710033E-03, 9.51284059E-03, 9.17521405E-03, 8.98069632E-03,
     &   8.63924560E-03, 8.48883495E-03, 8.13470876E-03, 7.83921070E-03,
     &   7.47227511E-03, 7.14558242E-03, 6.72262699E-03, 6.34526319E-03,
     &   5.94467091E-03, 5.43066937E-03, 5.16270772E-03, 4.98012106E-03,
     &   4.60680480E-03, 4.40118056E-03, 4.20172022E-03, 3.98578254E-03,
     &   3.75048203E-03, 3.49922414E-03, 3.23437266E-03, 2.66694794E-03/
         DATA ((DAS(I,J), I= 201, 300), J=1,1) /
     &   2.02982809E-03, 1.66715279E-03, 1.53175532E-03, 1.39182037E-03,
     &   1.24701360E-03, 1.09702776E-03, 9.41587110E-04, 7.80411440E-04,
     &   6.13377533E-04, 4.40337681E-04, 2.61091152E-04, 7.56194559E-05,
     &  -1.16088157E-04,-3.14164088E-04,-5.19418497E-04,-7.31473264E-04,
     &  -9.50466794E-04,-1.17655571E-03,-1.40981391E-03,-1.65060725E-03,
     &  -1.89957298E-03,-2.15737005E-03,-2.42501933E-03,-2.70384200E-03,
     &  -2.99556468E-03,-3.30256766E-03,-3.62790399E-03,-3.97587555E-03,
     &  -4.35101857E-03,-4.75653468E-03,-4.92150904E-03,-4.90796488E-03,
     &  -5.28780495E-03,-5.87535421E-03,-6.45808911E-03,-7.06725676E-03,
     &  -7.71437414E-03,-8.40800113E-03,-9.15575028E-03,-9.96622034E-03,
     &  -1.08491192E-02,-1.18157145E-02,-1.28793062E-02,-1.40557802E-02,
     &  -1.53642841E-02,-1.68280695E-02,-1.84755331E-02,-2.03414720E-02,
     &  -2.24685043E-02,-2.49084191E-02,-2.77227560E-02,-3.09806797E-02,
     &  -3.47491034E-02,-3.90618883E-02,-4.03878127E-02,-4.17479088E-02,
     &  -4.31342709E-02,-4.45354281E-02,-4.59351882E-02,-4.73111525E-02,
     &  -4.86328250E-02,-4.98592511E-02,-5.09361464E-02,-5.17925440E-02,
     &  -5.23371275E-02,-5.24546801E-02,-5.20034921E-02,-5.08151975E-02,
     &  -4.86992798E-02,-4.54552011E-02,-4.08951926E-02,-3.48792921E-02,
     &  -2.73601827E-02,-1.84286921E-02,-8.34374175E-03, 2.47164523E-03,
     &   1.34785309E-02, 2.41066772E-02, 3.38495624E-02, 4.23381659E-02,
     &   4.93732459E-02, 5.49155368E-02, 5.90483442E-02, 6.19310283E-02,
     &   6.37572173E-02, 6.47242424E-02, 6.50144715E-02, 6.47862212E-02,
     &   6.41711483E-02, 6.32754134E-02, 6.21826708E-02, 6.09576708E-02,
     &   5.96497997E-02, 5.82962361E-02, 5.69246155E-02, 5.55552007E-02,
     &   5.42026102E-02, 5.28771722E-02, 5.15859749E-02, 5.03336738E-02/
         DATA ((DAS(I,J), I= 301, 400), J=1,1) /
     &   4.91231097E-02, 4.79557789E-02, 4.68321916E-02, 4.57521416E-02,
     &   4.23015526E-02, 3.93179606E-02, 3.67339503E-02, 3.44857055E-02,
     &   3.25181246E-02, 3.07853444E-02, 2.92497410E-02, 2.78805775E-02,
     &   2.66527136E-02, 2.55455044E-02, 2.45418997E-02, 2.36277248E-02,
     &   2.27911067E-02, 2.20220167E-02, 2.13119003E-02, 2.06533686E-02,
     &   2.00406747E-02, 1.94666251E-02, 1.89263457E-02, 1.84140698E-02,
     &   1.79226457E-02, 1.77306927E-02, 1.77053407E-02, 1.74094949E-02,
     &   1.69674137E-02, 1.65743774E-02, 1.62137936E-02, 1.58836378E-02,
     &   1.55751668E-02, 1.52870073E-02, 1.50167793E-02, 1.47625301E-02,
     &   1.45228101E-02, 1.42962746E-02, 1.40817791E-02, 1.38783511E-02,
     &   1.36851293E-02, 1.35015286E-02, 1.33264632E-02, 1.31595701E-02,
     &   1.30002620E-02, 1.28479942E-02, 1.27023304E-02, 1.25628045E-02,
     &   1.24290292E-02, 1.23006389E-02, 1.21772720E-02, 1.20587240E-02,
     &   1.19445089E-02, 1.18343823E-02, 1.17281447E-02, 1.15890975E-02,
     &   1.13133687E-02, 1.07143062E-02, 9.76852144E-03, 9.02940373E-03,
     &   8.48201774E-03, 7.98978716E-03, 7.49290129E-03, 7.09167405E-03,
     &   6.71107512E-03, 6.67175624E-03, 6.30995405E-03, 6.03987870E-03,
     &   5.94964172E-03, 5.73287130E-03, 5.52186564E-03, 5.50124575E-03,
     &   5.31874133E-03, 5.12415487E-03, 5.03142399E-03, 4.94826150E-03,
     &   4.80408339E-03, 4.68008741E-03, 4.56530695E-03, 4.44517584E-03,
     &   4.37099201E-03, 4.32039830E-03, 4.19186442E-03, 4.06527468E-03,
     &   4.05366790E-03, 3.95235885E-03, 3.85711411E-03, 3.81458798E-03,
     &   3.76909839E-03, 3.67841409E-03, 3.59297372E-03, 3.50475597E-03,
     &   3.47989948E-03, 3.42071273E-03, 3.37498018E-03, 3.33120786E-03,
     &   3.27017985E-03, 3.23940348E-03, 3.23747849E-03, 3.23630025E-03/
         DATA ((DAS(I,J), I= 401, 500), J=1,1) /
     &   3.27269866E-03, 3.23590604E-03, 3.15470224E-03, 3.04983643E-03,
     &   3.01256998E-03, 2.88638717E-03, 2.88688595E-03, 2.89190299E-03,
     &   2.90351105E-03, 2.94344826E-03, 3.00063523E-03, 3.06329250E-03,
     &   3.07022286E-03, 3.13460969E-03, 3.14239336E-03, 3.18611924E-03,
     &   3.22689224E-03, 3.39731647E-03, 3.42724160E-03, 3.63363807E-03,
     &   3.64837813E-03, 3.66278787E-03, 3.79653074E-03, 3.89574353E-03,
     &   3.90957285E-03, 3.96211947E-03, 3.96331736E-03, 3.95829816E-03,
     &   3.95550929E-03, 3.93725050E-03, 3.92946969E-03, 3.90559779E-03,
     &   3.90322230E-03, 3.89536561E-03, 3.89429084E-03, 3.89649882E-03,
     &   3.89680023E-03, 3.90401969E-03, 3.90980487E-03, 3.97640824E-03,
     &   4.05317095E-03, 4.08718228E-03, 4.10987406E-03, 4.12123463E-03,
     &   4.23614966E-03, 4.25711712E-03, 4.31024177E-03, 4.35451588E-03,
     &   4.37771170E-03, 4.46626289E-03, 4.57494263E-03, 4.59940851E-03,
     &   4.61211662E-03, 4.69428868E-03, 4.73708233E-03, 4.78114053E-03,
     &   4.96460158E-03, 4.98581846E-03, 5.03303357E-03, 5.04943646E-03,
     &   5.04272046E-03, 5.03962082E-03, 5.02913298E-03, 5.02146405E-03,
     &   5.01354453E-03, 4.99394050E-03, 4.97653291E-03, 4.98621004E-03,
     &   5.03474900E-03, 5.08851482E-03, 5.09389452E-03, 5.11912097E-03,
     &   5.10788028E-03, 5.11783531E-03, 5.12195046E-03, 5.14771001E-03,
     &   5.14931474E-03, 5.15549680E-03, 5.17139114E-03, 5.11092301E-03,
     &   5.08645263E-03, 4.83182969E-03, 4.70224384E-03, 4.61062713E-03,
     &   4.39920459E-03, 4.27477176E-03, 4.26237138E-03, 4.25209380E-03,
     &   4.22788367E-03, 4.22187758E-03, 4.19420831E-03, 4.18522893E-03,
     &   4.14656590E-03, 4.09084074E-03, 4.03249393E-03, 4.00755871E-03,
     &   3.65309318E-03, 3.59231422E-03, 3.56513464E-03, 3.74345565E-03/
         DATA ((DAS(I,J), I= 501, 600), J=1,1) /
     &   4.27877965E-03, 4.56954458E-03, 4.87233261E-03, 4.99450012E-03,
     &   5.03614933E-03, 4.97339342E-03, 4.87082430E-03, 4.70484807E-03,
     &   4.50379965E-03, 4.30059783E-03, 4.05885948E-03, 3.75203473E-03,
     &   3.35347837E-03, 2.81842549E-03, 2.06606133E-03, 9.35693499E-04,
     &  -9.45406142E-04,-4.72480390E-03,-1.34656342E-02,-8.94948647E-02,
     &  -9.91313678E-02,-1.10930516E-01,-1.25712616E-01,-1.44772866E-01,
     &  -1.70283134E-01,-2.06184734E-01,-2.60451054E-01,-3.52013780E-01,
     &  -5.39426889E-01,-1.13774817E+00,-1.20312775E+00,-1.27641097E+00,
     &  -1.35911779E+00,-1.45318286E+00,-1.56110657E+00,-1.68617679E+00,
     &  -1.83280312E+00,-2.00703528E+00,-2.21739491E+00,-2.47626246E+00,
     &  -2.80229513E+00,-3.22486566E+00,-3.79270159E+00,-3.86030735E+00,
     &  -5.37026780E+00,-6.46919711E+00,-7.35453496E+00,-8.12949706E+00,
     &  -8.73264117E+00,-9.26676793E+00,-9.70241561E+00,-1.01472179E+01,
     &  -1.04629459E+01,-1.07681860E+01,-1.09972815E+01,-1.12045491E+01,
     &  -1.13396535E+01,-1.14825709E+01,-1.15338091E+01,-1.15791070E+01,
     &  -1.15787310E+01,-1.15482379E+01,-1.14489534E+01,-1.13418556E+01,
     &  -1.11975885E+01,-1.10121653E+01,-1.07815146E+01,-1.05015722E+01,
     &  -1.01683989E+01,-9.77832558E+00,-9.32812387E+00,-8.81520049E+00,
     &  -8.23780796E+00,-7.24968418E+00,-6.51095658E+00,-5.28998515E+00,
     &  -3.94883159E+00, 4.72547970E-03, 3.95837386E+00, 5.29960330E+00,
     &   6.52066754E+00, 7.25946421E+00, 8.24769904E+00, 8.82516873E+00,
     &   9.33817044E+00, 9.78845070E+00, 1.01786019E+01, 1.05118517E+01,
     &   1.07918689E+01, 1.10225919E+01, 1.12080848E+01, 1.13524188E+01,
     &   1.14595803E+01, 1.15589549E+01, 1.15895042E+01, 1.15899587E+01,
     &   1.15447330E+01, 1.14935395E+01, 1.13507036E+01, 1.12156543E+01/
         DATA ((DAS(I,J), I= 601, 700), J=1,1) /
     &   1.10084527E+01, 1.07794157E+01, 1.04742394E+01, 1.01585666E+01,
     &   9.71382928E+00, 9.27823512E+00, 8.74416407E+00, 8.14107301E+00,
     &   7.36616745E+00, 6.48088192E+00, 5.38200347E+00, 4.41903179E+00,
     &   3.67593622E+00, 3.14247557E+00, 2.74232249E+00, 2.43164668E+00,
     &   2.18372923E+00, 1.98143845E+00, 1.81331666E+00, 1.67142516E+00,
     &   1.55009634E+00, 1.44517925E+00, 1.35356593E+00, 1.27288417E+00,
     &   1.20129265E+00, 1.13734059E+00, 1.07986969E+00, 1.02794408E+00,
     &   9.80799496E-01, 5.15941835E-01, 3.51195670E-01, 2.66881470E-01,
     &   2.15657244E-01, 1.81239096E-01, 1.56521678E-01, 1.37910159E-01,
     &   1.23390582E-01, 1.11746948E-01, 1.02201635E-01, 2.56251180E-02,
     &   1.23902575E-02, 1.05654190E-02, 8.61674170E-03, 7.90506617E-03,
     &   7.02190660E-03, 5.77066318E-03, 4.21449513E-03, 3.55680148E-03,
     &   6.78000584E-04,-3.64383018E-03,-8.14493349E-03,-1.80758655E-02,
     &  -2.95267058E-02,-3.14531416E-02,-3.35897856E-02,-3.59731985E-02,
     &  -3.86489065E-02,-4.16743882E-02,-4.51232582E-02,-4.90913275E-02,
     &  -5.37056677E-02,-5.91384943E-02,-6.56291317E-02,-7.35202181E-02,
     &  -8.33201376E-02,-9.58168817E-02,-1.12300544E-01,-1.35037859E-01,
     &  -1.68407859E-01,-2.22088856E-01,-3.22392861E-01,-4.81042945E-01,
     &  -5.72030124E-01,-6.72042053E-01,-9.23050308E-01,-1.01599421E+00,
     &  -1.09420231E+00,-1.16204466E+00,-1.22055307E+00,-1.26987330E+00,
     &  -1.31372665E+00,-1.35111416E+00,-1.37923553E+00,-1.40480073E+00,
     &  -1.42500362E+00,-1.43972327E+00,-1.44913288E+00,-1.45399444E+00,
     &  -1.45398171E+00,-1.44914616E+00,-1.44002403E+00,-1.42565446E+00,
     &  -1.40534035E+00,-1.38264388E+00,-1.34933875E+00,-1.31440389E+00,
     &  -1.27309359E+00,-1.22498650E+00,-1.15978055E+00,-1.09577308E+00/
         DATA ((DAS(I,J), I= 701, 800), J=1,1) /
     &  -1.01136887E+00,-9.30625115E-01,-8.11120177E-01,-6.78775582E-01,
     &  -4.78342187E-01,-3.01759457E-01,-9.71162504E-02, 6.76820993E-03,
     &   1.10653938E-01, 2.13755510E-01, 4.91906855E-01, 6.92369827E-01,
     &   8.24740835E-01, 9.44275247E-01, 1.02504255E+00, 1.10947522E+00,
     &   1.17350755E+00, 1.23874263E+00, 1.28687449E+00, 1.32820916E+00,
     &   1.36316782E+00, 1.39649982E+00, 1.41921844E+00, 1.43955727E+00,
     &   1.45395029E+00, 1.46309458E+00, 1.46795389E+00, 1.46798605E+00,
     &   1.46314768E+00, 1.45375935E+00, 1.43906127E+00, 1.41887977E+00,
     &   1.39333541E+00, 1.36523257E+00, 1.32786538E+00, 1.28403179E+00,
     &   1.23473025E+00, 1.17624058E+00, 1.10841657E+00, 1.03022624E+00,
     &   9.37299903E-01, 8.26646065E-01, 8.86483995E-01, 6.86325544E-01,
     &   4.95342727E-01, 4.21796701E-01, 2.75008375E-01, 2.04591436E-01,
     &   1.63393961E-01, 1.36382449E-01, 1.17313416E-01, 1.03134815E-01,
     &   9.21794357E-02, 8.34602178E-02, 7.63553333E-02, 7.04539023E-02,
     &   6.54735213E-02, 6.12136095E-02, 5.75280266E-02, 5.43074427E-02,
     &   5.14685159E-02, 4.89467545E-02, 4.66913105E-02, 4.46616836E-02,
     &   1.81193197E-02, 1.53278457E-02, 1.40497380E-02, 1.32797937E-02,
     &   1.27445893E-02, 1.23422523E-02, 1.20242091E-02, 1.17645246E-02,
     &   1.15477308E-02, 1.13639346E-02, 1.12062628E-02, 1.10705337E-02,
     &   1.09530396E-02, 1.08514095E-02, 1.07639351E-02, 1.06890595E-02,
     &   1.06257082E-02, 1.05730368E-02, 1.05305503E-02, 1.04976508E-02,
     &   1.04741287E-02, 1.04598098E-02, 1.04546614E-02, 1.04587823E-02,
     &   1.04724317E-02, 1.04961026E-02, 1.05303749E-02, 1.05763137E-02,
     &   1.06353045E-02, 1.07096917E-02, 1.08025612E-02, 1.09197199E-02,
     &   1.10722864E-02, 1.12883916E-02, 1.18585431E-02, 1.24377799E-02/
         DATA ((DAS(I,J), I= 801, 900), J=1,1) /
     &   1.26632677E-02, 1.28255575E-02, 1.29528090E-02, 1.30563550E-02,
     &   1.31415585E-02, 1.32120257E-02, 1.32700211E-02, 1.33170676E-02,
     &   1.33541004E-02, 1.33819925E-02, 1.34013044E-02, 1.34123838E-02,
     &   1.34155333E-02, 1.34108898E-02, 1.33985096E-02, 1.33784113E-02,
     &   1.33504144E-02, 1.33143844E-02, 1.32700208E-02, 1.32169289E-02,
     &   1.31544944E-02, 1.30821290E-02, 1.29990209E-02, 1.29038272E-02,
     &   1.27953721E-02, 1.26716163E-02, 1.25300370E-02, 1.23673035E-02,
     &   1.21791034E-02, 1.19618041E-02, 1.17021314E-02, 1.13324991E-02,
     &   1.07896690E-02, 1.06301383E-02, 1.01934469E-02, 9.51503792E-03,
     &   9.44211082E-03, 8.95263437E-03, 8.75860616E-03, 8.56635959E-03,
     &   8.41350034E-03, 8.23481475E-03, 7.95970103E-03, 7.84647304E-03,
     &   7.85897717E-03, 7.66510560E-03, 7.67398343E-03, 7.91671167E-03,
     &   7.80381271E-03, 7.94608183E-03, 7.80051915E-03, 7.57457985E-03,
     &   7.80639726E-03, 7.51432027E-03, 6.93581889E-03, 6.77515995E-03,
     &   6.97042430E-03, 6.98483495E-03, 6.94765618E-03, 6.81522668E-03,
     &   6.41987296E-03, 6.23169049E-03, 5.79975441E-03, 5.44269292E-03,
     &   5.28894497E-03, 5.55357150E-03, 5.99623012E-03, 6.93881548E-03,
     &   7.27454171E-03, 7.69087615E-03, 7.95562460E-03, 8.24684388E-03,
     &   8.32782480E-03, 8.31542785E-03, 8.72048153E-03, 9.09231115E-03,
     &   9.00647733E-03, 8.96567651E-03, 9.02522004E-03, 9.07343571E-03,
     &   9.11036662E-03, 9.09512752E-03, 9.11898478E-03, 9.11108772E-03,
     &   8.99715647E-03, 8.94597028E-03, 8.96971879E-03, 9.04621117E-03,
     &   9.14340291E-03, 9.39247215E-03, 9.50645186E-03, 9.51420140E-03,
     &   9.51006899E-03, 9.41903444E-03, 9.17621974E-03, 9.16321888E-03,
     &   9.38993994E-03, 9.65375978E-03, 9.88968047E-03, 9.90508757E-03/
         DATA ((DAS(I,J), I= 901,1000), J=1,1) /
     &   1.00022225E-02, 1.01500051E-02, 1.03007084E-02, 1.05674649E-02,
     &   1.08474444E-02, 1.09630204E-02, 1.10819584E-02, 1.13430836E-02,
     &   1.13962397E-02, 1.12900847E-02, 1.10701911E-02, 1.09953559E-02,
     &   1.11254628E-02, 1.10783217E-02, 1.06952699E-02, 1.05681697E-02,
     &   1.06474470E-02, 1.06472403E-02, 1.01893050E-02, 9.72903699E-03,
     &   9.58147775E-03, 9.51214568E-03, 9.45562636E-03, 9.40434416E-03,
     &   9.13510004E-03, 9.00411441E-03, 9.04913599E-03, 9.03351345E-03,
     &   8.83974137E-03, 8.45999866E-03, 8.40944422E-03, 8.30639022E-03,
     &   8.37700232E-03, 8.40610388E-03, 8.46577338E-03, 8.52188151E-03,
     &   8.54095913E-03, 8.55593921E-03, 8.48736027E-03, 8.38277909E-03,
     &   8.30262358E-03, 8.66613547E-03, 8.96072219E-03, 8.94809234E-03,
     &   8.97930766E-03, 8.98892504E-03, 8.96395501E-03, 9.26826370E-03,
     &   9.69637770E-03, 9.81285991E-03, 9.80302423E-03, 9.85030970E-03,
     &   9.88496819E-03, 9.94473152E-03, 1.00070483E-02, 9.97416370E-03,
     &   9.90266721E-03, 9.93223710E-03, 9.58923264E-03, 9.47387814E-03,
     &   9.71080806E-03, 9.76068040E-03, 9.59114409E-03, 9.52180209E-03,
     &   9.51464614E-03, 9.52379410E-03, 9.53758231E-03, 9.78717299E-03,
     &   1.00513604E-02, 1.00967512E-02, 1.00911974E-02, 1.01272481E-02,
     &   9.96558119E-03, 1.01516569E-02, 1.02733109E-02, 1.04569230E-02,
     &   1.05339202E-02, 1.06052751E-02, 1.07363883E-02, 1.08567527E-02,
     &   1.09139302E-02, 1.09694455E-02, 1.10234818E-02, 1.10761845E-02,
     &   1.11276707E-02, 1.11777771E-02, 1.12270906E-02, 1.12754319E-02,
     &   1.13228583E-02, 1.13694189E-02, 1.14151562E-02, 1.14601073E-02,
     &   1.15043043E-02, 1.15477756E-02, 1.15905464E-02, 1.16326385E-02,
     &   1.16740715E-02, 1.17148621E-02, 1.17550273E-02, 1.17945786E-02/
         DATA ((DAS(I,J), I=1001,1100), J=1,1) /
     &   1.18335282E-02, 1.18718862E-02, 1.19096614E-02, 1.19468613E-02,
     &   1.19834918E-02, 1.20195579E-02, 1.20550633E-02, 1.20900103E-02,
     &   1.21244005E-02, 1.21582337E-02, 1.21915092E-02, 1.22242244E-02,
     &   1.22563758E-02, 1.22879585E-02, 1.23128109E-02, 1.23493907E-02,
     &   1.24084506E-02, 1.24650392E-02, 1.25190218E-02, 1.25702199E-02,
     &   1.26183986E-02, 1.26632486E-02, 1.27043598E-02, 1.27411821E-02,
     &   1.27729639E-02, 1.27986530E-02, 1.28166348E-02, 1.28248856E-02,
     &   1.28196765E-02, 1.27949570E-02, 1.27910516E-02, 1.27395776E-02,
     &   1.26302607E-02, 1.24082687E-02, 1.20266327E-02, 1.18676623E-02,
     &   1.12065459E-02, 9.97552939E-03, 9.40616085E-03, 8.60574238E-03,
     &   8.07058951E-03, 7.40043236E-03, 5.38554448E-03, 1.35541173E-03,
     &  -9.18998481E-03,-9.66051749E-03,-1.01508542E-02,-1.06622684E-02,
     &  -1.11961452E-02,-1.17539935E-02,-1.23374606E-02,-1.29483480E-02,
     &  -1.35886304E-02,-1.42604762E-02,-1.49662728E-02,-1.57086543E-02,
     &  -1.64905345E-02,-1.73151448E-02,-1.81860790E-02,-1.91073453E-02,
     &  -2.00834279E-02,-2.11193599E-02,-2.22208098E-02,-2.33941851E-02,
     &  -2.46467566E-02,-2.59868093E-02,-2.74238251E-02,-2.89687074E-02,
     &  -3.06340576E-02,-3.24345192E-02,-3.43872087E-02,-3.65122610E-02,
     &  -3.88335249E-02,-4.13794613E-02,-4.41843142E-02,-4.72896583E-02,
     &  -5.07464716E-02,-5.46179529E-02,-5.89834170E-02,-6.39437814E-02,
     &  -6.96294577E-02,-7.62119748E-02,-8.39215687E-02,-9.30746443E-02,
     &  -1.04118243E-01,-1.17705210E-01,-1.34827992E-01,-1.57072394E-01,
     &  -1.87138700E-01,-2.30028627E-01,-2.96157695E-01,-4.11376951E-01,
     &  -6.62158946E-01,-8.17701009E-01,-1.57133303E+00,-2.19429826E+00,
     &  -2.64752241E+00,-2.99954468E+00,-3.28991743E+00,-3.54511208E+00/
         DATA ((DAS(I,J), I=1101,1200), J=1,1) /
     &  -3.78307012E+00,-3.94959178E+00,-4.12006435E+00,-4.28903951E+00,
     &  -4.37117126E+00,-4.48737920E+00,-4.55796723E+00,-4.64759538E+00,
     &  -4.67172123E+00,-4.70918355E+00,-4.72853574E+00,-4.72510759E+00,
     &  -4.71326686E+00,-4.69372237E+00,-4.62791068E+00,-4.58029868E+00,
     &  -4.52094946E+00,-4.36560098E+00,-4.26804334E+00,-4.15583982E+00,
     &  -4.02674970E+00,-3.72187134E+00,-3.54173855E+00,-3.34575676E+00,
     &  -2.89813842E+00,-2.64934729E+00,-2.09993988E+00,-1.49286436E+00,
     &   1.74918243E-01, 1.50069471E+00, 2.10938755E+00, 2.65805837E+00,
     &   3.14329578E+00, 3.36050589E+00, 3.55761240E+00, 3.73707191E+00,
     &   4.04588235E+00, 4.17471786E+00, 4.28915150E+00, 4.38761378E+00,
     &   4.54461066E+00, 4.60413502E+00, 4.65298907E+00, 4.71973982E+00,
     &   4.74005557E+00, 4.75766110E+00, 4.75659868E+00, 4.73789334E+00,
     &   4.70117563E+00, 4.65001636E+00, 4.58788458E+00, 4.51752062E+00,
     &   4.40153328E+00, 4.31992517E+00, 4.15058642E+00, 3.98053699E+00,
     &   3.81349621E+00, 3.57537034E+00, 3.31995030E+00, 3.02929359E+00,
     &   2.67691752E+00, 2.22325876E+00, 1.59061743E+00, 8.73784982E-01,
     &   5.05630612E-01, 3.57928700E-01, 2.78415779E-01, 2.28747556E-01,
     &   1.94781839E-01, 1.70090718E-01, 1.51332791E-01, 1.36599426E-01,
     &   1.24721254E-01, 1.14941890E-01, 1.06750417E-01, 9.97892970E-02,
     &   9.38008313E-02, 8.85945907E-02, 8.40268100E-02, 7.99869209E-02,
     &   7.63884931E-02, 7.31629889E-02, 7.02553608E-02, 6.76208885E-02,
     &   6.52228654E-02, 6.30308810E-02, 6.10195261E-02, 5.91674059E-02,
     &   5.74563766E-02, 5.58709514E-02, 5.43978305E-02, 5.30255290E-02,
     &   5.17440771E-02, 5.05447783E-02, 4.94200126E-02, 4.83630748E-02,
     &   4.73680415E-02, 4.64296601E-02, 4.55432566E-02, 4.47046582E-02/
         DATA ((DAS(I,J), I=1201,1300), J=1,1) /
     &   4.39101277E-02, 4.31563082E-02, 4.24401761E-02, 4.17590004E-02,
     &   4.11103086E-02, 4.04918566E-02, 3.99016028E-02, 3.93376861E-02,
     &   3.87984063E-02, 3.82822068E-02, 3.77876603E-02, 3.73134552E-02,
     &   3.68583844E-02, 2.72011226E-02, 2.52678923E-02, 2.36968288E-02,
     &   1.83869457E-02, 1.47886999E-02, 1.40813414E-02, 1.36496697E-02,
     &   1.30548838E-02, 9.05929161E-03, 3.77082895E-03, 3.24321131E-03,
     &   2.65710589E-03, 2.00217574E-03, 1.26550403E-03, 4.30732974E-04,
     &  -5.23165971E-04,-1.62368922E-03,-2.90749644E-03,-4.42457584E-03,
     &  -6.24490837E-03,-8.46957409E-03,-1.12501872E-02,-1.48249870E-02,
     &  -1.95910120E-02,-2.62628585E-02,-3.62694769E-02,-5.29440233E-02,
     &  -8.62785810E-02,-1.30975009E-01,-1.38474545E-01,-1.46792889E-01,
     &  -1.56071724E-01,-1.66487382E-01,-1.78262102E-01,-1.91679987E-01,
     &  -2.07110098E-01,-2.25040693E-01,-2.46131443E-01,-2.71295616E-01,
     &  -3.01834355E-01,-3.39665882E-01,-3.87737729E-01,-4.50816794E-01,
     &  -5.37127077E-01,-6.62097081E-01,-8.58077174E-01,-1.20353597E+00,
     &  -1.90983475E+00,-2.12158630E+00,-2.26993720E+00,-2.41069821E+00,
     &  -2.50094081E+00,-2.54067952E+00,-2.53981277E+00,-2.50660639E+00,
     &  -2.43867024E+00,-2.32771809E+00,-2.16537048E+00,-2.02872149E+00,
     &  -2.00538893E+00,-1.99348699E+00,-1.96920940E+00,-1.95932089E+00,
     &  -1.95183776E+00,-1.94429732E+00,-1.86572581E+00,-1.73700258E+00,
     &  -1.57870383E+00,-1.42277030E+00,-1.23524479E+00,-1.03386229E+00,
     &  -8.42125042E-01,-7.31874461E-01,-6.19327105E-01,-5.04800888E-01,
     &  -3.41786681E-01,-2.23922249E-01,-1.05291164E-01,-3.39028881E-02,
     &  -1.00903160E-02, 1.37253496E-02, 3.75410168E-02, 1.32741916E-01,
     &   2.51373161E-01, 3.69237858E-01, 9.12969085E-01, 1.12309820E+00/
         DATA ((DAS(I,J), I=1301,1400), J=1,1) /
     &   1.48595937E+00, 1.63910051E+00, 1.79420129E+00, 1.93319973E+00,
     &   2.04460279E+00, 2.15352493E+00, 2.23868255E+00, 2.31974161E+00,
     &   2.38123756E+00, 2.43777054E+00, 2.47887899E+00, 2.51467825E+00,
     &   2.53884639E+00, 2.56819272E+00, 2.57353505E+00, 2.57301783E+00,
     &   2.56817671E+00, 2.54664274E+00, 2.53024480E+00, 2.49835024E+00,
     &   1.54042780E+00, 1.04254998E+00, 7.82003910E-01, 6.25021988E-01,
     &   5.20741347E-01, 4.46626060E-01, 3.91309805E-01, 3.48474280E-01,
     &   3.14337551E-01, 2.86501230E-01, 2.63372363E-01, 2.43852204E-01,
     &   2.27158684E-01, 2.12720165E-01, 2.00109213E-01, 1.88999879E-01,
     &   1.79139299E-01, 1.70328313E-01, 1.62407940E-01, 1.13806122E-01,
     &   8.04715492E-02, 6.37969689E-02, 5.37903031E-02, 4.71183964E-02,
     &   4.23522982E-02, 3.87774113E-02, 3.59966960E-02, 3.37719109E-02,
     &   3.19514390E-02, 3.04341962E-02, 2.91503162E-02, 2.80497589E-02,
     &   2.70958307E-02, 2.62610384E-02, 2.55243577E-02, 2.48694363E-02,
     &   2.42833644E-02, 2.37558141E-02, 2.03154096E-02, 1.50526360E-02,
     &   1.38950938E-02, 1.24413084E-02, 5.67536370E-03, 5.08489150E-03,
     &   4.40173353E-03, 3.60509172E-03, 2.66400398E-03, 1.53511882E-03,
     &   1.55872301E-04,-1.56763998E-03,-3.78299279E-03,-6.73602581E-03,
     &  -1.08693714E-02,-1.70683124E-02,-2.73979837E-02,-2.91943660E-02,
     &  -3.11537948E-02,-3.33000163E-02,-3.56608100E-02,-3.82697504E-02,
     &  -4.11688021E-02,-4.44088318E-02,-4.80533340E-02,-5.21840511E-02,
     &  -5.69046817E-02,-6.23506659E-02,-6.87045860E-02,-7.62132194E-02,
     &  -8.52449717E-02,-9.62298823E-02, 5.67536370E-03,-1.09965199E-01,
     &  -1.27625760E-01,-1.51175211E-01,-1.84319814E-01,-2.33718627E-01,
     &  -3.15880871E-01,-4.79336310E-01,-9.57679981E-01,-1.13724387E+00/
         DATA ((DAS(I,J), I=1401,1500), J=1,1) /
     &  -1.59081659E+00,-1.92274955E+00,-2.18548239E+00,-2.40526978E+00,
     &  -2.59160118E+00,-2.75078496E+00,-2.88568409E+00,-3.00369215E+00,
     &  -3.10798253E+00,-3.19619852E+00,-3.26715425E+00,-3.32609209E+00,
     &  -3.37237164E+00,-3.40601649E+00,-3.42985966E+00,-3.44077828E+00,
     &  -3.44071375E+00,-3.43003999E+00,-3.40702903E+00,-3.36979788E+00,
     &  -3.32504135E+00,-3.26702748E+00,-3.19439824E+00,-3.10580057E+00,
     &  -2.99992958E+00,-2.89763610E+00,-2.75708787E+00,-2.59633394E+00,
     &  -2.41482482E+00,-2.17662601E+00,-1.91047151E+00,-1.57400776E+00,
     &  -1.15910505E+00, 1.39186751E-02, 1.18694473E+00, 1.60184947E+00,
     &   1.93831542E+00, 2.20447208E+00, 2.44267320E+00, 2.62418438E+00,
     &   2.78494041E+00, 2.92549073E+00, 3.02778595E+00, 3.13365899E+00,
     &   3.22225867E+00, 3.29488986E+00, 3.35290559E+00, 3.39766391E+00,
     &   3.43489704E+00, 3.45790987E+00, 3.46858537E+00, 3.46865153E+00,
     &   3.45773465E+00, 3.43389327E+00, 3.40025005E+00, 3.35397214E+00,
     &   3.29494320E+00, 3.22398904E+00, 3.13577466E+00, 3.03148585E+00,
     &   2.91347929E+00, 2.77858162E+00, 2.61939929E+00, 2.43306932E+00,
     &   2.21328336E+00, 1.95055191E+00, 1.61862035E+00, 1.16504906E+00,
     &   9.85383906E-01, 5.07116153E-01, 3.43687168E-01, 2.61517481E-01,
     &   2.12119892E-01, 1.78979458E-01, 1.55431285E-01, 1.37769857E-01,
     &   1.24036583E-01, 1.13051569E-01, 1.04067036E-01, 9.64917470E-02,
     &   9.01630233E-02, 8.47414542E-02, 8.00461143E-02, 7.59399176E-02,
     &   5.52077635E-02, 4.48931117E-02, 3.86156282E-02, 3.45906361E-02,
     &   3.15599573E-02, 2.93598935E-02, 2.77430404E-02, 2.62874650E-02,
     &   2.51736814E-02, 2.41545460E-02, 2.34143585E-02, 2.27312706E-02,
     &   2.21389915E-02, 1.58078134E-02, 1.42821039E-02, 1.35196533E-02/
         DATA ((DAS(I,J), I=1501,1600), J=1,1) /
     &   1.31930975E-02, 1.29596921E-02, 1.27750108E-02, 1.26223635E-02,
     &   1.24932253E-02, 1.23823552E-02, 1.22868104E-02, 1.22049675E-02,
     &   1.21345198E-02, 1.20743292E-02, 1.20240503E-02, 1.19830376E-02,
     &   1.19505472E-02, 1.19259676E-02, 1.19094788E-02, 1.19009415E-02,
     &   1.18999748E-02, 1.19068278E-02, 1.19214619E-02, 1.19435252E-02,
     &   1.19746672E-02, 1.20130536E-02, 1.20612486E-02, 1.21187107E-02,
     &   1.21872025E-02, 1.22674648E-02, 1.23601418E-02, 1.24657400E-02,
     &   1.25931746E-02, 1.27422378E-02, 1.29181967E-02, 1.31427305E-02,
     &   1.34476635E-02, 1.42286641E-02, 1.50108452E-02, 1.53169390E-02,
     &   1.55426331E-02, 1.57197188E-02, 1.58699196E-02, 1.59984926E-02,
     &   1.61051818E-02, 1.61989605E-02, 1.62803241E-02, 1.63499069E-02,
     &   1.64084422E-02, 1.64577102E-02, 1.64971399E-02, 1.65293584E-02,
     &   1.65524583E-02, 1.65681487E-02, 1.65760695E-02, 1.65761564E-02,
     &   1.65686721E-02, 1.65532635E-02, 1.65297817E-02, 1.64983991E-02,
     &   1.64585261E-02, 1.64094364E-02, 1.63504995E-02, 1.62819967E-02,
     &   1.62009904E-02, 1.61070803E-02, 1.59981135E-02, 1.58713059E-02,
     &   1.57217377E-02, 1.55415938E-02, 1.53161514E-02, 1.50093352E-02,
     &   1.44287666E-02, 1.44101271E-02, 1.42813393E-02, 1.41995278E-02,
     &   1.41399483E-02, 1.40933345E-02, 1.40553419E-02, 1.40235663E-02,
     &   1.39966275E-02, 1.39735377E-02, 1.39537258E-02, 1.39366825E-02,
     &   1.39221460E-02, 1.39098600E-02, 1.38996199E-02, 1.38912994E-02,
     &   1.38848076E-02, 1.38800641E-02, 1.38770101E-02, 1.38756232E-02,
     &   1.38758867E-02, 1.38778061E-02, 1.38814091E-02, 1.38867371E-02,
     &   1.38938435E-02, 1.39028420E-02, 1.39138473E-02, 1.39269967E-02,
     &   1.39425261E-02, 1.39608265E-02, 1.39821096E-02, 1.40072277E-02/
         DATA ((DAS(I,J), I=1601,1700), J=1,1) /
     &   1.40369229E-02, 1.40728606E-02, 1.41181412E-02, 1.41803235E-02,
     &   1.43399202E-02, 1.44817686E-02, 1.45386336E-02, 1.45806552E-02,
     &   1.46147083E-02, 1.46434950E-02, 1.46685056E-02, 1.46904011E-02,
     &   1.47097510E-02, 1.47270282E-02, 1.47423572E-02, 1.47560211E-02,
     &   1.47681748E-02, 1.47788880E-02, 1.47883380E-02, 1.47966029E-02,
     &   1.48036274E-02, 1.48095685E-02, 1.48144602E-02, 1.48182654E-02,
     &   1.48210617E-02, 1.48228382E-02, 1.48236187E-02, 1.48233919E-02,
     &   1.48221539E-02, 1.48199055E-02, 1.48166094E-02, 1.48122536E-02,
     &   1.48067927E-02, 1.48001969E-02, 1.47924121E-02, 1.47833816E-02,
     &   1.47730164E-02, 1.47612926E-02, 1.47480806E-02, 1.47333530E-02,
     &   1.46475883E-02, 1.46443984E-02, 1.46416322E-02, 1.46392683E-02,
     &   1.46373069E-02, 1.46357456E-02, 1.46345786E-02, 1.46337920E-02,
     &   1.46333822E-02, 1.46333428E-02, 1.46336852E-02, 1.46344119E-02,
     &   1.46355230E-02, 1.46370172E-02, 1.46389125E-02, 1.46412170E-02,
     &   1.46439076E-02, 1.46470452E-02, 1.46506480E-02, 1.46546890E-02,
     &   1.46592687E-02, 1.46643078E-02, 1.46699250E-02, 1.46761490E-02,
     &   1.46823112E-02, 1.46899069E-02, 1.46981977E-02, 1.47074757E-02,
     &   1.47178147E-02, 1.47293882E-02, 1.47423900E-02, 1.47573847E-02,
     &   1.47750333E-02, 1.47967451E-02, 1.48259529E-02, 1.48995315E-02,
     &   1.49742675E-02, 1.50046605E-02, 1.50275924E-02, 1.50464932E-02,
     &   1.50627759E-02, 1.50770983E-02, 1.50900428E-02, 1.51017986E-02,
     &   1.51125398E-02, 1.51223299E-02, 1.51314994E-02, 1.51399875E-02,
     &   1.51479127E-02, 1.51553024E-02, 1.51621548E-02, 1.51686023E-02,
     &   1.51745263E-02, 1.51800105E-02, 1.51851723E-02, 1.51898643E-02,
     &   1.51942440E-02, 1.51982680E-02, 1.52019448E-02, 1.52053151E-02/
         DATA ((DAS(I,J), I=1701,1800), J=1,1) /
     &   1.52083792E-02, 1.52111391E-02, 1.52135987E-02, 1.52157817E-02,
     &   1.52176712E-02, 1.52192884E-02, 1.52206456E-02, 1.52217399E-02,
     &   1.52225705E-02, 1.52230827E-02, 1.52232481E-02, 1.52197036E-02,
     &   1.51878090E-02, 1.51514178E-02, 1.51225603E-02, 1.50983499E-02,
     &   1.50793642E-02, 1.50624050E-02, 1.50478492E-02, 1.50334568E-02,
     &   1.50191273E-02, 1.50048219E-02, 1.49885594E-02, 1.49710400E-02,
     &   1.49581445E-02, 1.49452490E-02, 1.49687479E-02, 1.49913527E-02,
     &   1.50115484E-02, 1.50315008E-02, 1.50496974E-02, 1.50679664E-02,
     &   1.50848427E-02, 1.51019618E-02, 1.51186258E-02, 1.51341995E-02,
     &   1.51501494E-02, 1.51651276E-02, 1.51805298E-02, 1.51950434E-02,
     &   1.52100116E-02, 1.52241519E-02, 1.52387670E-02, 1.52525997E-02,
     &   1.52669205E-02, 1.52804943E-02, 1.52939555E-02, 1.53079165E-02,
     &   1.53211703E-02, 1.53349283E-02, 1.53479998E-02, 1.53615782E-02,
     &   1.53744873E-02, 1.53879048E-02, 1.54006674E-02, 1.54139388E-02,
     &   1.54265680E-02, 1.54397058E-02, 1.54527795E-02, 1.54652268E-02,
     &   1.54781815E-02, 1.54905191E-02, 1.55033629E-02, 1.55155976E-02,
     &   1.55283371E-02, 1.55404749E-02, 1.55531159E-02, 1.55651619E-02,
     &   1.55777093E-02, 1.55896679E-02, 1.56015854E-02, 1.56140013E-02,
     &   1.56258371E-02, 1.56381694E-02, 1.56499267E-02, 1.56621785E-02,
     &   1.56738603E-02, 1.56860345E-02, 1.56976433E-02, 1.57097426E-02,
     &   1.57212808E-02, 1.57333075E-02, 1.57452979E-02, 1.57567336E-02,
     &   1.57686545E-02, 1.57789298E-02, 1.57907717E-02, 1.58020674E-02,
     &   1.58138443E-02, 1.58250784E-02, 1.58367916E-02, 1.58479656E-02,
     &   1.58596165E-02, 1.58707316E-02, 1.58823216E-02, 1.58933789E-02,
     &   1.59044084E-02, 1.59159098E-02, 1.59268832E-02, 1.59383265E-02/
         DATA ((DAS(I,J), I=1801,1840), J=1,1) /
     &   1.59492448E-02, 1.59606310E-02, 1.59714953E-02, 1.59828255E-02,
     &   1.59936365E-02, 1.60049116E-02, 1.60156704E-02, 1.60268912E-02,
     &   1.61471354E-02, 1.62643975E-02, 1.62828973E-02, 1.71151703E-02,
     &   1.74938916E-02, 1.84947376E-02, 1.90611478E-02, 1.90887324E-02,
     &   1.98482175E-02, 1.98506299E-02, 2.04207344E-02, 2.04425171E-02,
     &   2.04555474E-02, 2.07392364E-02, 2.09282713E-02, 2.09621712E-02,
     &   2.10175788E-02, 2.10997138E-02, 2.11576795E-02, 2.11940952E-02,
     &   2.15480578E-02, 2.15660113E-02, 2.16708283E-02, 2.16901644E-02,
     &   2.17772584E-02, 2.18117363E-02, 2.18391733E-02, 2.18647794E-02,
     &   2.19392513E-02, 2.20475657E-02, 2.20936158E-02, 2.23982160E-02/
  
         DATA ((DAS(I,J), I=   1, 100), J=2,2) /
     &   7.41922510E-06, 7.89105229E-06, 8.41665587E-06, 9.00905619E-06,
     &   9.71278512E-06, 1.04933378E-05, 1.29190689E-05, 1.20821829E-05,
     &   1.24100130E-05, 1.29266287E-05, 1.28241316E-05, 1.30636448E-05,
     &   1.30733417E-05, 1.31032383E-05, 1.31176630E-05, 1.32551846E-05,
     &   1.36374477E-05, 1.41597102E-05, 1.46145122E-05, 1.52641787E-05,
     &   1.56952178E-05, 1.61226460E-05, 1.63997825E-05, 1.65564329E-05,
     &   1.67161024E-05, 1.69958829E-05, 1.76044478E-05, 1.79283952E-05,
     &   1.80946239E-05, 1.85506593E-05, 1.89388638E-05, 1.92481473E-05,
     &   1.97661115E-05, 2.02534853E-05, 2.07269790E-05, 2.11983155E-05,
     &   2.16901138E-05, 2.23144308E-05, 2.29925058E-05, 2.37465237E-05,
     &   2.44255899E-05, 2.52830387E-05, 2.62620614E-05, 2.71408528E-05,
     &   2.84881873E-05, 3.03428099E-05, 3.18380604E-05, 3.27319873E-05,
     &   3.29840133E-05, 3.32572344E-05, 3.96512717E-05, 4.71705743E-05,
     &   5.39797807E-05, 5.56816639E-05, 6.04315678E-05, 6.16361307E-05,
     &   5.76699102E-05, 5.52184736E-05, 5.50732192E-05, 5.64330473E-05,
     &   5.90435169E-05, 5.99574642E-05, 6.22785678E-05, 6.59962154E-05,
     &   7.06901564E-05, 7.67434536E-05, 8.32598080E-05, 9.12095013E-05,
     &   9.39510208E-05, 9.89905667E-05, 1.04763198E-04, 1.06276630E-04,
     &   1.13187221E-04, 1.18743043E-04, 1.24591540E-04, 1.26554239E-04,
     &   1.25411917E-04, 1.24687300E-04, 1.25559360E-04, 1.63350889E-04,
     &   1.64659452E-04, 1.75952479E-04, 1.85564909E-04, 1.95656702E-04,
     &   2.13875099E-04, 2.51475895E-04, 2.83130252E-04, 3.06424486E-04,
     &   3.27508169E-04, 3.45835064E-04, 3.61512504E-04, 3.92457930E-04,
     &   4.48312678E-04, 5.36645865E-04, 7.00879701E-04, 8.07371770E-04,
     &   6.63581208E-04, 5.83857069E-04, 5.18433687E-04, 4.80976869E-04/
  
         DATA ((DAS(I,J), I= 101, 200), J=2,2) /
     &   4.57300373E-04, 4.40967980E-04, 4.28724070E-04, 4.18657024E-04,
     &   4.13234214E-04, 4.06790301E-04, 3.98770171E-04, 3.89095710E-04,
     &   3.77594948E-04, 3.64259162E-04, 3.48879559E-04, 3.30958752E-04,
     &   3.10247671E-04, 2.86154543E-04, 2.57896372E-04, 2.23873966E-04,
     &   1.81648318E-04, 1.31165548E-04, 2.01296577E-04, 2.45019335E-04,
     &   2.79174487E-04, 3.07142861E-04, 3.30804275E-04, 3.51153612E-04,
     &   3.68641145E-04, 3.83577892E-04, 3.96465348E-04, 4.07569474E-04,
     &   4.16938307E-04, 4.24588766E-04, 4.30793409E-04, 4.35550085E-04,
     &   4.38944050E-04, 4.40968783E-04, 4.41697217E-04, 4.41136163E-04,
     &   4.39334820E-04, 4.36369571E-04, 4.33812752E-04, 4.30702911E-04,
     &   4.27087203E-04, 4.20531758E-04, 4.12702907E-04, 4.03455814E-04,
     &   3.92774429E-04, 3.80527512E-04, 3.66480115E-04, 3.50741174E-04,
     &   3.32625110E-04, 3.12185025E-04, 2.88900056E-04, 2.63672681E-04,
     &   2.58211080E-04, 2.44666829E-04, 2.32761031E-04, 2.21124750E-04,
     &   2.06538280E-04, 1.87933814E-04, 1.92616181E-04, 1.81785181E-04,
     &   1.73841280E-04, 1.65854772E-04, 1.65022941E-04, 1.56929181E-04,
     &   1.50450439E-04, 1.45048294E-04, 1.40569191E-04, 1.38305793E-04,
     &   1.26741910E-04, 1.17667194E-04, 1.11213620E-04, 1.06996318E-04,
     &   1.03343996E-04, 1.00721694E-04, 9.89567381E-05, 9.80241353E-05,
     &   9.74540762E-05, 9.72623160E-05, 9.76857314E-05, 9.80509167E-05,
     &   9.90544341E-05, 9.95959845E-05, 1.01154083E-04, 1.02883464E-04,
     &   1.05285433E-04, 1.07452751E-04, 1.10378319E-04, 1.12984046E-04,
     &   1.16329170E-04, 1.21189761E-04, 1.24738418E-04, 1.27391307E-04,
     &   1.34244668E-04, 1.37659854E-04, 1.36737428E-04, 1.39288593E-04,
     &   1.44044879E-04, 1.50490229E-04, 1.57436224E-04, 1.68827425E-04/
  
         DATA ((DAS(I,J), I= 201, 300), J=2,2) /
     &   1.76357559E-04, 1.81251176E-04, 1.83351921E-04, 1.85666394E-04,
     &   1.88203633E-04, 1.90967970E-04, 1.93961483E-04, 1.97172045E-04,
     &   2.00586763E-04, 2.04247682E-04, 2.08160381E-04, 2.12330990E-04,
     &   2.16764306E-04, 2.21421290E-04, 2.26321446E-04, 2.31486161E-04,
     &   2.36725422E-04, 2.42145271E-04, 2.47820539E-04, 2.53771725E-04,
     &   2.60041505E-04, 2.66700925E-04, 2.73861960E-04, 2.81687056E-04,
     &   2.90407354E-04, 3.00347708E-04, 3.11987881E-04, 3.26147125E-04,
     &   3.44712903E-04, 3.76006326E-04, 4.13942358E-04, 4.82441337E-04,
     &   3.96728393E-04, 3.87649984E-04, 3.93989656E-04, 4.04677395E-04,
     &   4.18044943E-04, 4.33669756E-04, 4.51171782E-04, 4.70649288E-04,
     &   4.92284941E-04, 5.16328185E-04, 5.43097824E-04, 5.72996065E-04,
     &   6.06519480E-04, 6.44279917E-04, 6.87030641E-04, 7.35700187E-04,
     &   7.91429797E-04, 8.55609106E-04, 9.29891076E-04, 1.01613198E-03,
     &   1.11616333E-03, 1.23088980E-03, 1.26620364E-03, 1.30244123E-03,
     &   1.33937700E-03, 1.37672595E-03, 1.41404872E-03, 1.45072551E-03,
     &   1.48594572E-03, 1.51861318E-03, 1.54726756E-03, 1.57000036E-03,
     &   1.58435631E-03, 1.58723817E-03, 1.57483773E-03, 1.54263269E-03,
     &   1.48551046E-03, 1.39809956E-03, 1.27539342E-03, 1.11371785E-03,
     &   9.12005326E-04, 6.73254899E-04, 4.06574834E-04, 1.43881371E-04,
     &   2.19125547E-04, 4.91348928E-04, 7.50289645E-04, 9.77532765E-04,
     &   1.16638914E-03, 1.31540600E-03, 1.42666740E-03, 1.50438806E-03,
     &   1.55374052E-03, 1.58001404E-03, 1.58810402E-03, 1.58226343E-03,
     &   1.56603055E-03, 1.54225912E-03, 1.51319824E-03, 1.48058889E-03,
     &   1.44575902E-03, 1.40970838E-03, 1.37318015E-03, 1.33671935E-03,
     &   1.30071938E-03, 1.26545861E-03, 1.23112199E-03, 1.19782418E-03/
  
         DATA ((DAS(I,J), I= 301, 400), J=2,2) /
     &   1.16566088E-03, 1.13467672E-03, 1.10485970E-03, 1.07621860E-03,
     &   9.84896331E-04, 9.06198530E-04, 8.38323088E-04, 7.79522701E-04,
     &   7.28323360E-04, 6.83497181E-04, 6.44038543E-04, 6.09128687E-04,
     &   5.78101692E-04, 5.50415603E-04, 5.25629331E-04, 5.03384935E-04,
     &   4.83394834E-04, 4.65433872E-04, 4.49337091E-04, 4.35006356E-04,
     &   4.24568761E-04, 4.14846312E-04, 4.07981342E-04, 4.06090105E-04,
     &   4.20997082E-04, 5.06706514E-04, 5.06642026E-04, 4.01538632E-04,
     &   3.68395434E-04, 3.48847683E-04, 3.33882150E-04, 3.21303534E-04,
     &   3.10368397E-04, 3.00604141E-04, 2.91745615E-04, 2.83628596E-04,
     &   2.76130690E-04, 2.69166200E-04, 2.62671353E-04, 2.56598555E-04,
     &   2.50911526E-04, 2.45600635E-04, 2.40660409E-04, 2.36009635E-04,
     &   2.31605564E-04, 2.27430798E-04, 2.23517776E-04, 2.19855785E-04,
     &   2.16435340E-04, 2.13247793E-04, 2.10286185E-04, 2.07487216E-04,
     &   2.04733152E-04, 2.02146637E-04, 1.99722879E-04, 1.97350784E-04,
     &   1.91685962E-04, 1.82023862E-04, 1.64140472E-04, 1.53698789E-04,
     &   1.50355445E-04, 1.53484172E-04, 1.50990671E-04, 1.47670847E-04,
     &   1.47736060E-04, 1.47683240E-04, 1.48082752E-04, 1.51378453E-04,
     &   1.52505338E-04, 1.55503820E-04, 1.59652628E-04, 1.59902253E-04,
     &   1.64298121E-04, 1.69760503E-04, 1.72203388E-04, 1.75704664E-04,
     &   1.81719991E-04, 1.88780989E-04, 1.96516565E-04, 2.05362408E-04,
     &   2.10549650E-04, 2.14729294E-04, 2.24629073E-04, 2.36208918E-04,
     &   2.37307201E-04, 2.48659668E-04, 2.62814820E-04, 2.70247038E-04,
     &   2.78631097E-04, 2.96554051E-04, 3.17613816E-04, 3.43307035E-04,
     &   3.51802818E-04, 3.73972133E-04, 3.91195087E-04, 4.10589037E-04,
     &   4.56723110E-04, 5.22003319E-04, 5.30164520E-04, 5.96614460E-04/
  
         DATA ((DAS(I,J), I= 401, 500), J=2,2) /
     &   8.02045022E-04, 7.94105207E-04, 6.58231301E-04, 5.52031144E-04,
     &   5.20354994E-04, 2.59199816E-04, 3.74286258E-04, 4.06414873E-04,
     &   3.90874938E-04, 3.58951978E-04, 3.22397117E-04, 2.83744920E-04,
     &   2.80091479E-04, 2.45712661E-04, 2.40784121E-04, 2.19914421E-04,
     &   2.07585062E-04, 1.73588510E-04, 1.70224404E-04, 1.57820519E-04,
     &   1.57527078E-04, 1.57729546E-04, 1.51408587E-04, 1.42433359E-04,
     &   1.39569693E-04, 1.36004854E-04, 1.35724811E-04, 1.39824827E-04,
     &   1.39901414E-04, 1.37815100E-04, 1.39862520E-04, 1.34766840E-04,
     &   1.35518561E-04, 1.34095733E-04, 1.34514589E-04, 1.30290169E-04,
     &   1.30314484E-04, 1.27085060E-04, 1.28747138E-04, 1.30878533E-04,
     &   1.28627971E-04, 1.30623690E-04, 1.30204078E-04, 1.31554967E-04,
     &   1.47309376E-04, 1.51012557E-04, 1.68274560E-04, 1.73195535E-04,
     &   1.78776431E-04, 1.80426981E-04, 1.91749729E-04, 1.92712965E-04,
     &   1.93521601E-04, 1.99165219E-04, 1.98679258E-04, 1.97766301E-04,
     &   2.04418705E-04, 2.06780748E-04, 2.12842084E-04, 2.15819691E-04,
     &   2.20239953E-04, 2.20394976E-04, 2.22833399E-04, 2.23368595E-04,
     &   2.25501296E-04, 2.29442291E-04, 2.33366170E-04, 2.39736462E-04,
     &   2.52035065E-04, 2.62551369E-04, 2.64772660E-04, 2.88643795E-04,
     &   3.06628234E-04, 3.22634068E-04, 3.25512063E-04, 3.49381351E-04,
     &   3.53532485E-04, 3.58914010E-04, 3.79955995E-04, 4.11233412E-04,
     &   4.16564326E-04, 4.68779631E-04, 4.95477761E-04, 5.12008326E-04,
     &   5.42808555E-04, 5.65680805E-04, 5.70681122E-04, 5.73500990E-04,
     &   5.76219670E-04, 5.78613598E-04, 5.83682920E-04, 5.84594311E-04,
     &   5.89879013E-04, 5.97633586E-04, 6.07960388E-04, 6.13683114E-04,
     &   6.16724970E-04, 7.10605976E-04, 7.64677231E-04, 5.44156758E-04/
  
         DATA ((DAS(I,J), I= 501, 600), J=2,2) /
     &   4.48861218E-04, 3.94125632E-04, 3.60567592E-04, 3.50998151E-04,
     &   3.47537655E-04, 3.15945175E-04, 2.95189279E-04, 2.80544203E-04,
     &   2.72021454E-04, 2.70479454E-04, 2.73677026E-04, 2.82592294E-04,
     &   2.96980605E-04, 3.18266639E-04, 3.53487151E-04, 4.14324526E-04,
     &   5.27100663E-04, 7.72181483E-04, 1.36926706E-03, 6.72688772E-03,
     &   7.40850210E-03, 8.24323221E-03, 9.28915734E-03, 1.06379806E-02,
     &   1.24434766E-02, 1.49847019E-02, 1.88261924E-02, 2.53083595E-02,
     &   3.85769730E-02, 8.09389251E-02, 8.55679297E-02, 9.07565323E-02,
     &   9.66123499E-02, 1.03272361E-01, 1.10913598E-01, 1.19768852E-01,
     &   1.30150333E-01, 1.42486377E-01, 1.57380339E-01, 1.75708784E-01,
     &   1.98792690E-01, 2.28711723E-01, 2.68915915E-01, 2.73702571E-01,
     &   3.80611554E-01, 4.58418519E-01, 5.21102675E-01, 5.75971951E-01,
     &   6.18676081E-01, 6.56493608E-01, 6.87338567E-01, 7.18831697E-01,
     &   7.41186037E-01, 7.62797810E-01, 7.79018350E-01, 7.93693421E-01,
     &   8.03259154E-01, 8.13378074E-01, 8.17005866E-01, 8.20213071E-01,
     &   8.20186450E-01, 8.18027460E-01, 8.10997860E-01, 8.03415070E-01,
     &   7.93200591E-01, 7.80072158E-01, 7.63741500E-01, 7.43920864E-01,
     &   7.20331352E-01, 6.92713170E-01, 6.60837746E-01, 6.24521470E-01,
     &   5.83640614E-01, 5.13678946E-01, 4.61375160E-01, 3.74927296E-01,
     &   2.79970245E-01, 2.67378647E-04, 2.79880255E-01, 3.74842679E-01,
     &   4.61297115E-01, 5.13605790E-01, 5.83575321E-01, 6.24461640E-01,
     &   6.60783463E-01, 6.92664448E-01, 7.20288145E-01, 7.43883079E-01,
     &   7.63709002E-01, 7.80044781E-01, 7.93178150E-01, 8.03397362E-01,
     &   8.10984671E-01, 8.18020643E-01, 8.20183609E-01, 8.20215795E-01,
     &   8.17013696E-01, 8.13389066E-01, 8.03275927E-01, 7.93714091E-01/
  
         DATA ((DAS(I,J), I= 601, 700), J=2,2) /
     &   7.79043695E-01, 7.62827294E-01, 7.41220043E-01, 7.18869606E-01,
     &   6.87381077E-01, 6.56539907E-01, 6.18726325E-01, 5.76025951E-01,
     &   5.21160678E-01, 4.58480227E-01, 3.80676863E-01, 3.12496051E-01,
     &   2.59883031E-01, 2.22112696E-01, 1.93780876E-01, 1.71784275E-01,
     &   1.54231124E-01, 1.39908459E-01, 1.28005045E-01, 1.17958801E-01,
     &   1.09368449E-01, 1.01940088E-01, 9.54536675E-02, 8.97412304E-02,
     &   8.46724047E-02, 8.01444722E-02, 7.60754220E-02, 7.23989927E-02,
     &   6.90610724E-02, 3.61486784E-02, 2.44849450E-02, 1.85160021E-02,
     &   1.48899160E-02, 1.24537455E-02, 1.07044144E-02, 9.38739938E-03,
     &   8.36010761E-03, 7.53644326E-03, 6.86134895E-03, 1.47727927E-03,
     &   7.51895838E-04, 5.99675549E-04, 5.25822462E-04, 5.27231447E-04,
     &   5.78176748E-04, 7.01836378E-04, 9.32948774E-04, 1.01086498E-03,
     &   1.40950274E-03, 2.13145520E-03, 2.92724814E-03, 4.72899529E-03,
     &   6.83251800E-03, 7.18757950E-03, 7.58163953E-03, 8.02148048E-03,
     &   8.51555387E-03, 9.07452729E-03, 9.71206154E-03, 1.04459389E-02,
     &   1.12997439E-02, 1.23054383E-02, 1.35074401E-02, 1.49693430E-02,
     &   1.67855027E-02, 1.91021709E-02, 2.21587899E-02, 2.63760685E-02,
     &   3.25667615E-02, 4.25271789E-02, 6.11408773E-02, 9.05844136E-02,
     &   1.07471062E-01, 1.26032865E-01, 1.72619487E-01, 1.89869792E-01,
     &   2.04385170E-01, 2.16976686E-01, 2.27835833E-01, 2.36989660E-01,
     &   2.45128835E-01, 2.52067951E-01, 2.57287269E-01, 2.62032160E-01,
     &   2.65781804E-01, 2.68513752E-01, 2.70260155E-01, 2.71162434E-01,
     &   2.71160044E-01, 2.70262527E-01, 2.68569421E-01, 2.65902382E-01,
     &   2.62132028E-01, 2.57919510E-01, 2.51738004E-01, 2.45254024E-01,
     &   2.37586755E-01, 2.28657995E-01, 2.16555661E-01, 2.04675775E-01/
  
         DATA ((DAS(I,J), I= 701, 800), J=2,2) /
     &   1.89010233E-01, 1.74024086E-01, 1.51843838E-01, 1.27280582E-01,
     &   9.00801618E-02, 5.73068627E-02, 1.93289846E-02, 5.02014400E-04,
     &   1.92465387E-02, 3.83791447E-02, 9.00026971E-02, 1.27208606E-01,
     &   1.51776765E-01, 1.73962483E-01, 1.88952999E-01, 2.04623824E-01,
     &   2.16508325E-01, 2.28616064E-01, 2.37549423E-01, 2.45221215E-01,
     &   2.51709613E-01, 2.57896106E-01, 2.62112735E-01, 2.65887677E-01,
     &   2.68559070E-01, 2.70256290E-01, 2.71158214E-01, 2.71164211E-01,
     &   2.70266237E-01, 2.68523784E-01, 2.65795838E-01, 2.62050167E-01,
     &   2.57309145E-01, 2.52093266E-01, 2.45157922E-01, 2.37022416E-01,
     &   2.27872060E-01, 2.17016392E-01, 2.04428283E-01, 1.89916205E-01,
     &   1.72669165E-01, 1.52131980E-01, 1.63237799E-01, 1.26088856E-01,
     &   9.06434743E-02, 7.69940556E-02, 4.97529671E-02, 3.66866202E-02,
     &   2.90434733E-02, 2.40333589E-02, 2.04974399E-02, 1.78692434E-02,
     &   1.58393541E-02, 1.42245490E-02, 1.29094570E-02, 1.18178223E-02,
     &   1.08972319E-02, 1.01104680E-02, 9.43037993E-03, 8.83670264E-03,
     &   8.31400348E-03, 7.85031966E-03, 7.43624106E-03, 7.06426039E-03,
     &   2.26727156E-03, 1.80735915E-03, 1.61521312E-03, 1.50987505E-03,
     &   1.44213495E-03, 1.39501190E-03, 1.35993649E-03, 1.33276406E-03,
     &   1.31094734E-03, 1.29282726E-03, 1.27744593E-03, 1.26403259E-03,
     &   1.25208737E-03, 1.24124793E-03, 1.23118386E-03, 1.22171975E-03,
     &   1.21264720E-03, 1.20380020E-03, 1.19514066E-03, 1.18650488E-03,
     &   1.17781287E-03, 1.16901873E-03, 1.16005410E-03, 1.15084455E-03,
     &   1.14132336E-03, 1.13142796E-03, 1.12111557E-03, 1.11029804E-03,
     &   1.09889241E-03, 1.08677376E-03, 1.07383007E-03, 1.05982034E-03,
     &   1.04432361E-03, 1.02632067E-03, 9.95204931E-04, 9.83041509E-04/
  
         DATA ((DAS(I,J), I= 801, 900), J=2,2) /
     &   9.82879124E-04, 9.84164444E-04, 9.85898727E-04, 9.87698696E-04,
     &   9.89353882E-04, 9.90760202E-04, 9.91828509E-04, 9.92514760E-04,
     &   9.92763836E-04, 9.92557189E-04, 9.91838515E-04, 9.90612653E-04,
     &   9.88836429E-04, 9.86493813E-04, 9.83516209E-04, 9.79903840E-04,
     &   9.75643557E-04, 9.70645186E-04, 9.64884200E-04, 9.58342593E-04,
     &   9.50889347E-04, 9.42519686E-04, 9.33143981E-04, 9.22574542E-04,
     &   9.10795249E-04, 8.97498371E-04, 8.82519806E-04, 8.65575478E-04,
     &   8.46059139E-04, 8.23986966E-04, 7.97507429E-04, 7.63769993E-04,
     &   7.17549707E-04, 7.04394236E-04, 6.65869375E-04, 6.13341682E-04,
     &   6.08531368E-04, 5.75592337E-04, 5.64758655E-04, 5.57188960E-04,
     &   5.46678954E-04, 5.36592676E-04, 5.29376005E-04, 5.25631390E-04,
     &   5.21784057E-04, 5.16735129E-04, 5.07689417E-04, 5.04900295E-04,
     &   4.87712576E-04, 4.68716340E-04, 4.68776734E-04, 4.55036432E-04,
     &   4.42286593E-04, 4.42030961E-04, 4.39817415E-04, 4.44637963E-04,
     &   4.59857290E-04, 5.04909184E-04, 4.29363630E-04, 3.92039908E-04,
     &   4.01337945E-04, 4.10864902E-04, 4.27158669E-04, 4.25074578E-04,
     &   4.13767637E-04, 4.13629877E-04, 4.09771909E-04, 3.94511190E-04,
     &   3.86564579E-04, 3.66557842E-04, 3.63249574E-04, 3.63838756E-04,
     &   3.55854712E-04, 3.50325720E-04, 3.46669218E-04, 3.38694587E-04,
     &   3.32407142E-04, 3.29801808E-04, 3.29102493E-04, 3.28304312E-04,
     &   3.28448658E-04, 3.26788323E-04, 3.24798748E-04, 3.22286697E-04,
     &   3.22380323E-04, 3.23840346E-04, 3.22244710E-04, 3.13879162E-04,
     &   3.08823278E-04, 3.06814961E-04, 3.05433845E-04, 3.04580500E-04,
     &   3.03545719E-04, 3.03353010E-04, 3.02131591E-04, 2.99065794E-04,
     &   2.97659739E-04, 2.96305706E-04, 2.94992458E-04, 2.92866494E-04/
  
         DATA ((DAS(I,J), I= 901,1000), J=2,2) /
     &   2.91747769E-04, 2.91144396E-04, 2.90997809E-04, 2.91006913E-04,
     &   2.93003323E-04, 2.88742083E-04, 2.85629893E-04, 2.85171848E-04,
     &   2.84831626E-04, 2.83396853E-04, 2.83430271E-04, 2.84573421E-04,
     &   2.80971738E-04, 2.84687779E-04, 2.92585465E-04, 2.80459169E-04,
     &   2.79563599E-04, 2.75972286E-04, 2.75858910E-04, 2.79843996E-04,
     &   2.73489520E-04, 2.71964882E-04, 2.70568977E-04, 2.69489694E-04,
     &   2.67113939E-04, 2.68433508E-04, 2.68418738E-04, 2.68105021E-04,
     &   2.66493628E-04, 2.67460640E-04, 2.68133102E-04, 2.64760278E-04,
     &   2.64532079E-04, 2.64492416E-04, 2.60811927E-04, 2.61119712E-04,
     &   2.62028012E-04, 2.61104439E-04, 2.61941825E-04, 2.63251517E-04,
     &   2.58221924E-04, 2.57836483E-04, 2.57767877E-04, 2.63242858E-04,
     &   2.60859275E-04, 2.60469334E-04, 2.58869401E-04, 2.63533629E-04,
     &   2.72159310E-04, 2.77168268E-04, 2.72239376E-04, 2.71951447E-04,
     &   2.75786718E-04, 2.73349215E-04, 2.76146765E-04, 2.86332213E-04,
     &   3.01520744E-04, 2.89883856E-04, 3.10394980E-04, 3.26869841E-04,
     &   2.95953812E-04, 2.91186870E-04, 2.89034479E-04, 3.04559675E-04,
     &   3.06884310E-04, 3.37136678E-04, 3.39977562E-04, 3.89333550E-04,
     &   4.54498836E-04, 4.85240934E-04, 6.00990398E-04, 6.94372946E-04,
     &   6.88423675E-04, 5.84021924E-04, 4.83151876E-04, 3.95041996E-04,
     &   3.69774169E-04, 3.50337930E-04, 3.21960467E-04, 3.01927782E-04,
     &   2.93904925E-04, 2.86860524E-04, 2.80616249E-04, 2.75036297E-04,
     &   2.70015133E-04, 2.65466776E-04, 2.61329176E-04, 2.57545482E-04,
     &   2.54070886E-04, 2.50868149E-04, 2.47906035E-04, 2.45158132E-04,
     &   2.42601937E-04, 2.40218151E-04, 2.37990125E-04, 2.35903413E-04,
     &   2.33945420E-04, 2.32105117E-04, 2.30372805E-04, 2.28739923E-04/
  
         DATA ((DAS(I,J), I=1001,1100), J=2,2) /
     &   2.27198893E-04, 2.25742984E-04, 2.24366206E-04, 2.23063217E-04,
     &   2.21829243E-04, 2.20660015E-04, 2.19551715E-04, 2.18500922E-04,
     &   2.17504582E-04, 2.16559964E-04, 2.15664638E-04, 2.14816449E-04,
     &   2.14013495E-04, 2.13254113E-04, 2.12677004E-04, 2.11860519E-04,
     &   2.10626675E-04, 2.09546826E-04, 2.08618423E-04, 2.07842279E-04,
     &   2.07222934E-04, 2.06769306E-04, 2.06495728E-04, 2.06423569E-04,
     &   2.06583780E-04, 2.07020963E-04, 2.07800733E-04, 2.09018936E-04,
     &   2.10828293E-04, 2.13481360E-04, 2.13807979E-04, 2.17438587E-04,
     &   2.23665531E-04, 2.34696470E-04, 2.52800631E-04, 2.60457387E-04,
     &   2.94079852E-04, 3.64521444E-04, 3.99825071E-04, 4.51520703E-04,
     &   4.87126268E-04, 5.32619195E-04, 6.73555340E-04, 9.65100228E-04,
     &   1.74655357E-03, 1.78165323E-03, 1.81824111E-03, 1.85641288E-03,
     &   1.89627264E-03, 1.93793377E-03, 1.98152005E-03, 2.02716686E-03,
     &   2.07502255E-03, 2.12525009E-03, 2.17802885E-03, 2.23355676E-03,
     &   2.29205275E-03, 2.35375963E-03, 2.41894744E-03, 2.48791734E-03,
     &   2.56100626E-03, 2.63859237E-03, 2.72110158E-03, 2.80901532E-03,
     &   2.90287990E-03, 3.00331782E-03, 3.11104149E-03, 3.22687014E-03,
     &   3.35175059E-03, 3.48678306E-03, 3.63325359E-03, 3.79267501E-03,
     &   3.96683917E-03, 4.15788446E-03, 4.36838376E-03, 4.60146073E-03,
     &   4.86094555E-03, 5.15158655E-03, 5.47934295E-03, 5.85179702E-03,
     &   6.27874703E-03, 6.77308054E-03, 7.35209593E-03, 8.03956575E-03,
     &   8.86907771E-03, 9.88968213E-03, 1.11759449E-02, 1.28470125E-02,
     &   1.51057661E-02, 1.83280009E-02, 2.32962683E-02, 3.19528409E-02,
     &   5.07946800E-02, 6.24809865E-02, 1.19103643E-01, 1.65908981E-01,
     &   1.99961151E-01, 2.26409707E-01, 2.48226339E-01, 2.67399929E-01/
  
         DATA ((DAS(I,J), I=1101,1200), J=2,2) /
     &   2.85278479E-01, 2.97789785E-01, 3.10597936E-01, 3.23293582E-01,
     &   3.29464404E-01, 3.38195480E-01, 3.43498986E-01, 3.50233038E-01,
     &   3.52045691E-01, 3.54860357E-01, 3.56314351E-01, 3.56056785E-01,
     &   3.55167154E-01, 3.53698716E-01, 3.48754075E-01, 3.45176835E-01,
     &   3.40717739E-01, 3.29045914E-01, 3.21716099E-01, 3.13285892E-01,
     &   3.03586941E-01, 2.80680463E-01, 2.67146514E-01, 2.52421782E-01,
     &   2.18790803E-01, 2.00098343E-01, 1.58819650E-01, 1.13208214E-01,
     &   1.21011807E-02, 1.11708181E-01, 1.57441128E-01, 1.98664478E-01,
     &   2.35121892E-01, 2.51441575E-01, 2.66250811E-01, 2.79734173E-01,
     &   3.02936081E-01, 3.12615903E-01, 3.21213666E-01, 3.28611450E-01,
     &   3.40407124E-01, 3.44879378E-01, 3.48549938E-01, 3.53565132E-01,
     &   3.55091519E-01, 3.56414277E-01, 3.56334452E-01, 3.54929059E-01,
     &   3.52170338E-01, 3.48326577E-01, 3.43658416E-01, 3.38371745E-01,
     &   3.29657243E-01, 3.23525764E-01, 3.10802800E-01, 2.98026440E-01,
     &   2.85476131E-01, 2.67584972E-01, 2.48394448E-01, 2.26556480E-01,
     &   2.00081343E-01, 1.65996518E-01, 1.18464184E-01, 6.46063860E-02,
     &   3.69459769E-02, 2.58488697E-02, 1.98750195E-02, 1.61434960E-02,
     &   1.35917508E-02, 1.17368344E-02, 1.03276962E-02, 9.22093475E-03,
     &   8.32869149E-03, 7.59413659E-03, 6.97888337E-03, 6.45606865E-03,
     &   6.00633074E-03, 5.61536200E-03, 5.27236086E-03, 4.96901991E-03,
     &   4.69884533E-03, 4.45668759E-03, 4.23841077E-03, 4.04065483E-03,
     &   3.86066183E-03, 3.69614688E-03, 3.54520086E-03, 3.40621624E-03,
     &   3.27782978E-03, 3.15887782E-03, 3.04836109E-03, 2.94541659E-03,
     &   2.84929521E-03, 2.75934349E-03, 2.67498886E-03, 2.59572747E-03,
     &   2.52111420E-03, 2.45075434E-03, 2.38429664E-03, 2.32142752E-03/
  
         DATA ((DAS(I,J), I=1201,1300), J=2,2) /
     &   2.26186612E-03, 2.20536014E-03, 2.15168233E-03, 2.10062743E-03,
     &   2.05200959E-03, 2.00566012E-03, 1.96142553E-03, 1.91916591E-03,
     &   1.87875343E-03, 1.84007104E-03, 1.80301141E-03, 1.76747590E-03,
     &   1.73337372E-03, 1.00636560E-03, 8.54830531E-04, 7.10659573E-04,
     &   5.10647195E-04, 3.07837416E-04, 2.77827999E-04, 2.76927122E-04,
     &   3.18991210E-04, 1.09122610E-03, 2.26689751E-03, 2.38503894E-03,
     &   2.51638720E-03, 2.66327109E-03, 2.82860160E-03, 3.01606701E-03,
     &   3.23040939E-03, 3.47782982E-03, 3.76659657E-03, 4.10798453E-03,
     &   4.51777845E-03, 5.01877814E-03, 5.64518241E-03, 6.45072995E-03,
     &   7.52497960E-03, 9.02912113E-03, 1.12854799E-02, 1.50459094E-02,
     &   2.25643055E-02, 3.26458889E-02, 3.43374894E-02, 3.62137870E-02,
     &   3.83067409E-02, 4.06561258E-02, 4.33120717E-02, 4.63386635E-02,
     &   4.98191493E-02, 5.38636648E-02, 5.86210106E-02, 6.42971910E-02,
     &   7.11857026E-02, 7.97192350E-02, 9.05626579E-02, 1.04791231E-01,
     &   1.24260028E-01, 1.52449228E-01, 1.96656044E-01, 2.74580499E-01,
     &   4.33898972E-01, 4.81663372E-01, 5.15126610E-01, 5.46877807E-01,
     &   5.67233663E-01, 5.76197448E-01, 5.76001937E-01, 5.68511636E-01,
     &   5.53187403E-01, 5.28160130E-01, 4.91539681E-01, 4.60716022E-01,
     &   4.55452940E-01, 4.52768241E-01, 4.47291990E-01, 4.45061457E-01,
     &   4.43373501E-01, 4.41672618E-01, 4.23949388E-01, 3.94913531E-01,
     &   3.59206379E-01, 3.24032745E-01, 2.81732971E-01, 2.36307510E-01,
     &   1.93057717E-01, 1.68188717E-01, 1.42801647E-01, 1.16968223E-01,
     &   8.01975216E-02, 5.36112393E-02, 2.68523900E-02, 1.07511110E-02,
     &   5.38248901E-03, 2.42822814E-04, 5.37258939E-03, 2.68424922E-02,
     &   5.36013774E-02, 8.01877194E-02, 2.02835957E-01, 2.50234369E-01/
  
         DATA ((DAS(I,J), I=1301,1400), J=2,2) /
     &   3.32084271E-01, 3.66628031E-01, 4.01613824E-01, 4.32967443E-01,
     &   4.58096423E-01, 4.82665789E-01, 5.01874635E-01, 5.20158977E-01,
     &   5.34030505E-01, 5.46782544E-01, 5.56055302E-01, 5.64130476E-01,
     &   5.69582038E-01, 5.76201637E-01, 5.77406696E-01, 5.77290027E-01,
     &   5.76198027E-01, 5.71340649E-01, 5.67641795E-01, 5.60447399E-01,
     &   3.44370632E-01, 2.32065294E-01, 1.73294449E-01, 1.37884379E-01,
     &   1.14362041E-01, 9.76440474E-02, 8.51665167E-02, 7.55042417E-02,
     &   6.78041381E-02, 6.15252063E-02, 5.63081263E-02, 5.19050558E-02,
     &   4.81395853E-02, 4.48827711E-02, 4.20381979E-02, 3.95323421E-02,
     &   3.73081653E-02, 3.53207435E-02, 3.35342158E-02, 2.25717334E-02,
     &   1.50533416E-02, 1.12929157E-02, 9.03656140E-03, 7.53242576E-03,
     &   6.45818376E-03, 5.65264599E-03, 5.02625402E-03, 4.52526961E-03,
     &   4.11549452E-03, 3.77412962E-03, 3.48536445E-03, 3.23793407E-03,
     &   3.02357781E-03, 2.83609412E-03, 2.67074045E-03, 2.52382803E-03,
     &   2.39244520E-03, 2.27426248E-03, 1.50669968E-03, 4.13225908E-04,
     &   3.06616918E-04, 3.82937177E-04, 1.36594356E-03, 1.45997829E-03,
     &   1.56874441E-03, 1.69591903E-03, 1.84652583E-03, 2.02760166E-03,
     &   2.24930039E-03, 2.52686184E-03, 2.88423597E-03, 3.36132020E-03,
     &   4.02994928E-03, 5.03379555E-03, 6.70800943E-03, 6.99927012E-03,
     &   7.31699151E-03, 7.66502730E-03, 8.04788579E-03, 8.47101588E-03,
     &   8.94122795E-03, 9.46677716E-03, 1.00579681E-02, 1.07280666E-02,
     &   1.14939019E-02, 1.23774547E-02, 1.34083561E-02, 1.46266556E-02,
     &   1.60883617E-02, 1.78748995E-02, 1.36594356E-03, 2.01077644E-02,
     &   2.29776206E-02, 2.68031498E-02, 3.21558595E-02, 4.01766785E-02,
     &   5.35146321E-02, 8.00456109E-02, 1.57679723E-01, 1.86821737E-01/
  
         DATA ((DAS(I,J), I=1401,1500), J=2,2) /
     &   2.60432948E-01, 3.14302735E-01, 3.56941871E-01, 3.92611316E-01,
     &   4.22851150E-01, 4.48685173E-01, 4.70578020E-01, 4.89729607E-01,
     &   5.06654947E-01, 5.20971566E-01, 5.32487011E-01, 5.42052071E-01,
     &   5.49562816E-01, 5.55023072E-01, 5.58892616E-01, 5.60664631E-01,
     &   5.60654189E-01, 5.58921977E-01, 5.55187561E-01, 5.49145355E-01,
     &   5.41881850E-01, 5.32466815E-01, 5.20679852E-01, 5.06301376E-01,
     &   4.89119616E-01, 4.72518446E-01, 4.49708923E-01, 4.23620220E-01,
     &   3.94163162E-01, 3.55505951E-01, 3.12311817E-01, 2.57707221E-01,
     &   1.90372807E-01, 2.73563168E-04, 1.90367487E-01, 2.57702231E-01,
     &   3.12307185E-01, 3.55501668E-01, 3.94159255E-01, 4.23616646E-01,
     &   4.49705690E-01, 4.72515553E-01, 4.89117005E-01, 5.06299099E-01,
     &   5.20677901E-01, 5.32465179E-01, 5.41880516E-01, 5.49144312E-01,
     &   5.55186840E-01, 5.58921558E-01, 5.60654054E-01, 5.60664761E-01,
     &   5.58893028E-01, 5.55023775E-01, 5.49563783E-01, 5.42053304E-01,
     &   5.32488507E-01, 5.20973315E-01, 5.06656954E-01, 4.89731868E-01,
     &   4.70580522E-01, 4.48687908E-01, 4.22854119E-01, 3.92614514E-01,
     &   3.56945293E-01, 3.14306376E-01, 2.60436806E-01, 1.86825805E-01,
     &   1.57667345E-01, 8.00455261E-02, 5.35188862E-02, 4.01798424E-02,
     &   3.21594131E-02, 2.68074338E-02, 2.29819022E-02, 2.01117675E-02,
     &   1.78791703E-02, 1.60926243E-02, 1.46307718E-02, 1.34126297E-02,
     &   1.23817233E-02, 1.14980751E-02, 1.07323226E-02, 1.00622168E-02,
     &   6.71227858E-03, 5.03805969E-03, 4.03427197E-03, 3.36557426E-03,
     &   2.88857564E-03, 2.53121190E-03, 2.25354797E-03, 2.03197822E-03,
     &   1.85091878E-03, 1.70048923E-03, 1.57324010E-03, 1.46445584E-03,
     &   1.37040074E-03, 4.31321391E-04, 3.17537427E-04, 3.46862553E-04/
  
         DATA ((DAS(I,J), I=1501,1600), J=2,2) /
     &   3.84799116E-04, 4.17702299E-04, 4.46822650E-04, 4.72244472E-04,
     &   4.94749776E-04, 5.14507953E-04, 5.31903806E-04, 5.47031020E-04,
     &   5.60132836E-04, 5.71413831E-04, 5.80865664E-04, 5.88543235E-04,
     &   5.94591653E-04, 5.99096249E-04, 6.01987663E-04, 6.03319293E-04,
     &   6.03138566E-04, 6.01377078E-04, 5.98070224E-04, 5.93293305E-04,
     &   5.86691877E-04, 5.78678510E-04, 5.68741247E-04, 5.57016071E-04,
     &   5.43198411E-04, 5.27202135E-04, 5.08988715E-04, 4.88589712E-04,
     &   4.64506834E-04, 4.37184310E-04, 4.06311310E-04, 3.69615970E-04,
     &   3.26267595E-04, 2.71445891E-04, 3.23875383E-04, 3.66838187E-04,
     &   4.03435463E-04, 4.34329034E-04, 4.61732523E-04, 4.85931700E-04,
     &   5.06462450E-04, 5.24821842E-04, 5.40972118E-04, 5.54947090E-04,
     &   5.66829059E-04, 5.76923327E-04, 5.85088219E-04, 5.91843353E-04,
     &   5.96764219E-04, 6.00212676E-04, 6.02110713E-04, 6.02417789E-04,
     &   6.01203048E-04, 5.98420216E-04, 5.94011422E-04, 5.88043501E-04,
     &   5.80429744E-04, 5.71020210E-04, 5.59755732E-04, 5.46754150E-04,
     &   5.31451394E-04, 5.13938877E-04, 4.93986021E-04, 4.71162974E-04,
     &   4.45246661E-04, 4.15296918E-04, 3.80937654E-04, 3.39588798E-04,
     &   2.88405340E-04, 2.87486268E-04, 2.79386736E-04, 2.76786418E-04,
     &   2.76141995E-04, 2.76096397E-04, 2.76042739E-04, 2.76322180E-04,
     &   2.76849705E-04, 2.77416896E-04, 2.77955134E-04, 2.78377780E-04,
     &   2.78665996E-04, 2.78871779E-04, 2.78931160E-04, 2.78879016E-04,
     &   2.78672615E-04, 2.78255163E-04, 2.77684995E-04, 2.76924005E-04,
     &   2.75986287E-04, 2.74871599E-04, 2.73562044E-04, 2.72017052E-04,
     &   2.70270177E-04, 2.68308723E-04, 2.66125132E-04, 2.63718359E-04,
     &   2.61079951E-04, 2.58197004E-04, 2.55012363E-04, 2.51544006E-04/
  
         DATA ((DAS(I,J), I=1601,1700), J=2,2) /
     &   2.47887938E-04, 2.43343826E-04, 2.38470355E-04, 2.33369428E-04,
     &   2.26253470E-04, 2.28979176E-04, 2.32161718E-04, 2.35130249E-04,
     &   2.38189361E-04, 2.41045870E-04, 2.43534491E-04, 2.45928294E-04,
     &   2.48224956E-04, 2.50361109E-04, 2.52363458E-04, 2.54245692E-04,
     &   2.56002428E-04, 2.57625067E-04, 2.59124611E-04, 2.60504787E-04,
     &   2.61746290E-04, 2.62871237E-04, 2.63882222E-04, 2.64769893E-04,
     &   2.65528693E-04, 2.66163125E-04, 2.66696825E-04, 2.67127982E-04,
     &   2.67469360E-04, 2.67709347E-04, 2.67830439E-04, 2.67860499E-04,
     &   2.67844922E-04, 2.67813834E-04, 2.67782577E-04, 2.67806508E-04,
     &   2.67988701E-04, 2.67351390E-04, 2.66040107E-04, 2.64577896E-04,
     &   2.59911865E-04, 2.59797369E-04, 2.59659160E-04, 2.59493004E-04,
     &   2.59290523E-04, 2.59049330E-04, 2.58775240E-04, 2.58464588E-04,
     &   2.58113130E-04, 2.57112306E-04, 2.56085548E-04, 2.55084630E-04,
     &   2.54096278E-04, 2.53102939E-04, 2.52087134E-04, 2.51051912E-04,
     &   2.50004143E-04, 2.48920007E-04, 2.47796561E-04, 2.46635993E-04,
     &   2.45417131E-04, 2.44171256E-04, 2.42880228E-04, 2.41527649E-04,
     &   2.40084702E-04, 2.38646704E-04, 2.37113590E-04, 2.35571455E-04,
     &   2.33753820E-04, 2.31877697E-04, 2.29984570E-04, 2.28085460E-04,
     &   2.25884319E-04, 2.23522382E-04, 2.21095458E-04, 2.17773371E-04,
     &   2.18495986E-04, 2.19881753E-04, 2.21465334E-04, 2.23026734E-04,
     &   2.24368143E-04, 2.25769765E-04, 2.27198874E-04, 2.28605454E-04,
     &   2.29756220E-04, 2.30926978E-04, 2.32013339E-04, 2.33086279E-04,
     &   2.34115678E-04, 2.35092826E-04, 2.36033533E-04, 2.36947668E-04,
     &   2.37808600E-04, 2.38621286E-04, 2.39412295E-04, 2.40157221E-04,
     &   2.40880939E-04, 2.41578047E-04, 2.42242064E-04, 2.42884211E-04/
  
         DATA ((DAS(I,J), I=1701,1800), J=2,2) /
     &   2.43519273E-04, 2.44154964E-04, 2.44770177E-04, 2.45084513E-04,
     &   2.45418392E-04, 2.45796013E-04, 2.46254577E-04, 2.46836746E-04,
     &   2.47378777E-04, 2.47154367E-04, 2.46891442E-04, 2.45278535E-04,
     &   2.44543765E-04, 2.45928589E-04, 2.49485737E-04, 2.55522257E-04,
     &   2.63088828E-04, 2.72585585E-04, 2.83049736E-04, 2.95262694E-04,
     &   3.08868449E-04, 3.23253633E-04, 3.40064325E-04, 3.58127858E-04,
     &   3.65317452E-04, 3.72507045E-04, 3.58352976E-04, 3.45729057E-04,
     &   3.35272443E-04, 3.25687174E-04, 3.17568595E-04, 3.09988289E-04,
     &   3.03467084E-04, 2.97296675E-04, 2.91693655E-04, 2.86793605E-04,
     &   2.82089692E-04, 2.77942868E-04, 2.73933308E-04, 2.70375476E-04,
     &   2.66914959E-04, 2.63827580E-04, 2.60809628E-04, 2.58104638E-04,
     &   2.55449159E-04, 2.53059566E-04, 2.50804486E-04, 2.48578806E-04,
     &   2.46565896E-04, 2.44573123E-04, 2.42765626E-04, 2.40971313E-04,
     &   2.39339602E-04, 2.37715809E-04, 2.36235712E-04, 2.34759522E-04,
     &   2.33411111E-04, 2.32063540E-04, 2.30775408E-04, 2.29595408E-04,
     &   2.28412911E-04, 2.27327835E-04, 2.26238689E-04, 2.25237703E-04,
     &   2.24231445E-04, 2.23305292E-04, 2.22372955E-04, 2.21513676E-04,
     &   2.20647532E-04, 2.19848251E-04, 2.19076077E-04, 2.18296341E-04,
     &   2.17575553E-04, 2.16846899E-04, 2.16172607E-04, 2.15490248E-04,
     &   2.14858158E-04, 2.14217878E-04, 2.13624201E-04, 2.13022276E-04,
     &   2.12463660E-04, 2.11896786E-04, 2.11346671E-04, 2.10835488E-04,
     &   2.10316107E-04, 2.09820163E-04, 2.09328979E-04, 2.08871859E-04,
     &   2.08406715E-04, 2.07973521E-04, 2.07532417E-04, 2.07121332E-04,
     &   2.06702464E-04, 2.06311848E-04, 2.05913583E-04, 2.05541952E-04,
     &   2.05179105E-04, 2.04808824E-04, 2.04463003E-04, 2.04109897E-04/
  
         DATA ((DAS(I,J), I=1801,1840), J=2,2) /
     &   2.03779935E-04, 2.03442838E-04, 2.03127668E-04, 2.02805516E-04,
     &   2.02504166E-04, 2.02195986E-04, 2.01907564E-04, 2.01612464E-04,
     &   1.98775773E-04, 1.96481402E-04, 1.96154285E-04, 1.86997147E-04,
     &   1.84728708E-04, 1.80964202E-04, 1.79620100E-04, 1.79563967E-04,
     &   1.78272840E-04, 1.78269407E-04, 1.77548633E-04, 1.77524417E-04,
     &   1.77510036E-04, 1.77215360E-04, 1.77037025E-04, 1.77006451E-04,
     &   1.76957361E-04, 1.76886553E-04, 1.76837950E-04, 1.76807980E-04,
     &   1.76537902E-04, 1.76525170E-04, 1.76452571E-04, 1.76439496E-04,
     &   1.76381792E-04, 1.76359477E-04, 1.76341928E-04, 1.76325715E-04,
     &   1.76279454E-04, 1.76214472E-04, 1.76187645E-04, 1.76021283E-04/
C      
      save
      RETURN
      END

       subroutine dalhad_timelike1
       IMPLICIT NONE
       INTEGER NC,I,J
       PARAMETER(NC=200)
       REAL EMA(NC),DAM(NC,2)
       COMMON /DATM/EMA,DAM
  
       DATA  (EMA(I), I=   1, 100) /
     &   1.3005E+01, 1.3500E+01, 1.4000E+01, 1.4500E+01, 1.5000E+01,
     &   1.6000E+01, 1.7000E+01, 1.8000E+01, 1.9000E+01, 2.0000E+01,
     &   2.1000E+01, 2.2000E+01, 2.3000E+01, 2.4000E+01, 2.5000E+01,
     &   2.6000E+01, 2.7000E+01, 2.8000E+01, 2.9000E+01, 3.0000E+01,
     &   3.1000E+01, 3.2000E+01, 3.3000E+01, 3.4000E+01, 3.5000E+01,
     &   3.6000E+01, 3.7000E+01, 3.8000E+01, 3.9000E+01, 4.0000E+01,
     &   4.1000E+01, 4.2000E+01, 4.3000E+01, 4.4000E+01, 4.5000E+01,
     &   4.6000E+01, 4.7000E+01, 4.8000E+01, 4.9000E+01, 5.0000E+01,
     &   5.1000E+01, 5.2000E+01, 5.3000E+01, 5.4000E+01, 5.5000E+01,
     &   5.6000E+01, 5.7000E+01, 5.8000E+01, 5.9000E+01, 6.0000E+01,
     &   6.1000E+01, 6.2000E+01, 6.3000E+01, 6.4000E+01, 6.5000E+01,
     &   6.6000E+01, 6.7000E+01, 6.8000E+01, 6.9000E+01, 7.0000E+01,
     &   7.1000E+01, 7.2000E+01, 7.3000E+01, 7.4000E+01, 7.5000E+01,
     &   7.6000E+01, 7.7000E+01, 7.8000E+01, 7.9000E+01, 8.0000E+01,
     &   8.1000E+01, 8.2000E+01, 8.3000E+01, 8.4000E+01, 8.5000E+01,
     &   8.6000E+01, 8.7000E+01, 8.8000E+01, 8.9000E+01, 9.0000E+01,
     &   9.1000E+01, 9.2000E+01, 9.3000E+01, 9.4000E+01, 9.5000E+01,
     &   9.6000E+01, 9.7000E+01, 9.8000E+01, 9.9000E+01, 1.0000E+02,
     &   1.0900E+02, 1.1800E+02, 1.2700E+02, 1.3600E+02, 1.4500E+02,
     &   1.5400E+02, 1.6300E+02, 1.7200E+02, 1.8100E+02, 1.9000E+02/
  
       DATA  (EMA(I), I= 101, 200) /
     &   1.9900E+02, 2.0800E+02, 2.1700E+02, 2.2600E+02, 2.3500E+02,
     &   2.4400E+02, 2.5300E+02, 2.6200E+02, 2.7100E+02, 2.8000E+02,
     &   2.8900E+02, 2.9800E+02, 3.0700E+02, 3.1600E+02, 3.2500E+02,
     &   3.3400E+02, 3.4300E+02, 3.5200E+02, 3.6100E+02, 3.7000E+02,
     &   3.7900E+02, 3.8800E+02, 3.9700E+02, 4.0600E+02, 4.1500E+02,
     &   4.2400E+02, 4.3300E+02, 4.4200E+02, 4.5100E+02, 4.6000E+02,
     &   4.6900E+02, 4.7800E+02, 4.8700E+02, 4.9600E+02, 5.0500E+02,
     &   5.1400E+02, 5.2300E+02, 5.3200E+02, 5.4100E+02, 5.5000E+02,
     &   5.5900E+02, 5.6800E+02, 5.7700E+02, 5.8600E+02, 5.9500E+02,
     &   6.0400E+02, 6.1300E+02, 6.2200E+02, 6.3100E+02, 6.4000E+02,
     &   6.4900E+02, 6.5800E+02, 6.6700E+02, 6.7600E+02, 6.8500E+02,
     &   6.9400E+02, 7.0300E+02, 7.1200E+02, 7.2100E+02, 7.3000E+02,
     &   7.3900E+02, 7.4800E+02, 7.5700E+02, 7.6600E+02, 7.7500E+02,
     &   7.8400E+02, 7.9300E+02, 8.0200E+02, 8.1100E+02, 8.2000E+02,
     &   8.2900E+02, 8.3800E+02, 8.4700E+02, 8.5600E+02, 8.6500E+02,
     &   8.7400E+02, 8.8300E+02, 8.9200E+02, 9.0100E+02, 9.1000E+02,
     &   9.1900E+02, 9.2800E+02, 9.3700E+02, 9.4600E+02, 9.5500E+02,
     &   9.6400E+02, 9.7300E+02, 9.8200E+02, 9.9100E+02, 1.0000E+03,
     &   2.0000E+03, 3.0000E+03, 4.0000E+03, 5.0000E+03, 6.0000E+03,
     &   8.0000E+03, 1.0000E+04, 1.2000E+04, 1.4000E+04, 2.0000E+04/
  
         DATA ((DAM(I,J), I=   1, 100), J=1,1) /
     &   1.5779E-02, 1.6027E-02, 1.6264E-02, 1.6491E-02, 1.6707E-02,
     &   1.7115E-02, 1.7494E-02, 1.7848E-02, 1.8181E-02, 1.8495E-02,
     &   1.8792E-02, 1.9075E-02, 1.9344E-02, 1.9602E-02, 1.9848E-02,
     &   2.0085E-02, 2.0311E-02, 2.0529E-02, 2.0739E-02, 2.0942E-02,
     &   2.1138E-02, 2.1328E-02, 2.1512E-02, 2.1690E-02, 2.1863E-02,
     &   2.2031E-02, 2.2194E-02, 2.2353E-02, 2.2508E-02, 2.2658E-02,
     &   2.2805E-02, 2.2948E-02, 2.3088E-02, 2.3225E-02, 2.3358E-02,
     &   2.3488E-02, 2.3616E-02, 2.3741E-02, 2.3863E-02, 2.3983E-02,
     &   2.4100E-02, 2.4215E-02, 2.4328E-02, 2.4439E-02, 2.4548E-02,
     &   2.4654E-02, 2.4759E-02, 2.4862E-02, 2.4963E-02, 2.5063E-02,
     &   2.5160E-02, 2.5257E-02, 2.5351E-02, 2.5444E-02, 2.5536E-02,
     &   2.5626E-02, 2.5715E-02, 2.5803E-02, 2.5889E-02, 2.5974E-02,
     &   2.6058E-02, 2.6141E-02, 2.6222E-02, 2.6302E-02, 2.6382E-02,
     &   2.6460E-02, 2.6537E-02, 2.6613E-02, 2.6688E-02, 2.6763E-02,
     &   2.6836E-02, 2.6908E-02, 2.6980E-02, 2.7051E-02, 2.7120E-02,
     &   2.7189E-02, 2.7258E-02, 2.7325E-02, 2.7392E-02, 2.7458E-02,
     &   2.7523E-02, 2.7587E-02, 2.7651E-02, 2.7714E-02, 2.7776E-02,
     &   2.7838E-02, 2.7899E-02, 2.7960E-02, 2.8019E-02, 2.8079E-02,
     &   2.8586E-02, 2.9054E-02, 2.9486E-02, 2.9889E-02, 3.0266E-02,
     &   3.0620E-02, 3.0954E-02, 3.1270E-02, 3.1570E-02, 3.1855E-02/
         DATA ((DAM(I,J), I= 101, 200), J=1,1) /
     &   3.2127E-02, 3.2386E-02, 3.2635E-02, 3.2873E-02, 3.3103E-02,
     &   3.3323E-02, 3.3536E-02, 3.3741E-02, 3.3939E-02, 3.4130E-02,
     &   3.4316E-02, 3.4495E-02, 3.4670E-02, 3.4839E-02, 3.5003E-02,
     &   3.5163E-02, 3.5319E-02, 3.5469E-02, 3.5618E-02, 3.5763E-02,
     &   3.5904E-02, 3.6042E-02, 3.6176E-02, 3.6308E-02, 3.6437E-02,
     &   3.6562E-02, 3.6685E-02, 3.6806E-02, 3.6924E-02, 3.7040E-02,
     &   3.7153E-02, 3.7265E-02, 3.7374E-02, 3.7481E-02, 3.7587E-02,
     &   3.7690E-02, 3.7792E-02, 3.7892E-02, 3.7990E-02, 3.8086E-02,
     &   3.8181E-02, 3.8275E-02, 3.8367E-02, 3.8458E-02, 3.8547E-02,
     &   3.8635E-02, 3.8721E-02, 3.8807E-02, 3.8891E-02, 3.8973E-02,
     &   3.9055E-02, 3.9136E-02, 3.9215E-02, 3.9294E-02, 3.9371E-02,
     &   3.9447E-02, 3.9523E-02, 3.9597E-02, 3.9671E-02, 3.9743E-02,
     &   3.9815E-02, 3.9886E-02, 3.9956E-02, 4.0025E-02, 4.0093E-02,
     &   4.0161E-02, 4.0227E-02, 4.0293E-02, 4.0359E-02, 4.0423E-02,
     &   4.0487E-02, 4.0550E-02, 4.0613E-02, 4.0674E-02, 4.0736E-02,
     &   4.0796E-02, 4.0856E-02, 4.0915E-02, 4.0974E-02, 4.1032E-02,
     &   4.1090E-02, 4.1147E-02, 4.1203E-02, 4.1259E-02, 4.1314E-02,
     &   4.1369E-02, 4.1423E-02, 4.1477E-02, 4.1531E-02, 4.1583E-02,
     &   4.5631E-02, 4.7995E-02, 4.9671E-02, 5.0971E-02, 5.2032E-02,
     &   5.3706E-02, 5.5004E-02, 5.6063E-02, 5.6959E-02, 5.9031E-02/
  
         DATA ((DAM(I,J), I=   1, 100), J=2,2) /
     &   2.0982E-04, 2.0161E-04, 1.9648E-04, 1.9299E-04, 1.9046E-04,
     &   1.8700E-04, 1.8473E-04, 1.8312E-04, 1.8191E-04, 1.8096E-04,
     &   1.8021E-04, 1.7959E-04, 1.7908E-04, 1.7864E-04, 1.7827E-04,
     &   1.7795E-04, 1.7767E-04, 1.7743E-04, 1.7722E-04, 1.7702E-04,
     &   1.7685E-04, 1.7670E-04, 1.7656E-04, 1.7644E-04, 1.7633E-04,
     &   1.7622E-04, 1.7613E-04, 1.7604E-04, 1.7597E-04, 1.7589E-04,
     &   1.7583E-04, 1.7577E-04, 1.7571E-04, 1.7565E-04, 1.7561E-04,
     &   1.7556E-04, 1.7552E-04, 1.7548E-04, 1.7544E-04, 1.7540E-04,
     &   1.7537E-04, 1.7534E-04, 1.7531E-04, 1.7528E-04, 1.7526E-04,
     &   1.7523E-04, 1.7521E-04, 1.7519E-04, 1.7517E-04, 1.7515E-04,
     &   1.7513E-04, 1.7511E-04, 1.7509E-04, 1.7508E-04, 1.7506E-04,
     &   1.7505E-04, 1.7503E-04, 1.7502E-04, 1.7501E-04, 1.7499E-04,
     &   1.7498E-04, 1.7497E-04, 1.7496E-04, 1.7495E-04, 1.7494E-04,
     &   1.7493E-04, 1.7492E-04, 1.7491E-04, 1.7491E-04, 1.7490E-04,
     &   1.7489E-04, 1.7488E-04, 1.7488E-04, 1.7487E-04, 1.7486E-04,
     &   1.7486E-04, 1.7485E-04, 1.7484E-04, 1.7484E-04, 1.7483E-04,
     &   1.7483E-04, 1.7482E-04, 1.7482E-04, 1.7481E-04, 1.7481E-04,
     &   1.7480E-04, 1.7480E-04, 1.7480E-04, 1.7479E-04, 1.7479E-04,
     &   1.7476E-04, 1.7473E-04, 1.7472E-04, 1.7470E-04, 1.7469E-04,
     &   1.7468E-04, 1.7467E-04, 1.7467E-04, 1.7466E-04, 1.7466E-04/
  
         DATA ((DAM(I,J), I= 101, 200), J=2,2) /
     &   1.7465E-04, 1.7465E-04, 1.7465E-04, 1.7465E-04, 1.7464E-04,
     &   1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04,
     &   1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7463E-04,
     &   1.7463E-04, 1.7463E-04, 1.7463E-04, 1.7463E-04, 1.7463E-04,
     &   1.7463E-04, 1.7463E-04, 1.7463E-04, 1.7463E-04, 1.7463E-04,
     &   1.7463E-04, 1.7463E-04, 1.7463E-04, 1.7463E-04, 1.7463E-04,
     &   1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04,
     &   1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04,
     &   1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04,
     &   1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04,
     &   1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04,
     &   1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04,
     &   1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04,
     &   1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04,
     &   1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7464E-04, 1.7465E-04,
     &   1.7465E-04, 1.7465E-04, 1.7465E-04, 1.7465E-04, 1.7465E-04,
     &   1.7465E-04, 1.7465E-04, 1.7465E-04, 1.7465E-04, 1.7465E-04,
     &   1.7465E-04, 1.7465E-04, 1.7465E-04, 1.7465E-04, 1.7465E-04,
     &   1.7466E-04, 1.7467E-04, 1.7468E-04, 1.7469E-04, 1.7469E-04,
     &   1.7470E-04, 1.7470E-04, 1.7470E-04, 1.7471E-04, 1.7471E-04/
C      
      save
      RETURN
      END

       subroutine dalhad_spacelike
       IMPLICIT NONE
       INTEGER NA,I,J
       PARAMETER(NA=977)
       REAL ETA(NA),DAT(NA,2)
       COMMON /DATT/ETA,DAT
  
       DATA  (ETA(I), I=   1, 100) /
     &  -1.0000E+03,-9.9000E+02,-9.8000E+02,-9.7000E+02,-9.6000E+02,
     &  -9.5000E+02,-9.4000E+02,-9.3000E+02,-9.2000E+02,-9.1000E+02,
     &  -9.0000E+02,-8.9000E+02,-8.8000E+02,-8.7000E+02,-8.6000E+02,
     &  -8.5000E+02,-8.4000E+02,-8.3000E+02,-8.2000E+02,-8.1000E+02,
     &  -8.0000E+02,-7.9000E+02,-7.8000E+02,-7.7000E+02,-7.6000E+02,
     &  -7.5000E+02,-7.4000E+02,-7.3000E+02,-7.2000E+02,-7.1000E+02,
     &  -7.0000E+02,-6.9000E+02,-6.8000E+02,-6.7000E+02,-6.6000E+02,
     &  -6.5000E+02,-6.4000E+02,-6.3000E+02,-6.2000E+02,-6.1000E+02,
     &  -6.0000E+02,-5.9000E+02,-5.8000E+02,-5.7000E+02,-5.6000E+02,
     &  -5.5000E+02,-5.4000E+02,-5.3000E+02,-5.2000E+02,-5.1000E+02,
     &  -5.0000E+02,-4.9000E+02,-4.8000E+02,-4.7000E+02,-4.6000E+02,
     &  -4.5000E+02,-4.4000E+02,-4.3000E+02,-4.2000E+02,-4.1000E+02,
     &  -4.0000E+02,-3.9000E+02,-3.8000E+02,-3.7000E+02,-3.6000E+02,
     &  -3.5000E+02,-3.4000E+02,-3.3000E+02,-3.2000E+02,-3.1000E+02,
     &  -3.0000E+02,-2.9000E+02,-2.8000E+02,-2.7000E+02,-2.6000E+02,
     &  -2.5000E+02,-2.4000E+02,-2.3000E+02,-2.2000E+02,-2.1000E+02,
     &  -2.0000E+02,-1.9000E+02,-1.8000E+02,-1.7000E+02,-1.6000E+02,
     &  -1.5000E+02,-1.4000E+02,-1.3000E+02,-1.2000E+02,-1.1000E+02,
     &  -1.0000E+02,-9.9000E+01,-9.8000E+01,-9.7000E+01,-9.6000E+01,
     &  -9.5000E+01,-9.4000E+01,-9.3000E+01,-9.2000E+01,-9.1000E+01/
  
       DATA  (ETA(I), I= 101, 200) /
     &  -9.0000E+01,-8.9000E+01,-8.8000E+01,-8.7000E+01,-8.6000E+01,
     &  -8.5000E+01,-8.4000E+01,-8.3000E+01,-8.2000E+01,-8.1000E+01,
     &  -8.0000E+01,-7.9000E+01,-7.8000E+01,-7.7000E+01,-7.6000E+01,
     &  -7.5000E+01,-7.4000E+01,-7.3000E+01,-7.2000E+01,-7.1000E+01,
     &  -7.0000E+01,-6.9000E+01,-6.8000E+01,-6.7000E+01,-6.6000E+01,
     &  -6.5000E+01,-6.4000E+01,-6.3000E+01,-6.2000E+01,-6.1000E+01,
     &  -6.0000E+01,-5.9000E+01,-5.8000E+01,-5.7000E+01,-5.6000E+01,
     &  -5.5000E+01,-5.4000E+01,-5.3000E+01,-5.2000E+01,-5.1000E+01,
     &  -5.0000E+01,-4.9000E+01,-4.8000E+01,-4.7000E+01,-4.6000E+01,
     &  -4.5000E+01,-4.4000E+01,-4.3000E+01,-4.2000E+01,-4.1000E+01,
     &  -4.0000E+01,-3.9000E+01,-3.8000E+01,-3.7000E+01,-3.6000E+01,
     &  -3.5000E+01,-3.4000E+01,-3.3000E+01,-3.2000E+01,-3.1000E+01,
     &  -3.0000E+01,-2.9000E+01,-2.8000E+01,-2.7000E+01,-2.6000E+01,
     &  -2.5000E+01,-2.4000E+01,-2.3000E+01,-2.2000E+01,-2.1000E+01,
     &  -2.0000E+01,-1.9000E+01,-1.8000E+01,-1.7000E+01,-1.6000E+01,
     &  -1.5000E+01,-1.4000E+01,-1.3000E+01,-1.2000E+01,-1.1000E+01,
     &  -1.0000E+01,-9.9100E+00,-9.8200E+00,-9.7300E+00,-9.6400E+00,
     &  -9.5500E+00,-9.4600E+00,-9.3700E+00,-9.2800E+00,-9.1900E+00,
     &  -9.1000E+00,-9.0100E+00,-8.9200E+00,-8.8300E+00,-8.7400E+00,
     &  -8.6500E+00,-8.5600E+00,-8.4700E+00,-8.3800E+00,-8.2900E+00/
  
       DATA  (ETA(I), I= 201, 300) /
     &  -8.2000E+00,-8.1100E+00,-8.0200E+00,-7.9300E+00,-7.8400E+00,
     &  -7.7500E+00,-7.6600E+00,-7.5700E+00,-7.4800E+00,-7.3900E+00,
     &  -7.3000E+00,-7.2100E+00,-7.1200E+00,-7.0300E+00,-6.9400E+00,
     &  -6.8500E+00,-6.7600E+00,-6.6700E+00,-6.5800E+00,-6.4900E+00,
     &  -6.4000E+00,-6.3100E+00,-6.2200E+00,-6.1300E+00,-6.0400E+00,
     &  -5.9500E+00,-5.8600E+00,-5.7700E+00,-5.6800E+00,-5.5900E+00,
     &  -5.5000E+00,-5.4100E+00,-5.3200E+00,-5.2300E+00,-5.1400E+00,
     &  -5.0500E+00,-4.9600E+00,-4.8700E+00,-4.7800E+00,-4.6900E+00,
     &  -4.6000E+00,-4.5100E+00,-4.4200E+00,-4.3300E+00,-4.2400E+00,
     &  -4.1500E+00,-4.0600E+00,-3.9700E+00,-3.8800E+00,-3.7900E+00,
     &  -3.7000E+00,-3.6100E+00,-3.5200E+00,-3.4300E+00,-3.3400E+00,
     &  -3.2500E+00,-3.1600E+00,-3.0700E+00,-2.9800E+00,-2.8900E+00,
     &  -2.8000E+00,-2.7100E+00,-2.6200E+00,-2.5300E+00,-2.4400E+00,
     &  -2.3500E+00,-2.2600E+00,-2.1700E+00,-2.0800E+00,-1.9900E+00,
     &  -1.9000E+00,-1.8100E+00,-1.7200E+00,-1.6300E+00,-1.5400E+00,
     &  -1.4500E+00,-1.3600E+00,-1.2700E+00,-1.1800E+00,-1.0900E+00,
     &  -1.0000E+00,-9.9100E-01,-9.8200E-01,-9.7300E-01,-9.6400E-01,
     &  -9.5500E-01,-9.4600E-01,-9.3700E-01,-9.2800E-01,-9.1900E-01,
     &  -9.1000E-01,-9.0100E-01,-8.9200E-01,-8.8300E-01,-8.7400E-01,
     &  -8.6500E-01,-8.5600E-01,-8.4700E-01,-8.3800E-01,-8.2900E-01/
  
       DATA  (ETA(I), I= 301, 400) /
     &  -8.2000E-01,-8.1100E-01,-8.0200E-01,-7.9300E-01,-7.8400E-01,
     &  -7.7500E-01,-7.6600E-01,-7.5700E-01,-7.4800E-01,-7.3900E-01,
     &  -7.3000E-01,-7.2100E-01,-7.1200E-01,-7.0300E-01,-6.9400E-01,
     &  -6.8500E-01,-6.7600E-01,-6.6700E-01,-6.5800E-01,-6.4900E-01,
     &  -6.4000E-01,-6.3100E-01,-6.2200E-01,-6.1300E-01,-6.0400E-01,
     &  -5.9500E-01,-5.8600E-01,-5.7700E-01,-5.6800E-01,-5.5900E-01,
     &  -5.5000E-01,-5.4100E-01,-5.3200E-01,-5.2300E-01,-5.1400E-01,
     &  -5.0500E-01,-4.9600E-01,-4.8700E-01,-4.7800E-01,-4.6900E-01,
     &  -4.6000E-01,-4.5100E-01,-4.4200E-01,-4.3300E-01,-4.2400E-01,
     &  -4.1500E-01,-4.0600E-01,-3.9700E-01,-3.8800E-01,-3.7900E-01,
     &  -3.7000E-01,-3.6100E-01,-3.5200E-01,-3.4300E-01,-3.3400E-01,
     &  -3.2500E-01,-3.1600E-01,-3.0700E-01,-2.9800E-01,-2.8900E-01,
     &  -2.8000E-01,-2.7100E-01,-2.6200E-01,-2.5300E-01,-2.4400E-01,
     &  -2.3500E-01,-2.2600E-01,-2.1700E-01,-2.0800E-01,-1.9900E-01,
     &  -1.9000E-01,-1.8100E-01,-1.7200E-01,-1.6300E-01,-1.5400E-01,
     &  -1.4500E-01,-1.3600E-01,-1.2700E-01,-1.1800E-01,-1.0900E-01,
     &  -1.0000E-01,-9.9100E-02,-9.8200E-02,-9.7300E-02,-9.6400E-02,
     &  -9.5500E-02,-9.4600E-02,-9.3700E-02,-9.2800E-02,-9.1900E-02,
     &  -9.1000E-02,-9.0100E-02,-8.9200E-02,-8.8300E-02,-8.7400E-02,
     &  -8.6500E-02,-8.5600E-02,-8.4700E-02,-8.3800E-02,-8.2900E-02/
  
       DATA  (ETA(I), I= 401, 500) /
     &  -8.2000E-02,-8.1100E-02,-8.0200E-02,-7.9300E-02,-7.8400E-02,
     &  -7.7500E-02,-7.6600E-02,-7.5700E-02,-7.4800E-02,-7.3900E-02,
     &  -7.3000E-02,-7.2100E-02,-7.1200E-02,-7.0300E-02,-6.9400E-02,
     &  -6.8500E-02,-6.7600E-02,-6.6700E-02,-6.5800E-02,-6.4900E-02,
     &  -6.4000E-02,-6.3100E-02,-6.2200E-02,-6.1300E-02,-6.0400E-02,
     &  -5.9500E-02,-5.8600E-02,-5.7700E-02,-5.6800E-02,-5.5900E-02,
     &  -5.5000E-02,-5.4100E-02,-5.3200E-02,-5.2300E-02,-5.1400E-02,
     &  -5.0500E-02,-4.9600E-02,-4.8700E-02,-4.7800E-02,-4.6900E-02,
     &  -4.6000E-02,-4.5100E-02,-4.4200E-02,-4.3300E-02,-4.2400E-02,
     &  -4.1500E-02,-4.0600E-02,-3.9700E-02,-3.8800E-02,-3.7900E-02,
     &  -3.7000E-02,-3.6100E-02,-3.5200E-02,-3.4300E-02,-3.3400E-02,
     &  -3.2500E-02,-3.1600E-02,-3.0700E-02,-2.9800E-02,-2.8900E-02,
     &  -2.8000E-02,-2.7100E-02,-2.6200E-02,-2.5300E-02,-2.4400E-02,
     &  -2.3500E-02,-2.2600E-02,-2.1700E-02,-2.0800E-02,-1.9900E-02,
     &  -1.9000E-02,-1.8100E-02,-1.7200E-02,-1.6300E-02,-1.5400E-02,
     &  -1.4500E-02,-1.3600E-02,-1.2700E-02,-1.1800E-02,-1.0900E-02,
     &  -1.0000E-02,-9.9100E-03,-9.8200E-03,-9.7300E-03,-9.6400E-03,
     &  -9.5500E-03,-9.4600E-03,-9.3700E-03,-9.2800E-03,-9.1900E-03,
     &  -9.1000E-03,-9.0100E-03,-8.9200E-03,-8.8300E-03,-8.7400E-03,
     &  -8.6500E-03,-8.5600E-03,-8.4700E-03,-8.3800E-03,-8.2900E-03/
  
       DATA  (ETA(I), I= 501, 600) /
     &  -8.2000E-03,-8.1100E-03,-8.0200E-03,-7.9300E-03,-7.8400E-03,
     &  -7.7500E-03,-7.6600E-03,-7.5700E-03,-7.4800E-03,-7.3900E-03,
     &  -7.3000E-03,-7.2100E-03,-7.1200E-03,-7.0300E-03,-6.9400E-03,
     &  -6.8500E-03,-6.7600E-03,-6.6700E-03,-6.5800E-03,-6.4900E-03,
     &  -6.4000E-03,-6.3100E-03,-6.2200E-03,-6.1300E-03,-6.0400E-03,
     &  -5.9500E-03,-5.8600E-03,-5.7700E-03,-5.6800E-03,-5.5900E-03,
     &  -5.5000E-03,-5.4100E-03,-5.3200E-03,-5.2300E-03,-5.1400E-03,
     &  -5.0500E-03,-4.9600E-03,-4.8700E-03,-4.7800E-03,-4.6900E-03,
     &  -4.6000E-03,-4.5100E-03,-4.4200E-03,-4.3300E-03,-4.2400E-03,
     &  -4.1500E-03,-4.0600E-03,-3.9700E-03,-3.8800E-03,-3.7900E-03,
     &  -3.7000E-03,-3.6100E-03,-3.5200E-03,-3.4300E-03,-3.3400E-03,
     &  -3.2500E-03,-3.1600E-03,-3.0700E-03,-2.9800E-03,-2.8900E-03,
     &  -2.8000E-03,-2.7100E-03,-2.6200E-03,-2.5300E-03,-2.4400E-03,
     &  -2.3500E-03,-2.2600E-03,-2.1700E-03,-2.0800E-03,-1.9900E-03,
     &  -1.9000E-03,-1.8100E-03,-1.7200E-03,-1.6300E-03,-1.5400E-03,
     &  -1.4500E-03,-1.3600E-03,-1.2700E-03,-1.1800E-03,-1.0900E-03,
     &  -1.0000E-03,-9.9100E-04,-9.8200E-04,-9.7300E-04,-9.6400E-04,
     &  -9.5500E-04,-9.4600E-04,-9.3700E-04,-9.2800E-04,-9.1900E-04,
     &  -9.1000E-04,-9.0100E-04,-8.9200E-04,-8.8300E-04,-8.7400E-04,
     &  -8.6500E-04,-8.5600E-04,-8.4700E-04,-8.3800E-04,-8.2900E-04/
  
       DATA  (ETA(I), I= 601, 700) /
     &  -8.2000E-04,-8.1100E-04,-8.0200E-04,-7.9300E-04,-7.8400E-04,
     &  -7.7500E-04,-7.6600E-04,-7.5700E-04,-7.4800E-04,-7.3900E-04,
     &  -7.3000E-04,-7.2100E-04,-7.1200E-04,-7.0300E-04,-6.9400E-04,
     &  -6.8500E-04,-6.7600E-04,-6.6700E-04,-6.5800E-04,-6.4900E-04,
     &  -6.4000E-04,-6.3100E-04,-6.2200E-04,-6.1300E-04,-6.0400E-04,
     &  -5.9500E-04,-5.8600E-04,-5.7700E-04,-5.6800E-04,-5.5900E-04,
     &  -5.5000E-04,-5.4100E-04,-5.3200E-04,-5.2300E-04,-5.1400E-04,
     &  -5.0500E-04,-4.9600E-04,-4.8700E-04,-4.7800E-04,-4.6900E-04,
     &  -4.6000E-04,-4.5100E-04,-4.4200E-04,-4.3300E-04,-4.2400E-04,
     &  -4.1500E-04,-4.0600E-04,-3.9700E-04,-3.8800E-04,-3.7900E-04,
     &  -3.7000E-04,-3.6100E-04,-3.5200E-04,-3.4300E-04,-3.3400E-04,
     &  -3.2500E-04,-3.1600E-04,-3.0700E-04,-2.9800E-04,-2.8900E-04,
     &  -2.8000E-04,-2.7100E-04,-2.6200E-04,-2.5300E-04,-2.4400E-04,
     &  -2.3500E-04,-2.2600E-04,-2.1700E-04,-2.0800E-04,-1.9900E-04,
     &  -1.9000E-04,-1.8100E-04,-1.7200E-04,-1.6300E-04,-1.5400E-04,
     &  -1.4500E-04,-1.3600E-04,-1.2700E-04,-1.1800E-04,-1.0900E-04,
     &  -1.0000E-04,-9.9100E-05,-9.8200E-05,-9.7300E-05,-9.6400E-05,
     &  -9.5500E-05,-9.4600E-05,-9.3700E-05,-9.2800E-05,-9.1900E-05,
     &  -9.1000E-05,-9.0100E-05,-8.9200E-05,-8.8300E-05,-8.7400E-05,
     &  -8.6500E-05,-8.5600E-05,-8.4700E-05,-8.3800E-05,-8.2900E-05/
  
       DATA  (ETA(I), I= 701, 800) /
     &  -8.2000E-05,-8.1100E-05,-8.0200E-05,-7.9300E-05,-7.8400E-05,
     &  -7.7500E-05,-7.6600E-05,-7.5700E-05,-7.4800E-05,-7.3900E-05,
     &  -7.3000E-05,-7.2100E-05,-7.1200E-05,-7.0300E-05,-6.9400E-05,
     &  -6.8500E-05,-6.7600E-05,-6.6700E-05,-6.5800E-05,-6.4900E-05,
     &  -6.4000E-05,-6.3100E-05,-6.2200E-05,-6.1300E-05,-6.0400E-05,
     &  -5.9500E-05,-5.8600E-05,-5.7700E-05,-5.6800E-05,-5.5900E-05,
     &  -5.5000E-05,-5.4100E-05,-5.3200E-05,-5.2300E-05,-5.1400E-05,
     &  -5.0500E-05,-4.9600E-05,-4.8700E-05,-4.7800E-05,-4.6900E-05,
     &  -4.6000E-05,-4.5100E-05,-4.4200E-05,-4.3300E-05,-4.2400E-05,
     &  -4.1500E-05,-4.0600E-05,-3.9700E-05,-3.8800E-05,-3.7900E-05,
     &  -3.7000E-05,-3.6100E-05,-3.5200E-05,-3.4300E-05,-3.3400E-05,
     &  -3.2500E-05,-3.1600E-05,-3.0700E-05,-2.9800E-05,-2.8900E-05,
     &  -2.8000E-05,-2.7100E-05,-2.6200E-05,-2.5300E-05,-2.4400E-05,
     &  -2.3500E-05,-2.2600E-05,-2.1700E-05,-2.0800E-05,-1.9900E-05,
     &  -1.9000E-05,-1.8100E-05,-1.7200E-05,-1.6300E-05,-1.5400E-05,
     &  -1.4500E-05,-1.3600E-05,-1.2700E-05,-1.1800E-05,-1.0900E-05,
     &  -1.0000E-05,-9.9100E-06,-9.8200E-06,-9.7300E-06,-9.6400E-06,
     &  -9.5500E-06,-9.4600E-06,-9.3700E-06,-9.2800E-06,-9.1900E-06,
     &  -9.1000E-06,-9.0100E-06,-8.9200E-06,-8.8300E-06,-8.7400E-06,
     &  -8.6500E-06,-8.5600E-06,-8.4700E-06,-8.3800E-06,-8.2900E-06/
  
       DATA  (ETA(I), I= 801, 900) /
     &  -8.2000E-06,-8.1100E-06,-8.0200E-06,-7.9300E-06,-7.8400E-06,
     &  -7.7500E-06,-7.6600E-06,-7.5700E-06,-7.4800E-06,-7.3900E-06,
     &  -7.3000E-06,-7.2100E-06,-7.1200E-06,-7.0300E-06,-6.9400E-06,
     &  -6.8500E-06,-6.7600E-06,-6.6700E-06,-6.5800E-06,-6.4900E-06,
     &  -6.4000E-06,-6.3100E-06,-6.2200E-06,-6.1300E-06,-6.0400E-06,
     &  -5.9500E-06,-5.8600E-06,-5.7700E-06,-5.6800E-06,-5.5900E-06,
     &  -5.5000E-06,-5.4100E-06,-5.3200E-06,-5.2300E-06,-5.1400E-06,
     &  -5.0500E-06,-4.9600E-06,-4.8700E-06,-4.7800E-06,-4.6900E-06,
     &  -4.6000E-06,-4.5100E-06,-4.4200E-06,-4.3300E-06,-4.2400E-06,
     &  -4.1500E-06,-4.0600E-06,-3.9700E-06,-3.8800E-06,-3.7900E-06,
     &  -3.7000E-06,-3.6100E-06,-3.5200E-06,-3.4300E-06,-3.3400E-06,
     &  -3.2500E-06,-3.1600E-06,-3.0700E-06,-2.9800E-06,-2.8900E-06,
     &  -2.8000E-06,-2.7100E-06,-2.6200E-06,-2.5300E-06,-2.4400E-06,
     &  -2.3500E-06,-2.2600E-06,-2.1700E-06,-2.0800E-06,-1.9900E-06,
     &  -1.9000E-06,-1.8100E-06,-1.7200E-06,-1.6300E-06,-1.5400E-06,
     &  -1.4500E-06,-1.3600E-06,-1.2700E-06,-1.1800E-06,-1.0900E-06,
     &  -1.0000E-06, 0.0000E+00, 1.0000E-06, 3.0010E-03, 6.0010E-03,
     &   9.0010E-03, 1.2000E-02, 1.5000E-02, 1.8000E-02, 2.1000E-02,
     &   2.4000E-02, 2.7000E-02, 3.0000E-02, 3.3000E-02, 3.6000E-02,
     &   3.9000E-02, 4.2000E-02, 4.5000E-02, 4.8000E-02, 5.1000E-02/
  
       DATA  (ETA(I), I= 901,977) /
     &   5.4000E-02, 5.7000E-02, 6.0000E-02, 6.3000E-02, 6.6000E-02,
     &   6.9000E-02, 7.2000E-02, 7.5000E-02, 7.8000E-02, 8.1000E-02,
     &   8.4000E-02, 8.7000E-02, 9.0000E-02, 9.3000E-02, 9.6000E-02,
     &   9.9000E-02, 1.0200E-01, 1.0500E-01, 1.0800E-01, 1.1100E-01,
     &   1.1400E-01, 1.1700E-01, 1.2000E-01, 1.2300E-01, 1.2600E-01,
     &   1.2900E-01, 1.3200E-01, 1.3500E-01, 1.3800E-01, 1.4100E-01,
     &   1.4400E-01, 1.4700E-01, 1.5000E-01, 1.5300E-01, 1.5600E-01,
     &   1.5900E-01, 1.6200E-01, 1.6500E-01, 1.6800E-01, 1.7100E-01,
     &   1.7400E-01, 1.7700E-01, 1.8000E-01, 1.8300E-01, 1.8600E-01,
     &   1.8900E-01, 1.9200E-01, 1.9500E-01, 1.9800E-01, 2.0100E-01,
     &   2.0400E-01, 2.0700E-01, 2.1000E-01, 2.1300E-01, 2.1600E-01,
     &   2.1900E-01, 2.2200E-01, 2.2500E-01, 2.2800E-01, 2.3100E-01,
     &   2.3400E-01, 2.3700E-01, 2.4000E-01, 2.4300E-01, 2.4600E-01,
     &   2.4900E-01, 2.5200E-01, 2.5500E-01, 2.5800E-01, 2.6100E-01,
     &   2.6400E-01, 2.6700E-01, 2.7000E-01, 2.7100E-01, 2.7300E-01,
     &   0.27370000D0, 0.27599999D0/
  
         DATA ((DAT(I,J), I=   1, 100), J=1,1) /
     &   4.1582E-02, 4.1524E-02, 4.1464E-02, 4.1404E-02, 4.1344E-02,
     &   4.1282E-02, 4.1220E-02, 4.1158E-02, 4.1095E-02, 4.1031E-02,
     &   4.0966E-02, 4.0901E-02, 4.0834E-02, 4.0768E-02, 4.0700E-02,
     &   4.0632E-02, 4.0562E-02, 4.0492E-02, 4.0421E-02, 4.0349E-02,
     &   4.0277E-02, 4.0203E-02, 4.0129E-02, 4.0053E-02, 3.9977E-02,
     &   3.9899E-02, 3.9820E-02, 3.9741E-02, 3.9660E-02, 3.9578E-02,
     &   3.9495E-02, 3.9411E-02, 3.9325E-02, 3.9239E-02, 3.9151E-02,
     &   3.9061E-02, 3.8970E-02, 3.8878E-02, 3.8784E-02, 3.8689E-02,
     &   3.8592E-02, 3.8494E-02, 3.8394E-02, 3.8292E-02, 3.8188E-02,
     &   3.8083E-02, 3.7975E-02, 3.7865E-02, 3.7754E-02, 3.7640E-02,
     &   3.7524E-02, 3.7406E-02, 3.7285E-02, 3.7161E-02, 3.7035E-02,
     &   3.6906E-02, 3.6775E-02, 3.6640E-02, 3.6502E-02, 3.6360E-02,
     &   3.6216E-02, 3.6067E-02, 3.5915E-02, 3.5758E-02, 3.5597E-02,
     &   3.5432E-02, 3.5262E-02, 3.5087E-02, 3.4906E-02, 3.4720E-02,
     &   3.4527E-02, 3.4328E-02, 3.4122E-02, 3.3908E-02, 3.3686E-02,
     &   3.3456E-02, 3.3216E-02, 3.2966E-02, 3.2705E-02, 3.2431E-02,
     &   3.2144E-02, 3.1842E-02, 3.1524E-02, 3.1188E-02, 3.0831E-02,
     &   3.0451E-02, 3.0044E-02, 2.9608E-02, 2.9136E-02, 2.8623E-02,
     &   2.8061E-02, 2.8001E-02, 2.7941E-02, 2.7881E-02, 2.7820E-02,
     &   2.7758E-02, 2.7695E-02, 2.7632E-02, 2.7568E-02, 2.7504E-02/
         DATA ((DAT(I,J), I= 101, 200), J=1,1) /
     &   2.7439E-02, 2.7373E-02, 2.7306E-02, 2.7239E-02, 2.7170E-02,
     &   2.7101E-02, 2.7031E-02, 2.6961E-02, 2.6889E-02, 2.6817E-02,
     &   2.6743E-02, 2.6669E-02, 2.6594E-02, 2.6517E-02, 2.6440E-02,
     &   2.6362E-02, 2.6283E-02, 2.6202E-02, 2.6121E-02, 2.6038E-02,
     &   2.5954E-02, 2.5869E-02, 2.5783E-02, 2.5695E-02, 2.5606E-02,
     &   2.5516E-02, 2.5425E-02, 2.5331E-02, 2.5237E-02, 2.5141E-02,
     &   2.5043E-02, 2.4944E-02, 2.4842E-02, 2.4740E-02, 2.4635E-02,
     &   2.4528E-02, 2.4420E-02, 2.4309E-02, 2.4197E-02, 2.4082E-02,
     &   2.3965E-02, 2.3845E-02, 2.3723E-02, 2.3599E-02, 2.3471E-02,
     &   2.3341E-02, 2.3208E-02, 2.3072E-02, 2.2933E-02, 2.2790E-02,
     &   2.2644E-02, 2.2494E-02, 2.2341E-02, 2.2183E-02, 2.2021E-02,
     &   2.1854E-02, 2.1683E-02, 2.1506E-02, 2.1324E-02, 2.1137E-02,
     &   2.0943E-02, 2.0742E-02, 2.0535E-02, 2.0320E-02, 2.0097E-02,
     &   1.9866E-02, 1.9625E-02, 1.9374E-02, 1.9112E-02, 1.8838E-02,
     &   1.8551E-02, 1.8250E-02, 1.7933E-02, 1.7598E-02, 1.7244E-02,
     &   1.6867E-02, 1.6466E-02, 1.6036E-02, 1.5574E-02, 1.5074E-02,
     &   1.4530E-02, 1.4478E-02, 1.4426E-02, 1.4374E-02, 1.4321E-02,
     &   1.4268E-02, 1.4214E-02, 1.4160E-02, 1.4106E-02, 1.4050E-02,
     &   1.3995E-02, 1.3939E-02, 1.3882E-02, 1.3825E-02, 1.3767E-02,
     &   1.3709E-02, 1.3650E-02, 1.3591E-02, 1.3531E-02, 1.3471E-02/
         DATA ((DAT(I,J), I= 201, 300), J=1,1) /
     &   1.3409E-02, 1.3348E-02, 1.3285E-02, 1.3222E-02, 1.3159E-02,
     &   1.3094E-02, 1.3030E-02, 1.2964E-02, 1.2898E-02, 1.2831E-02,
     &   1.2763E-02, 1.2694E-02, 1.2625E-02, 1.2555E-02, 1.2484E-02,
     &   1.2412E-02, 1.2340E-02, 1.2266E-02, 1.2192E-02, 1.2117E-02,
     &   1.2041E-02, 1.1964E-02, 1.1886E-02, 1.1807E-02, 1.1727E-02,
     &   1.1646E-02, 1.1564E-02, 1.1481E-02, 1.1396E-02, 1.1311E-02,
     &   1.1224E-02, 1.1136E-02, 1.1047E-02, 1.0957E-02, 1.0865E-02,
     &   1.0772E-02, 1.0678E-02, 1.0582E-02, 1.0485E-02, 1.0386E-02,
     &   1.0285E-02, 1.0183E-02, 1.0079E-02, 9.9739E-03, 9.8666E-03,
     &   9.7575E-03, 9.6464E-03, 9.5334E-03, 9.4183E-03, 9.3010E-03,
     &   9.1816E-03, 9.0599E-03, 8.9357E-03, 8.8091E-03, 8.6799E-03,
     &   8.5480E-03, 8.4133E-03, 8.2757E-03, 8.1350E-03, 7.9910E-03,
     &   7.8436E-03, 7.6927E-03, 7.5380E-03, 7.3793E-03, 7.2163E-03,
     &   7.0489E-03, 6.8766E-03, 6.6993E-03, 6.5164E-03, 6.3275E-03,
     &   6.1322E-03, 5.9299E-03, 5.7199E-03, 5.5015E-03, 5.2739E-03,
     &   5.0360E-03, 4.7867E-03, 4.5248E-03, 4.2487E-03, 3.9570E-03,
     &   3.6481E-03, 3.6162E-03, 3.5841E-03, 3.5518E-03, 3.5193E-03,
     &   3.4866E-03, 3.4537E-03, 3.4207E-03, 3.3874E-03, 3.3540E-03,
     &   3.3203E-03, 3.2864E-03, 3.2524E-03, 3.2181E-03, 3.1836E-03,
     &   3.1489E-03, 3.1141E-03, 3.0790E-03, 3.0437E-03, 3.0082E-03/
         DATA ((DAT(I,J), I= 301, 400), J=1,1) /
     &   2.9725E-03, 2.9366E-03, 2.9005E-03, 2.8642E-03, 2.8276E-03,
     &   2.7909E-03, 2.7540E-03, 2.7168E-03, 2.6795E-03, 2.6420E-03,
     &   2.6042E-03, 2.5663E-03, 2.5282E-03, 2.4899E-03, 2.4514E-03,
     &   2.4127E-03, 2.3738E-03, 2.3348E-03, 2.2956E-03, 2.2562E-03,
     &   2.2166E-03, 2.1769E-03, 2.1371E-03, 2.0971E-03, 2.0569E-03,
     &   2.0166E-03, 1.9762E-03, 1.9357E-03, 1.8950E-03, 1.8543E-03,
     &   1.8135E-03, 1.7725E-03, 1.7316E-03, 1.6905E-03, 1.6494E-03,
     &   1.6083E-03, 1.5672E-03, 1.5260E-03, 1.4849E-03, 1.4438E-03,
     &   1.4027E-03, 1.3617E-03, 1.3208E-03, 1.2799E-03, 1.2392E-03,
     &   1.1986E-03, 1.1582E-03, 1.1180E-03, 1.0780E-03, 1.0382E-03,
     &   9.9863E-04, 9.5937E-04, 9.2042E-04, 8.8181E-04, 8.4357E-04,
     &   8.0573E-04, 7.6831E-04, 7.3135E-04, 6.9488E-04, 6.5894E-04,
     &   6.2356E-04, 5.8877E-04, 5.5461E-04, 5.2112E-04, 4.8833E-04,
     &   4.5627E-04, 4.2500E-04, 3.9453E-04, 3.6492E-04, 3.3620E-04,
     &   3.0841E-04, 2.8159E-04, 2.5577E-04, 2.3099E-04, 2.0729E-04,
     &   1.8471E-04, 1.6328E-04, 1.4304E-04, 1.2402E-04, 1.0625E-04,
     &   8.9759E-05, 8.8182E-05, 8.6619E-05, 8.5068E-05, 8.3531E-05,
     &   8.2006E-05, 8.0496E-05, 7.8998E-05, 7.7514E-05, 7.6043E-05,
     &   7.4585E-05, 7.3141E-05, 7.1710E-05, 7.0293E-05, 6.8889E-05,
     &   6.7499E-05, 6.6122E-05, 6.4759E-05, 6.3410E-05, 6.2074E-05/
         DATA ((DAT(I,J), I= 401, 500), J=1,1) /
     &   6.0751E-05, 5.9443E-05, 5.8148E-05, 5.6867E-05, 5.5599E-05,
     &   5.4345E-05, 5.3105E-05, 5.1879E-05, 5.0667E-05, 4.9468E-05,
     &   4.8284E-05, 4.7113E-05, 4.5956E-05, 4.4813E-05, 4.3684E-05,
     &   4.2569E-05, 4.1468E-05, 4.0382E-05, 3.9309E-05, 3.8250E-05,
     &   3.7205E-05, 3.6175E-05, 3.5158E-05, 3.4156E-05, 3.3168E-05,
     &   3.2194E-05, 3.1234E-05, 3.0288E-05, 2.9357E-05, 2.8440E-05,
     &   2.7537E-05, 2.6649E-05, 2.5775E-05, 2.4915E-05, 2.4069E-05,
     &   2.3238E-05, 2.2421E-05, 2.1619E-05, 2.0831E-05, 2.0057E-05,
     &   1.9298E-05, 1.8554E-05, 1.7824E-05, 1.7108E-05, 1.6407E-05,
     &   1.5720E-05, 1.5048E-05, 1.4390E-05, 1.3747E-05, 1.3119E-05,
     &   1.2505E-05, 1.1905E-05, 1.1321E-05, 1.0751E-05, 1.0195E-05,
     &   9.6543E-06, 9.1281E-06, 8.6165E-06, 8.1197E-06, 7.6374E-06,
     &   7.1699E-06, 6.7171E-06, 6.2790E-06, 5.8556E-06, 5.4469E-06,
     &   5.0529E-06, 4.6737E-06, 4.3092E-06, 3.9595E-06, 3.6245E-06,
     &   3.3043E-06, 2.9989E-06, 2.7083E-06, 2.4324E-06, 2.1714E-06,
     &   1.9251E-06, 1.6936E-06, 1.4770E-06, 1.2751E-06, 1.0881E-06,
     &   9.1583E-07, 8.9942E-07, 8.8316E-07, 8.6705E-07, 8.5109E-07,
     &   8.3527E-07, 8.1961E-07, 8.0409E-07, 7.8872E-07, 7.7350E-07,
     &   7.5842E-07, 7.4350E-07, 7.2872E-07, 7.1409E-07, 6.9961E-07,
     &   6.8528E-07, 6.7110E-07, 6.5706E-07, 6.4317E-07, 6.2944E-07/
         DATA ((DAT(I,J), I= 501, 600), J=1,1) /
     &   6.1584E-07, 6.0240E-07, 5.8911E-07, 5.7596E-07, 5.6296E-07,
     &   5.5011E-07, 5.3741E-07, 5.2486E-07, 5.1246E-07, 5.0020E-07,
     &   4.8809E-07, 4.7613E-07, 4.6432E-07, 4.5266E-07, 4.4114E-07,
     &   4.2978E-07, 4.1856E-07, 4.0749E-07, 3.9657E-07, 3.8579E-07,
     &   3.7517E-07, 3.6469E-07, 3.5436E-07, 3.4418E-07, 3.3415E-07,
     &   3.2427E-07, 3.1453E-07, 3.0495E-07, 2.9551E-07, 2.8622E-07,
     &   2.7708E-07, 2.6808E-07, 2.5924E-07, 2.5054E-07, 2.4200E-07,
     &   2.3360E-07, 2.2534E-07, 2.1724E-07, 2.0929E-07, 2.0148E-07,
     &   1.9382E-07, 1.8631E-07, 1.7895E-07, 1.7174E-07, 1.6467E-07,
     &   1.5776E-07, 1.5099E-07, 1.4437E-07, 1.3790E-07, 1.3157E-07,
     &   1.2540E-07, 1.1937E-07, 1.1350E-07, 1.0777E-07, 1.0218E-07,
     &   9.6752E-08, 9.1468E-08, 8.6332E-08, 8.1345E-08, 7.6505E-08,
     &   7.1815E-08, 6.7272E-08, 6.2878E-08, 5.8633E-08, 5.4535E-08,
     &   5.0587E-08, 4.6786E-08, 4.3134E-08, 3.9630E-08, 3.6275E-08,
     &   3.3068E-08, 3.0009E-08, 2.7099E-08, 2.4338E-08, 2.1724E-08,
     &   1.9259E-08, 1.6943E-08, 1.4774E-08, 1.2755E-08, 1.0883E-08,
     &   9.1602E-09, 8.9960E-09, 8.8334E-09, 8.6722E-09, 8.5125E-09,
     &   8.3543E-09, 8.1976E-09, 8.0423E-09, 7.8886E-09, 7.7363E-09,
     &   7.5855E-09, 7.4362E-09, 7.2884E-09, 7.1421E-09, 6.9972E-09,
     &   6.8539E-09, 6.7120E-09, 6.5716E-09, 6.4327E-09, 6.2952E-09/
         DATA ((DAT(I,J), I= 601, 700), J=1,1) /
     &   6.1593E-09, 6.0248E-09, 5.8919E-09, 5.7604E-09, 5.6304E-09,
     &   5.5018E-09, 5.3748E-09, 5.2492E-09, 5.1252E-09, 5.0026E-09,
     &   4.8815E-09, 4.7618E-09, 4.6437E-09, 4.5270E-09, 4.4119E-09,
     &   4.2982E-09, 4.1860E-09, 4.0753E-09, 3.9660E-09, 3.8583E-09,
     &   3.7520E-09, 3.6472E-09, 3.5439E-09, 3.4421E-09, 3.3418E-09,
     &   3.2429E-09, 3.1456E-09, 3.0497E-09, 2.9553E-09, 2.8624E-09,
     &   2.7710E-09, 2.6810E-09, 2.5925E-09, 2.5056E-09, 2.4201E-09,
     &   2.3361E-09, 2.2536E-09, 2.1725E-09, 2.0930E-09, 2.0149E-09,
     &   1.9383E-09, 1.8632E-09, 1.7896E-09, 1.7174E-09, 1.6468E-09,
     &   1.5776E-09, 1.5099E-09, 1.4437E-09, 1.3790E-09, 1.3158E-09,
     &   1.2540E-09, 1.1938E-09, 1.1350E-09, 1.0777E-09, 1.0219E-09,
     &   9.6754E-10, 9.1470E-10, 8.6334E-10, 8.1346E-10, 7.6507E-10,
     &   7.1816E-10, 6.7273E-10, 6.2879E-10, 5.8633E-10, 5.4536E-10,
     &   5.0587E-10, 4.6787E-10, 4.3134E-10, 3.9631E-10, 3.6275E-10,
     &   3.3068E-10, 3.0010E-10, 2.7099E-10, 2.4338E-10, 2.1724E-10,
     &   1.9259E-10, 1.6943E-10, 1.4774E-10, 1.2755E-10, 1.0883E-10,
     &   9.1602E-11, 8.9960E-11, 8.8334E-11, 8.6722E-11, 8.5125E-11,
     &   8.3543E-11, 8.1976E-11, 8.0424E-11, 7.8886E-11, 7.7363E-11,
     &   7.5855E-11, 7.4362E-11, 7.2884E-11, 7.1421E-11, 6.9972E-11,
     &   6.8539E-11, 6.7120E-11, 6.5716E-11, 6.4327E-11, 6.2953E-11/
         DATA ((DAT(I,J), I= 701, 800), J=1,1) /
     &   6.1593E-11, 6.0248E-11, 5.8919E-11, 5.7604E-11, 5.6304E-11,
     &   5.5018E-11, 5.3748E-11, 5.2492E-11, 5.1252E-11, 5.0026E-11,
     &   4.8815E-11, 4.7618E-11, 4.6437E-11, 4.5270E-11, 4.4119E-11,
     &   4.2982E-11, 4.1860E-11, 4.0753E-11, 3.9660E-11, 3.8583E-11,
     &   3.7520E-11, 3.6472E-11, 3.5439E-11, 3.4421E-11, 3.3418E-11,
     &   3.2429E-11, 3.1456E-11, 3.0497E-11, 2.9553E-11, 2.8624E-11,
     &   2.7710E-11, 2.6810E-11, 2.5926E-11, 2.5056E-11, 2.4201E-11,
     &   2.3361E-11, 2.2536E-11, 2.1725E-11, 2.0930E-11, 2.0149E-11,
     &   1.9383E-11, 1.8632E-11, 1.7896E-11, 1.7174E-11, 1.6468E-11,
     &   1.5776E-11, 1.5099E-11, 1.4437E-11, 1.3790E-11, 1.3158E-11,
     &   1.2540E-11, 1.1938E-11, 1.1350E-11, 1.0777E-11, 1.0219E-11,
     &   9.6754E-12, 9.1470E-12, 8.6334E-12, 8.1346E-12, 7.6507E-12,
     &   7.1816E-12, 6.7273E-12, 6.2879E-12, 5.8633E-12, 5.4536E-12,
     &   5.0587E-12, 4.6787E-12, 4.3134E-12, 3.9631E-12, 3.6275E-12,
     &   3.3068E-12, 3.0010E-12, 2.7099E-12, 2.4338E-12, 2.1724E-12,
     &   1.9259E-12, 1.6943E-12, 1.4774E-12, 1.2755E-12, 1.0883E-12,
     &   9.1602E-13, 8.9960E-13, 8.8334E-13, 8.6722E-13, 8.5125E-13,
     &   8.3543E-13, 8.1976E-13, 8.0424E-13, 7.8886E-13, 7.7363E-13,
     &   7.5855E-13, 7.4362E-13, 7.2884E-13, 7.1421E-13, 6.9972E-13,
     &   6.8539E-13, 6.7120E-13, 6.5716E-13, 6.4327E-13, 6.2953E-13/
         DATA ((DAT(I,J), I= 801, 900), J=1,1) /
     &   6.1593E-13, 6.0248E-13, 5.8919E-13, 5.7604E-13, 5.6304E-13,
     &   5.5018E-13, 5.3748E-13, 5.2492E-13, 5.1252E-13, 5.0026E-13,
     &   4.8815E-13, 4.7618E-13, 4.6437E-13, 4.5270E-13, 4.4119E-13,
     &   4.2982E-13, 4.1860E-13, 4.0753E-13, 3.9660E-13, 3.8583E-13,
     &   3.7520E-13, 3.6472E-13, 3.5439E-13, 3.4421E-13, 3.3418E-13,
     &   3.2429E-13, 3.1456E-13, 3.0497E-13, 2.9553E-13, 2.8624E-13,
     &   2.7710E-13, 2.6810E-13, 2.5926E-13, 2.5056E-13, 2.4201E-13,
     &   2.3361E-13, 2.2536E-13, 2.1725E-13, 2.0930E-13, 2.0149E-13,
     &   1.9383E-13, 1.8632E-13, 1.7896E-13, 1.7174E-13, 1.6468E-13,
     &   1.5776E-13, 1.5099E-13, 1.4437E-13, 1.3790E-13, 1.3158E-13,
     &   1.2540E-13, 1.1938E-13, 1.1350E-13, 1.0777E-13, 1.0219E-13,
     &   9.6754E-14, 9.1470E-14, 8.6334E-14, 8.1346E-14, 7.6507E-14,
     &   7.1816E-14, 6.7273E-14, 6.2879E-14, 5.8633E-14, 5.4536E-14,
     &   5.0587E-14, 4.6787E-14, 4.3134E-14, 3.9631E-14, 3.6275E-14,
     &   3.3068E-14, 3.0010E-14, 2.7099E-14, 2.4338E-14, 2.1724E-14,
     &   1.9259E-14, 1.6943E-14, 1.4774E-14, 1.2755E-14, 1.0883E-14,
     &   9.1602E-15, 0.0000E+00,-9.7216E-15,-8.2498E-08,-3.2990E-07,
     &  -7.4226E-07,-1.3195E-06,-2.0620E-06,-2.9699E-06,-4.0433E-06,
     &  -5.2826E-06,-6.6879E-06,-8.2596E-06,-9.9981E-06,-1.1904E-05,
     &  -1.3977E-05,-1.6218E-05,-1.8628E-05,-2.1207E-05,-2.3955E-05/
         DATA ((DAT(I,J), I= 901,977), J=1,1) /
     &  -2.6874E-05,-2.9964E-05,-3.3226E-05,-3.6660E-05,-4.0268E-05,
     &  -4.4050E-05,-4.8007E-05,-5.2139E-05,-5.6449E-05,-6.0937E-05,
     &  -6.5604E-05,-7.0451E-05,-7.5480E-05,-8.0692E-05,-8.6087E-05,
     &  -9.1668E-05,-9.7436E-05,-1.0339E-04,-1.0954E-04,-1.1588E-04,
     &  -1.2241E-04,-1.2913E-04,-1.3605E-04,-1.4317E-04,-1.5049E-04,
     &  -1.5802E-04,-1.6575E-04,-1.7368E-04,-1.8182E-04,-1.9018E-04,
     &  -1.9875E-04,-2.0754E-04,-2.1654E-04,-2.2577E-04,-2.3522E-04,
     &  -2.4490E-04,-2.5481E-04,-2.6496E-04,-2.7534E-04,-2.8597E-04,
     &  -2.9684E-04,-3.0796E-04,-3.1933E-04,-3.3096E-04,-3.4285E-04,
     &  -3.5501E-04,-3.6744E-04,-3.8014E-04,-3.9313E-04,-4.0641E-04,
     &  -4.1998E-04,-4.3385E-04,-4.4803E-04,-4.6253E-04,-4.7734E-04,
     &  -4.9249E-04,-5.0798E-04,-5.2382E-04,-5.4001E-04,-5.5658E-04,
     &  -5.7353E-04,-5.9088E-04,-6.0864E-04,-6.2683E-04,-6.4547E-04,
     &  -6.6457E-04,-6.8417E-04,-7.0428E-04,-7.2495E-04,-7.4622E-04,
     &  -7.6814E-04,-7.9077E-04,-8.1421E-04,-8.2222E-04,-8.3861E-04,
     &  -8.44461040E-04,-8.64236337E-04/
  
         DATA ((DAT(I,J), I=   1, 100), J=2,2) /
     &   1.9235E-04, 1.9235E-04, 1.9235E-04, 1.9235E-04, 1.9234E-04,
     &   1.9234E-04, 1.9234E-04, 1.9234E-04, 1.9234E-04, 1.9234E-04,
     &   1.9234E-04, 1.9234E-04, 1.9234E-04, 1.9234E-04, 1.9234E-04,
     &   1.9234E-04, 1.9234E-04, 1.9234E-04, 1.9234E-04, 1.9234E-04,
     &   1.9234E-04, 1.9234E-04, 1.9234E-04, 1.9234E-04, 1.9234E-04,
     &   1.9233E-04, 1.9233E-04, 1.9233E-04, 1.9233E-04, 1.9233E-04,
     &   1.9233E-04, 1.9233E-04, 1.9233E-04, 1.9233E-04, 1.9233E-04,
     &   1.9233E-04, 1.9233E-04, 1.9233E-04, 1.9232E-04, 1.9232E-04,
     &   1.9232E-04, 1.9232E-04, 1.9232E-04, 1.9232E-04, 1.9232E-04,
     &   1.9232E-04, 1.9232E-04, 1.9232E-04, 1.9231E-04, 1.9231E-04,
     &   1.9231E-04, 1.9231E-04, 1.9231E-04, 1.9231E-04, 1.9230E-04,
     &   1.9230E-04, 1.9230E-04, 1.9230E-04, 1.9230E-04, 1.9229E-04,
     &   1.9229E-04, 1.9229E-04, 1.9229E-04, 1.9228E-04, 1.9228E-04,
     &   1.9228E-04, 1.9227E-04, 1.9227E-04, 1.9227E-04, 1.9226E-04,
     &   1.9226E-04, 1.9225E-04, 1.9224E-04, 1.9224E-04, 1.9223E-04,
     &   1.9222E-04, 1.9221E-04, 1.9220E-04, 1.9219E-04, 1.9218E-04,
     &   1.9216E-04, 1.9215E-04, 1.9213E-04, 1.9211E-04, 1.9208E-04,
     &   1.9205E-04, 1.9201E-04, 1.9196E-04, 1.9190E-04, 1.9182E-04,
     &   1.9172E-04, 1.9171E-04, 1.9169E-04, 1.9168E-04, 1.9167E-04,
     &   1.9166E-04, 1.9164E-04, 1.9163E-04, 1.9161E-04, 1.9160E-04/
  
         DATA ((DAT(I,J), I= 101, 200), J=2,2) /
     &   1.9158E-04, 1.9157E-04, 1.9155E-04, 1.9153E-04, 1.9152E-04,
     &   1.9150E-04, 1.9148E-04, 1.9146E-04, 1.9144E-04, 1.9142E-04,
     &   1.9140E-04, 1.9137E-04, 1.9135E-04, 1.9133E-04, 1.9130E-04,
     &   1.9128E-04, 1.9125E-04, 1.9122E-04, 1.9119E-04, 1.9116E-04,
     &   1.9113E-04, 1.9110E-04, 1.9106E-04, 1.9103E-04, 1.9099E-04,
     &   1.9095E-04, 1.9091E-04, 1.9086E-04, 1.9082E-04, 1.9077E-04,
     &   1.9072E-04, 1.9067E-04, 1.9062E-04, 1.9056E-04, 1.9050E-04,
     &   1.9044E-04, 1.9037E-04, 1.9030E-04, 1.9023E-04, 1.9015E-04,
     &   1.9007E-04, 1.8998E-04, 1.8989E-04, 1.8979E-04, 1.8969E-04,
     &   1.8958E-04, 1.8946E-04, 1.8934E-04, 1.8921E-04, 1.8907E-04,
     &   1.8892E-04, 1.8875E-04, 1.8858E-04, 1.8840E-04, 1.8820E-04,
     &   1.8798E-04, 1.8775E-04, 1.8750E-04, 1.8723E-04, 1.8694E-04,
     &   1.8662E-04, 1.8628E-04, 1.8590E-04, 1.8549E-04, 1.8504E-04,
     &   1.8454E-04, 1.8400E-04, 1.8340E-04, 1.8274E-04, 1.8201E-04,
     &   1.8120E-04, 1.8029E-04, 1.7929E-04, 1.7816E-04, 1.7689E-04,
     &   1.7547E-04, 1.7386E-04, 1.7203E-04, 1.6994E-04, 1.6755E-04,
     &   1.6476E-04, 1.6449E-04, 1.6421E-04, 1.6393E-04, 1.6365E-04,
     &   1.6336E-04, 1.6307E-04, 1.6277E-04, 1.6246E-04, 1.6216E-04,
     &   1.6184E-04, 1.6153E-04, 1.6120E-04, 1.6088E-04, 1.6054E-04,
     &   1.6020E-04, 1.5986E-04, 1.5951E-04, 1.5915E-04, 1.5879E-04/
  
         DATA ((DAT(I,J), I= 201, 300), J=2,2) /
     &   1.5842E-04, 1.5804E-04, 1.5766E-04, 1.5727E-04, 1.5687E-04,
     &   1.5647E-04, 1.5605E-04, 1.5563E-04, 1.5520E-04, 1.5477E-04,
     &   1.5432E-04, 1.5387E-04, 1.5340E-04, 1.5293E-04, 1.5244E-04,
     &   1.5195E-04, 1.5144E-04, 1.5092E-04, 1.5040E-04, 1.4986E-04,
     &   1.4930E-04, 1.4874E-04, 1.4816E-04, 1.4756E-04, 1.4696E-04,
     &   1.4633E-04, 1.4569E-04, 1.4504E-04, 1.4437E-04, 1.4368E-04,
     &   1.4297E-04, 1.4224E-04, 1.4150E-04, 1.4073E-04, 1.3994E-04,
     &   1.3913E-04, 1.3829E-04, 1.3743E-04, 1.3654E-04, 1.3563E-04,
     &   1.3469E-04, 1.3371E-04, 1.3271E-04, 1.3167E-04, 1.3060E-04,
     &   1.2950E-04, 1.2835E-04, 1.2717E-04, 1.2594E-04, 1.2467E-04,
     &   1.2335E-04, 1.2198E-04, 1.2056E-04, 1.1908E-04, 1.1754E-04,
     &   1.1594E-04, 1.1428E-04, 1.1254E-04, 1.1073E-04, 1.0884E-04,
     &   1.0686E-04, 1.0479E-04, 1.0263E-04, 1.0036E-04, 9.7985E-05,
     &   9.5493E-05, 9.2878E-05, 9.0133E-05, 8.7249E-05, 8.4220E-05,
     &   8.1038E-05, 7.7698E-05, 7.4193E-05, 7.0519E-05, 6.6674E-05,
     &   6.2659E-05, 5.8476E-05, 5.4133E-05, 4.9644E-05, 4.5028E-05,
     &   4.0311E-05, 3.9835E-05, 3.9358E-05, 3.8881E-05, 3.8403E-05,
     &   3.7925E-05, 3.7446E-05, 3.6967E-05, 3.6488E-05, 3.6008E-05,
     &   3.5528E-05, 3.5048E-05, 3.4567E-05, 3.4087E-05, 3.3606E-05,
     &   3.3125E-05, 3.2644E-05, 3.2164E-05, 3.1683E-05, 3.1203E-05/
  
         DATA ((DAT(I,J), I= 301, 400), J=2,2) /
     &   3.0723E-05, 3.0243E-05, 2.9764E-05, 2.9285E-05, 2.8806E-05,
     &   2.8328E-05, 2.7851E-05, 2.7374E-05, 2.6898E-05, 2.6423E-05,
     &   2.5949E-05, 2.5476E-05, 2.5003E-05, 2.4532E-05, 2.4062E-05,
     &   2.3593E-05, 2.3126E-05, 2.2659E-05, 2.2195E-05, 2.1731E-05,
     &   2.1270E-05, 2.0810E-05, 2.0352E-05, 1.9896E-05, 1.9441E-05,
     &   1.8989E-05, 1.8539E-05, 1.8091E-05, 1.7645E-05, 1.7202E-05,
     &   1.6761E-05, 1.6323E-05, 1.5887E-05, 1.5455E-05, 1.5025E-05,
     &   1.4598E-05, 1.4174E-05, 1.3753E-05, 1.3336E-05, 1.2922E-05,
     &   1.2512E-05, 1.2105E-05, 1.1702E-05, 1.1303E-05, 1.0908E-05,
     &   1.0517E-05, 1.0131E-05, 9.7488E-06, 9.3713E-06, 8.9985E-06,
     &   8.6305E-06, 8.2675E-06, 7.9097E-06, 7.5572E-06, 7.2102E-06,
     &   6.8688E-06, 6.5333E-06, 6.2037E-06, 5.8803E-06, 5.5633E-06,
     &   5.2528E-06, 4.9490E-06, 4.6521E-06, 4.3624E-06, 4.0800E-06,
     &   3.8052E-06, 3.5380E-06, 3.2789E-06, 3.0279E-06, 2.7853E-06,
     &   2.5514E-06, 2.3263E-06, 2.1102E-06, 1.9035E-06, 1.7063E-06,
     &   1.5188E-06, 1.3412E-06, 1.1739E-06, 1.0169E-06, 8.7051E-07,
     &   7.3491E-07, 7.2195E-07, 7.0910E-07, 6.9636E-07, 6.8373E-07,
     &   6.7121E-07, 6.5880E-07, 6.4650E-07, 6.3432E-07, 6.2224E-07,
     &   6.1028E-07, 5.9843E-07, 5.8669E-07, 5.7506E-07, 5.6354E-07,
     &   5.5214E-07, 5.4084E-07, 5.2966E-07, 5.1860E-07, 5.0764E-07/
  
         DATA ((DAT(I,J), I= 401, 500), J=2,2) /
     &   4.9680E-07, 4.8607E-07, 4.7546E-07, 4.6496E-07, 4.5457E-07,
     &   4.4430E-07, 4.3414E-07, 4.2409E-07, 4.1416E-07, 4.0435E-07,
     &   3.9464E-07, 3.8506E-07, 3.7558E-07, 3.6623E-07, 3.5698E-07,
     &   3.4786E-07, 3.3885E-07, 3.2995E-07, 3.2117E-07, 3.1251E-07,
     &   3.0396E-07, 2.9553E-07, 2.8721E-07, 2.7901E-07, 2.7093E-07,
     &   2.6296E-07, 2.5511E-07, 2.4738E-07, 2.3977E-07, 2.3227E-07,
     &   2.2489E-07, 2.1762E-07, 2.1048E-07, 2.0345E-07, 1.9654E-07,
     &   1.8974E-07, 1.8307E-07, 1.7651E-07, 1.7007E-07, 1.6375E-07,
     &   1.5755E-07, 1.5147E-07, 1.4550E-07, 1.3966E-07, 1.3393E-07,
     &   1.2832E-07, 1.2283E-07, 1.1746E-07, 1.1221E-07, 1.0708E-07,
     &   1.0206E-07, 9.7168E-08, 9.2394E-08, 8.7739E-08, 8.3204E-08,
     &   7.8788E-08, 7.4492E-08, 7.0316E-08, 6.6260E-08, 6.2324E-08,
     &   5.8508E-08, 5.4812E-08, 5.1236E-08, 4.7780E-08, 4.4444E-08,
     &   4.1229E-08, 3.8134E-08, 3.5160E-08, 3.2306E-08, 2.9573E-08,
     &   2.6960E-08, 2.4468E-08, 2.2096E-08, 1.9845E-08, 1.7715E-08,
     &   1.5706E-08, 1.3817E-08, 1.2050E-08, 1.0403E-08, 8.8766E-09,
     &   7.4715E-09, 7.3376E-09, 7.2050E-09, 7.0735E-09, 6.9433E-09,
     &   6.8143E-09, 6.6865E-09, 6.5599E-09, 6.4345E-09, 6.3103E-09,
     &   6.1873E-09, 6.0656E-09, 5.9450E-09, 5.8257E-09, 5.7075E-09,
     &   5.5906E-09, 5.4749E-09, 5.3604E-09, 5.2471E-09, 5.1350E-09/
  
         DATA ((DAT(I,J), I= 501, 600), J=2,2) /
     &   5.0241E-09, 4.9144E-09, 4.8060E-09, 4.6987E-09, 4.5927E-09,
     &   4.4879E-09, 4.3843E-09, 4.2818E-09, 4.1806E-09, 4.0807E-09,
     &   3.9819E-09, 3.8843E-09, 3.7880E-09, 3.6928E-09, 3.5989E-09,
     &   3.5061E-09, 3.4146E-09, 3.3243E-09, 3.2352E-09, 3.1473E-09,
     &   3.0606E-09, 2.9752E-09, 2.8909E-09, 2.8079E-09, 2.7260E-09,
     &   2.6454E-09, 2.5660E-09, 2.4878E-09, 2.4108E-09, 2.3350E-09,
     &   2.2604E-09, 2.1870E-09, 2.1149E-09, 2.0439E-09, 1.9742E-09,
     &   1.9057E-09, 1.8383E-09, 1.7722E-09, 1.7073E-09, 1.6437E-09,
     &   1.5812E-09, 1.5199E-09, 1.4599E-09, 1.4010E-09, 1.3434E-09,
     &   1.2870E-09, 1.2317E-09, 1.1777E-09, 1.1250E-09, 1.0734E-09,
     &   1.0230E-09, 9.7384E-10, 9.2589E-10, 8.7915E-10, 8.3362E-10,
     &   7.8930E-10, 7.4619E-10, 7.0429E-10, 6.6360E-10, 6.2413E-10,
     &   5.8586E-10, 5.4880E-10, 5.1296E-10, 4.7832E-10, 4.4490E-10,
     &   4.1268E-10, 3.8168E-10, 3.5188E-10, 3.2330E-10, 2.9593E-10,
     &   2.6977E-10, 2.4481E-10, 2.2107E-10, 1.9854E-10, 1.7722E-10,
     &   1.5711E-10, 1.3822E-10, 1.2053E-10, 1.0405E-10, 8.8784E-11,
     &   7.4728E-11, 7.3389E-11, 7.2062E-11, 7.0747E-11, 6.9444E-11,
     &   6.8154E-11, 6.6875E-11, 6.5609E-11, 6.4354E-11, 6.3112E-11,
     &   6.1882E-11, 6.0664E-11, 5.9458E-11, 5.8264E-11, 5.7083E-11,
     &   5.5913E-11, 5.4756E-11, 5.3610E-11, 5.2477E-11, 5.1356E-11/
  
         DATA ((DAT(I,J), I= 601, 700), J=2,2) /
     &   5.0247E-11, 4.9150E-11, 4.8065E-11, 4.6992E-11, 4.5932E-11,
     &   4.4883E-11, 4.3847E-11, 4.2823E-11, 4.1810E-11, 4.0810E-11,
     &   3.9822E-11, 3.8847E-11, 3.7883E-11, 3.6931E-11, 3.5992E-11,
     &   3.5064E-11, 3.4149E-11, 3.3246E-11, 3.2354E-11, 3.1475E-11,
     &   3.0609E-11, 2.9754E-11, 2.8911E-11, 2.8080E-11, 2.7262E-11,
     &   2.6456E-11, 2.5661E-11, 2.4879E-11, 2.4109E-11, 2.3351E-11,
     &   2.2605E-11, 2.1871E-11, 2.1150E-11, 2.0440E-11, 1.9743E-11,
     &   1.9057E-11, 1.8384E-11, 1.7723E-11, 1.7074E-11, 1.6437E-11,
     &   1.5812E-11, 1.5200E-11, 1.4599E-11, 1.4011E-11, 1.3434E-11,
     &   1.2870E-11, 1.2318E-11, 1.1778E-11, 1.1250E-11, 1.0734E-11,
     &   1.0230E-11, 9.7386E-12, 9.2591E-12, 8.7917E-12, 8.3363E-12,
     &   7.8931E-12, 7.4620E-12, 7.0430E-12, 6.6361E-12, 6.2413E-12,
     &   5.8587E-12, 5.4881E-12, 5.1296E-12, 4.7833E-12, 4.4490E-12,
     &   4.1268E-12, 3.8168E-12, 3.5189E-12, 3.2330E-12, 2.9593E-12,
     &   2.6977E-12, 2.4482E-12, 2.2107E-12, 1.9854E-12, 1.7722E-12,
     &   1.5712E-12, 1.3822E-12, 1.2053E-12, 1.0405E-12, 8.8784E-13,
     &   7.4728E-13, 7.3389E-13, 7.2062E-13, 7.0747E-13, 6.9444E-13,
     &   6.8154E-13, 6.6875E-13, 6.5609E-13, 6.4354E-13, 6.3112E-13,
     &   6.1882E-13, 6.0664E-13, 5.9458E-13, 5.8264E-13, 5.7083E-13,
     &   5.5913E-13, 5.4756E-13, 5.3610E-13, 5.2477E-13, 5.1356E-13/
  
         DATA ((DAT(I,J), I= 701, 800), J=2,2) /
     &   5.0247E-13, 4.9150E-13, 4.8065E-13, 4.6993E-13, 4.5932E-13,
     &   4.4883E-13, 4.3847E-13, 4.2823E-13, 4.1811E-13, 4.0810E-13,
     &   3.9822E-13, 3.8847E-13, 3.7883E-13, 3.6931E-13, 3.5992E-13,
     &   3.5064E-13, 3.4149E-13, 3.3246E-13, 3.2354E-13, 3.1475E-13,
     &   3.0609E-13, 2.9754E-13, 2.8911E-13, 2.8080E-13, 2.7262E-13,
     &   2.6456E-13, 2.5661E-13, 2.4879E-13, 2.4109E-13, 2.3351E-13,
     &   2.2605E-13, 2.1871E-13, 2.1150E-13, 2.0440E-13, 1.9743E-13,
     &   1.9057E-13, 1.8384E-13, 1.7723E-13, 1.7074E-13, 1.6437E-13,
     &   1.5812E-13, 1.5200E-13, 1.4599E-13, 1.4011E-13, 1.3434E-13,
     &   1.2870E-13, 1.2318E-13, 1.1778E-13, 1.1250E-13, 1.0734E-13,
     &   1.0230E-13, 9.7386E-14, 9.2591E-14, 8.7917E-14, 8.3363E-14,
     &   7.8931E-14, 7.4620E-14, 7.0430E-14, 6.6361E-14, 6.2413E-14,
     &   5.8587E-14, 5.4881E-14, 5.1296E-14, 4.7833E-14, 4.4490E-14,
     &   4.1268E-14, 3.8168E-14, 3.5189E-14, 3.2330E-14, 2.9593E-14,
     &   2.6977E-14, 2.4482E-14, 2.2107E-14, 1.9854E-14, 1.7722E-14,
     &   1.5712E-14, 1.3822E-14, 1.2053E-14, 1.0405E-14, 8.8784E-15,
     &   7.4728E-15, 7.3389E-15, 7.2062E-15, 7.0747E-15, 6.9444E-15,
     &   6.8154E-15, 6.6875E-15, 6.5609E-15, 6.4354E-15, 6.3112E-15,
     &   6.1882E-15, 6.0664E-15, 5.9458E-15, 5.8264E-15, 5.7083E-15,
     &   5.5913E-15, 5.4756E-15, 5.3610E-15, 5.2477E-15, 5.1356E-15/
  
         DATA ((DAT(I,J), I= 801, 900), J=2,2) /
     &   5.0247E-15, 4.9150E-15, 4.8065E-15, 4.6993E-15, 4.5932E-15,
     &   4.4883E-15, 4.3847E-15, 4.2823E-15, 4.1811E-15, 4.0810E-15,
     &   3.9822E-15, 3.8847E-15, 3.7883E-15, 3.6931E-15, 3.5992E-15,
     &   3.5064E-15, 3.4149E-15, 3.3246E-15, 3.2354E-15, 3.1475E-15,
     &   3.0609E-15, 2.9754E-15, 2.8911E-15, 2.8080E-15, 2.7262E-15,
     &   2.6456E-15, 2.5661E-15, 2.4879E-15, 2.4109E-15, 2.3351E-15,
     &   2.2605E-15, 2.1871E-15, 2.1150E-15, 2.0440E-15, 1.9743E-15,
     &   1.9057E-15, 1.8384E-15, 1.7723E-15, 1.7074E-15, 1.6437E-15,
     &   1.5812E-15, 1.5200E-15, 1.4599E-15, 1.4011E-15, 1.3434E-15,
     &   1.2870E-15, 1.2318E-15, 1.1778E-15, 1.1250E-15, 1.0734E-15,
     &   1.0230E-15, 9.7386E-16, 9.2591E-16, 8.7917E-16, 8.3363E-16,
     &   7.8931E-16, 7.4620E-16, 7.0430E-16, 6.6361E-16, 6.2413E-16,
     &   5.8587E-16, 5.4881E-16, 5.1296E-16, 4.7833E-16, 4.4490E-16,
     &   4.1268E-16, 3.8168E-16, 3.5189E-16, 3.2330E-16, 2.9593E-16,
     &   2.6977E-16, 2.4482E-16, 2.2107E-16, 1.9854E-16, 1.7722E-16,
     &   1.5711E-16, 1.3822E-16, 1.2053E-16, 1.0405E-16, 8.8784E-17,
     &   7.4728E-17, 0.0000E+00, 7.9585E-17, 6.7301E-10, 2.6913E-09,
     &   6.0551E-09, 1.0763E-08, 1.6820E-08, 2.4225E-08, 3.2980E-08,
     &   4.3086E-08, 5.4545E-08, 6.7360E-08, 8.1532E-08, 9.7065E-08,
     &   1.1396E-07, 1.3222E-07, 1.5186E-07, 1.7286E-07, 1.9525E-07/
  
         DATA ((DAT(I,J), I= 901,977), J=2,2) /
     &   2.1902E-07, 2.4417E-07, 2.7072E-07, 2.9866E-07, 3.2801E-07,
     &   3.5877E-07, 3.9094E-07, 4.2453E-07, 4.5955E-07, 4.9601E-07,
     &   5.3391E-07, 5.7326E-07, 6.1408E-07, 6.5636E-07, 7.0012E-07,
     &   7.4537E-07, 7.9211E-07, 8.4037E-07, 8.9014E-07, 9.4145E-07,
     &   9.9430E-07, 1.0487E-06, 1.1047E-06, 1.1622E-06, 1.2214E-06,
     &   1.2822E-06, 1.3446E-06, 1.4086E-06, 1.4743E-06, 1.5417E-06,
     &   1.6108E-06, 1.6816E-06, 1.7542E-06, 1.8285E-06, 1.9046E-06,
     &   1.9825E-06, 2.0622E-06, 2.1439E-06, 2.2273E-06, 2.3128E-06,
     &   2.4001E-06, 2.4894E-06, 2.5808E-06, 2.6742E-06, 2.7697E-06,
     &   2.8673E-06, 2.9671E-06, 3.0691E-06, 3.1734E-06, 3.2800E-06,
     &   3.3889E-06, 3.5003E-06, 3.6142E-06, 3.7306E-06, 3.8497E-06,
     &   3.9714E-06, 4.0960E-06, 4.2234E-06, 4.3538E-06, 4.4872E-06,
     &   4.6239E-06, 4.7638E-06, 4.9072E-06, 5.0542E-06, 5.2050E-06,
     &   5.3598E-06, 5.5187E-06, 5.6820E-06, 5.8499E-06, 6.0228E-06,
     &   6.2011E-06, 6.3850E-06, 6.5752E-06, 6.6401E-06, 6.7722E-06,
     &   6.81924437E-06, 6.97679928E-06/
c
      save
      RETURN
      END
